Class: ContextDev::Models::AIExtractProductParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::AIExtractProductParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/ai_extract_product_params.rb
Overview
Instance Attribute Summary collapse
-
#max_age_ms ⇒ Integer?
Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#url ⇒ String
The product page URL to extract product data from.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(url:, max_age_ms: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AIExtractProductParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, max_age_ms: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::AIExtractProductParams for more details.
|
|
# File 'lib/context_dev/models/ai_extract_product_params.rb', line 31
|
Instance Attribute Details
#max_age_ms ⇒ Integer?
Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds. Defaults to 7 days (604800000 ms) when omitted. Max is 30 days (2592000000 ms). Set to 0 to always scrape fresh.
22 |
# File 'lib/context_dev/models/ai_extract_product_params.rb', line 22 optional :max_age_ms, Integer, api_name: :maxAgeMs |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. Maximum allowed value is 300000ms (5 minutes).
29 |
# File 'lib/context_dev/models/ai_extract_product_params.rb', line 29 optional :timeout_ms, Integer, api_name: :timeoutMS |
#url ⇒ String
The product page URL to extract product data from.
14 |
# File 'lib/context_dev/models/ai_extract_product_params.rb', line 14 required :url, String |