Class: ContextDev::Models::AIExtractProductResponse::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::AIExtractProductResponse::Product
- Defined in:
- lib/context_dev/models/ai_extract_product_response.rb
Overview
Defined Under Namespace
Modules: BillingFrequency, PricingModel
Instance Attribute Summary collapse
-
#billing_frequency ⇒ Symbol, ...
Billing frequency for the product.
-
#category ⇒ String?
Category of the product.
-
#currency ⇒ String?
Currency code for the price (e.g., USD, EUR).
-
#description ⇒ String
Description of the product.
-
#features ⇒ Array<String>
List of product features.
-
#image_url ⇒ String?
URL to the product image.
-
#images ⇒ Array<String>
URLs to product images on the page (up to 7).
-
#name ⇒ String
Name of the product.
-
#price ⇒ Float?
Price of the product.
-
#pricing_model ⇒ Symbol, ...
Pricing model for the product.
-
#sku ⇒ String?
Stock Keeping Unit (product identifier).
-
#tags ⇒ Array<String>
Tags associated with the product.
-
#target_audience ⇒ Array<String>
Target audience for the product (array of strings).
-
#url ⇒ String?
URL to the product page.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(description:, features:, images:, name:, sku:, tags:, target_audience:, billing_frequency: nil, category: nil, currency: nil, image_url: nil, price: nil, pricing_model: nil, url: nil) ⇒ Object
constructor
The extracted product data, or null if not a product page.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, features:, images:, name:, sku:, tags:, target_audience:, billing_frequency: nil, category: nil, currency: nil, image_url: nil, price: nil, pricing_model: nil, url: nil) ⇒ Object
The extracted product data, or null if not a product page
|
|
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 172
|
Instance Attribute Details
#billing_frequency ⇒ Symbol, ...
Billing frequency for the product
130 131 132 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 130 optional :billing_frequency, enum: -> { ContextDev::Models::AIExtractProductResponse::Product::BillingFrequency }, nil?: true |
#category ⇒ String?
Category of the product
138 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 138 optional :category, String, nil?: true |
#currency ⇒ String?
Currency code for the price (e.g., USD, EUR)
144 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 144 optional :currency, String, nil?: true |
#description ⇒ String
Description of the product
88 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 88 required :description, String |
#features ⇒ Array<String>
List of product features
94 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 94 required :features, ContextDev::Internal::Type::ArrayOf[String] |
#image_url ⇒ String?
URL to the product image
150 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 150 optional :image_url, String, nil?: true |
#images ⇒ Array<String>
URLs to product images on the page (up to 7)
100 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 100 required :images, ContextDev::Internal::Type::ArrayOf[String] |
#name ⇒ String
Name of the product
106 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 106 required :name, String |
#price ⇒ Float?
Price of the product
156 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 156 optional :price, Float, nil?: true |
#pricing_model ⇒ Symbol, ...
Pricing model for the product
162 163 164 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 162 optional :pricing_model, enum: -> { ContextDev::Models::AIExtractProductResponse::Product::PricingModel }, nil?: true |
#sku ⇒ String?
Stock Keeping Unit (product identifier). Null if no identifier is found.
112 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 112 required :sku, String, nil?: true |
#tags ⇒ Array<String>
Tags associated with the product
118 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 118 required :tags, ContextDev::Internal::Type::ArrayOf[String] |
#target_audience ⇒ Array<String>
Target audience for the product (array of strings)
124 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 124 required :target_audience, ContextDev::Internal::Type::ArrayOf[String] |
#url ⇒ String?
URL to the product page
170 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 170 optional :url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 214
|