Class: ContextDev::Models::AIExtractProductsParams::Body::ByDirectURL
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::AIExtractProductsParams::Body::ByDirectURL
- Defined in:
- lib/context_dev/models/ai_extract_products_params.rb
Instance Attribute Summary collapse
-
#direct_url ⇒ String
A specific URL to use directly as the starting point for extraction without domain resolution.
-
#max_products ⇒ Integer?
Maximum number of products to extract.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Instance Method Summary collapse
-
#initialize(direct_url:, max_products: nil, timeout_ms: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ByDirectURL for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(direct_url:, max_products: nil, timeout_ms: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::AIExtractProductsParams::Body::ByDirectURL for more details.
|
|
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 78
|
Instance Attribute Details
#direct_url ⇒ String
A specific URL to use directly as the starting point for extraction without domain resolution.
63 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 63 required :direct_url, String, api_name: :directUrl |
#max_products ⇒ Integer?
Maximum number of products to extract.
69 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 69 optional :max_products, Integer, api_name: :maxProducts |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. Maximum allowed value is 300000ms (5 minutes).
76 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 76 optional :timeout_ms, Integer, api_name: :timeoutMS |