Class: ContextDev::Models::AIExtractProductsParams::Body::ByDomain
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::AIExtractProductsParams::Body::ByDomain
- Defined in:
- lib/context_dev/models/ai_extract_products_params.rb
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain name to analyze.
-
#max_age_ms ⇒ Integer?
Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds.
-
#max_products ⇒ Integer?
Maximum number of products to extract.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ContextDev::Internal::Type::BaseModel
Instance Attribute Details
#domain ⇒ String
The domain name to analyze.
31 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 31 required :domain, String |
#max_age_ms ⇒ Integer?
Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds. Defaults to 7 days (604800000 ms) when omitted. Max is 30 days (2592000000 ms). Set to 0 to always scrape fresh.
39 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 39 optional :max_age_ms, Integer, api_name: :maxAgeMs |
#max_products ⇒ Integer?
Maximum number of products to extract.
45 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 45 optional :max_products, Integer, api_name: :maxProducts |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. Maximum allowed value is 300000ms (5 minutes).
52 |
# File 'lib/context_dev/models/ai_extract_products_params.rb', line 52 optional :timeout_ms, Integer, api_name: :timeoutMS |