Class: ContextDev::Models::BatchGetResultsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/batch_get_results_params.rb,
sig/context_dev/models/batch_get_results_params.rbs

Overview

See Also:

  • ContextDev::Resources::Batch#get_results

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(batch_id:, cursor: nil, limit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BatchGetResultsParams for more details.

Parameters:

  • batch_id (String)

    ID of the batch to retrieve or cancel.

  • cursor (String) (defaults to: nil)

    next_cursor from the previous page.

  • limit (Integer) (defaults to: nil)

    Records per page. Defaults to 25. A page can close early so its payload stays un

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/batch_get_results_params.rb', line 29

Instance Attribute Details

#batch_idString

ID of the batch to retrieve or cancel.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/context_dev/models/batch_get_results_params.rb', line 14

required :batch_id, String

#cursorString?

next_cursor from the previous page.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/context_dev/models/batch_get_results_params.rb', line 20

optional :cursor, String

#limitInteger?

Records per page. Defaults to 25. A page can close early so its payload stays under ~8 MB; rely on next_cursor rather than counting records.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


27
# File 'lib/context_dev/models/batch_get_results_params.rb', line 27

optional :limit, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/context_dev/models/batch_get_results_params.rbs', line 28

def to_hash: -> {