Class: ContextDev::Models::BatchGetResultsResponse::Data::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BatchGetResultsResponse::Data::Error
- Defined in:
- lib/context_dev/models/batch_get_results_response.rb,
sig/context_dev/models/batch_get_results_response.rbs
Instance Attribute Summary collapse
-
#error_code ⇒ String
Why the page failed.
-
#item_id ⇒ String?
Caller-supplied identifier echoed from submission.
-
#message ⇒ String
Human-readable failure detail.
-
#meta ⇒ Hash{Symbol=>Object}?
Caller-supplied metadata echoed from submission.
-
#status ⇒ Symbol, :error
The page could not be scraped.
-
#url ⇒ String
URL as submitted, or as discovered by the crawl.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
357 |
# File 'sig/context_dev/models/batch_get_results_response.rbs', line 357
def initialize: (
|
Instance Attribute Details
#error_code ⇒ String
Why the page failed.
387 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 387 required :error_code, String |
#item_id ⇒ String?
Caller-supplied identifier echoed from submission.
411 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 411 optional :item_id, String, api_name: :itemId |
#message ⇒ String
Human-readable failure detail.
393 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 393 required :message, String |
#meta ⇒ Hash{Symbol=>Object}?
Caller-supplied metadata echoed from submission.
417 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 417 optional :meta, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#status ⇒ Symbol, :error
The page could not be scraped.
399 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 399 required :status, const: :error |
#url ⇒ String
URL as submitted, or as discovered by the crawl.
405 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 405 required :url, String |
Instance Method Details
#to_hash ⇒ {
366 |
# File 'sig/context_dev/models/batch_get_results_response.rbs', line 366
def to_hash: -> {
|