Class: ContextDev::Models::BatchListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/batch_list_params.rb,
sig/context_dev/models/batch_list_params.rbs

Overview

See Also:

  • ContextDev::Resources::Batch#list

Defined Under Namespace

Modules: SearchType, Status

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cursor: nil, limit: nil, q: nil, search_type: nil, status: nil, tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BatchListParams for more details.

Parameters:

  • cursor (String) (defaults to: nil)

    Cursor from the previous page.

  • limit (Integer) (defaults to: nil)

    Batches per page. Defaults to 25.

  • q (String) (defaults to: nil)

    Free-text search term, matched against the batch id, crawl source (start URL or

  • search_type (Symbol, ContextDev::Models::BatchListParams::SearchType) (defaults to: nil)

    prefix for as-you-type prefix matching (default), exact for full-token match

  • status (Symbol, ContextDev::Models::BatchListParams::Status) (defaults to: nil)

    Filter by status.

  • tags (String) (defaults to: nil)

    Comma-separated list of tags to filter by (matches batches having any of them).

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/batch_list_params.rb', line 48

Instance Attribute Details

#cursorString?

Cursor from the previous page.

Parameters:

  • (String)

Returns:

  • (String, nil)


14
# File 'lib/context_dev/models/batch_list_params.rb', line 14

optional :cursor, String

#limitInteger?

Batches per page. Defaults to 25.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


20
# File 'lib/context_dev/models/batch_list_params.rb', line 20

optional :limit, Integer

#qString?

Free-text search term, matched against the batch id, crawl source (start URL or sitemap domain), and tags.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/context_dev/models/batch_list_params.rb', line 27

optional :q, String

#search_typeSymbol, ...

prefix for as-you-type prefix matching (default), exact for full-token matching.



34
# File 'lib/context_dev/models/batch_list_params.rb', line 34

optional :search_type, enum: -> { ContextDev::BatchListParams::SearchType }

#statusSymbol, ...

Filter by status.



40
# File 'lib/context_dev/models/batch_list_params.rb', line 40

optional :status, enum: -> { ContextDev::BatchListParams::Status }

#tagsString?

Comma-separated list of tags to filter by (matches batches having any of them).

Parameters:

  • (String)

Returns:

  • (String, nil)


46
# File 'lib/context_dev/models/batch_list_params.rb', line 46

optional :tags, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/batch_list_params.rb', line 74

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/context_dev/models/batch_list_params.rbs', line 56

def to_hash: -> {