Module: ContextDev::Models::BatchSubmitParams::Input::Crawl::Data::Markdown::Options::Pdf::Ocr
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/context_dev/models/batch_submit_params.rb,
sig/context_dev/models/batch_submit_params.rbs
Overview
When true, OCR the selected PDF pages that have no usable text layer (scans), replacing each recovered page's text with the OCR result while pages with a real text layer keep it. Billed at 1 credit per page OCR actually recovered, on top of the base request cost. When false, no OCR runs.
collapse
- TRUE =
:true- FALSE =
:false
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Boolean, Symbol)
1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'lib/context_dev/models/batch_submit_params.rb', line 1717 define_sorbet_constant!(:Variants) do T.type_alias do T.any( T::Boolean, ContextDev::BatchSubmitParams::Input::Crawl::Data::Markdown::Options::Pdf::Ocr::TaggedSymbol ) end end |
Instance Method Details
#self?.variants ⇒ ::Array[ContextDev::Models::BatchSubmitParams::Input::Crawl::Data::Markdown::Options::Pdf::ocr]
2057 |
# File 'sig/context_dev/models/batch_submit_params.rbs', line 2057
def self?.variants: -> ::Array[ContextDev::Models::BatchSubmitParams::Input::Crawl::Data::Markdown::Options::Pdf::ocr]
|