Class: ContextDev::Models::BrandIdentifyFromTransactionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandIdentifyFromTransactionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/brand_identify_from_transaction_params.rb
Overview
Defined Under Namespace
Modules: CountryGl, ForceLanguage
Instance Attribute Summary collapse
-
#city ⇒ String?
Optional city name to prioritize when searching for the brand.
-
#country_gl ⇒ Symbol, ...
Optional country code (GL parameter) to specify the country.
-
#force_language ⇒ Symbol, ...
Optional parameter to force the language of the retrieved brand data.
-
#high_confidence_only ⇒ Boolean?
When set to true, the API will perform an additional verification steps to ensure the identified brand matches the transaction with high confidence.
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#mcc ⇒ String?
Optional Merchant Category Code (MCC) to help identify the business category/industry.
-
#phone ⇒ Float?
Optional phone number from the transaction to help verify brand match.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#transaction_info ⇒ String
Transaction information to identify the brand.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandIdentifyFromTransactionParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandIdentifyFromTransactionParams for more details.
|
|
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 71
|
Instance Attribute Details
#city ⇒ String?
Optional city name to prioritize when searching for the brand.
20 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 20 optional :city, String |
#country_gl ⇒ Symbol, ...
Optional country code (GL parameter) to specify the country. This affects the geographic location used for search queries.
27 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 27 optional :country_gl, enum: -> { ContextDev::BrandIdentifyFromTransactionParams::CountryGl } |
#force_language ⇒ Symbol, ...
Optional parameter to force the language of the retrieved brand data.
33 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 33 optional :force_language, enum: -> { ContextDev::BrandIdentifyFromTransactionParams::ForceLanguage } |
#high_confidence_only ⇒ Boolean?
When set to true, the API will perform an additional verification steps to ensure the identified brand matches the transaction with high confidence.
40 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 40 optional :high_confidence_only, ContextDev::Internal::Type::Boolean |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
48 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 48 optional :max_speed, ContextDev::Internal::Type::Boolean |
#mcc ⇒ String?
Optional Merchant Category Code (MCC) to help identify the business category/industry.
55 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 55 optional :mcc, String |
#phone ⇒ Float?
Optional phone number from the transaction to help verify brand match.
61 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 61 optional :phone, Float |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
69 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 69 optional :timeout_ms, Integer |
#transaction_info ⇒ String
Transaction information to identify the brand
14 |
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 14 required :transaction_info, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_identify_from_transaction_params.rb', line 340
|