Class: ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo
- Defined in:
- lib/context_dev/models/brand_identify_from_transaction_response.rb
Defined Under Namespace
Modules: Mode, Type Classes: Color, Resolution
Instance Attribute Summary collapse
-
#colors ⇒ Array<ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Color>?
Array of colors in the logo.
-
#mode ⇒ Symbol, ...
Indicates when this logo is best used: ‘light’ = best for light mode, ‘dark’ = best for dark mode, ‘has_opaque_background’ = can be used for either as image has its own background.
-
#resolution ⇒ ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Resolution?
Resolution of the logo image.
-
#type ⇒ Symbol, ...
Type of the logo based on resolution (e.g., ‘icon’, ‘logo’).
-
#url ⇒ String?
CDN hosted url of the logo (ready for display).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(aspect_ratio: nil, height: nil, width: nil) ⇒ Object
constructor
Resolution of the logo image.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aspect_ratio: nil, height: nil, width: nil) ⇒ Object
Resolution of the logo image
|
|
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 755
|
Instance Attribute Details
#colors ⇒ Array<ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Color>?
Array of colors in the logo
697 698 |
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 697 optional :colors, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Color] } |
#mode ⇒ Symbol, ...
Indicates when this logo is best used: ‘light’ = best for light mode, ‘dark’ = best for dark mode, ‘has_opaque_background’ = can be used for either as image has its own background
706 |
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 706 optional :mode, enum: -> { ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Mode } |
#resolution ⇒ ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Resolution?
Resolution of the logo image
712 713 |
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 712 optional :resolution, -> { ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Resolution } |
#type ⇒ Symbol, ...
Type of the logo based on resolution (e.g., ‘icon’, ‘logo’)
719 |
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 719 optional :type, enum: -> { ContextDev::Models::BrandIdentifyFromTransactionResponse::Brand::Logo::Type } |
#url ⇒ String?
CDN hosted url of the logo (ready for display)
725 |
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 725 optional :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_identify_from_transaction_response.rb', line 773
|