Class: ContextDev::Models::BrandRetrieveByEmailResponse::Brand

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_retrieve_by_email_response.rb

Overview

See Also:

Defined Under Namespace

Modules: PrimaryLanguage Classes: Address, Backdrop, Color, Industries, Links, Logo, Social, Stock

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(blog: nil, careers: nil, contact: nil, pricing: nil, privacy: nil, terms: nil) ⇒ Object

Important website links for the brand

Parameters:

  • blog (String, nil) (defaults to: nil)

    URL to the brand’s blog or news page

  • careers (String, nil) (defaults to: nil)

    URL to the brand’s careers or job opportunities page

  • contact (String, nil) (defaults to: nil)

    URL to the brand’s contact or contact us page

  • pricing (String, nil) (defaults to: nil)

    URL to the brand’s pricing or plans page

  • privacy (String, nil) (defaults to: nil)

    URL to the brand’s privacy policy page

  • terms (String, nil) (defaults to: nil)

    URL to the brand’s terms of service or terms and conditions page



# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 150

Instance Attribute Details

#addressContextDev::Models::BrandRetrieveByEmailResponse::Brand::Address?

Physical address of the brand



50
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 50

optional :address, -> { ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Address }

#backdropsArray<ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Backdrop>?

An array of backdrop images for the brand



56
57
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 56

optional :backdrops,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Backdrop] }

#colorsArray<ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Color>?

An array of brand colors



63
64
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 63

optional :colors,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Color] }

#descriptionString?

A brief description of the brand

Returns:

  • (String, nil)


70
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 70

optional :description, String

#domainString?

The domain name of the brand

Returns:

  • (String, nil)


76
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 76

optional :domain, String

#emailString?

Company email address

Returns:

  • (String, nil)


82
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 82

optional :email, String

#industriesContextDev::Models::BrandRetrieveByEmailResponse::Brand::Industries?

Industry classification information for the brand



88
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 88

optional :industries, -> { ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Industries }

#is_nsfwBoolean?

Indicates whether the brand content is not safe for work (NSFW)

Returns:

  • (Boolean, nil)


94
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 94

optional :is_nsfw, ContextDev::Internal::Type::Boolean

Important website links for the brand



100
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 100

optional :links, -> { ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Links }

#logosArray<ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Logo>?

An array of logos associated with the brand



106
107
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 106

optional :logos,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Logo] }

#phoneString?

Company phone number

Returns:

  • (String, nil)


113
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 113

optional :phone, String

#primary_languageSymbol, ...

The primary language of the brand’s website content. Detected from the HTML lang tag, page content analysis, or social media descriptions.



120
121
122
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 120

optional :primary_language,
enum: -> { ContextDev::Models::BrandRetrieveByEmailResponse::Brand::PrimaryLanguage },
nil?: true

#sloganString?

The brand’s slogan

Returns:

  • (String, nil)


128
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 128

optional :slogan, String

#socialsArray<ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Social>?

An array of social media links for the brand



134
135
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 134

optional :socials,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Social] }

#stockContextDev::Models::BrandRetrieveByEmailResponse::Brand::Stock?

Stock market information for this brand (will be null if not a publicly traded company)



142
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 142

optional :stock, -> { ContextDev::Models::BrandRetrieveByEmailResponse::Brand::Stock }

#titleString?

The title or name of the brand

Returns:

  • (String, nil)


148
# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 148

optional :title, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/brand_retrieve_by_email_response.rb', line 642