Class: ContextDev::Models::BrandRetrieveByIsinParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveByIsinParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/brand_retrieve_by_isin_params.rb
Overview
Defined Under Namespace
Modules: ForceLanguage
Instance Attribute Summary collapse
-
#force_language ⇒ Symbol, ...
Optional parameter to force the language of the retrieved brand data.
-
#isin ⇒ String
ISIN (International Securities Identification Number) to retrieve brand data for (e.g., ‘AU000000IMD5’, ‘US0378331005’).
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(isin:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandRetrieveByIsinParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(isin:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveByIsinParams for more details.
|
|
# File 'lib/context_dev/models/brand_retrieve_by_isin_params.rb', line 40
|
Instance Attribute Details
#force_language ⇒ Symbol, ...
Optional parameter to force the language of the retrieved brand data.
22 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_params.rb', line 22 optional :force_language, enum: -> { ContextDev::BrandRetrieveByIsinParams::ForceLanguage } |
#isin ⇒ String
ISIN (International Securities Identification Number) to retrieve brand data for (e.g., ‘AU000000IMD5’, ‘US0378331005’). Must be exactly 12 characters: 2 letters followed by 9 alphanumeric characters and ending with a digit.
16 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_params.rb', line 16 required :isin, String |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
30 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_params.rb', line 30 optional :max_speed, ContextDev::Internal::Type::Boolean |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
38 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_params.rb', line 38 optional :timeout_ms, Integer |