Class: ContextDev::Models::BrandRetrieveByIsinResponse::Brand::Links
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveByIsinResponse::Brand::Links
- Defined in:
- lib/context_dev/models/brand_retrieve_by_isin_response.rb
Overview
Instance Attribute Summary collapse
-
#blog ⇒ String?
URL to the brand’s blog or news page.
-
#careers ⇒ String?
URL to the brand’s careers or job opportunities page.
-
#contact ⇒ String?
URL to the brand’s contact or contact us page.
-
#pricing ⇒ String?
URL to the brand’s pricing or plans page.
-
#privacy ⇒ String?
URL to the brand’s privacy policy page.
-
#terms ⇒ String?
URL to the brand’s terms of service or terms and conditions page.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ContextDev::Internal::Type::BaseModel
Instance Attribute Details
#blog ⇒ String?
URL to the brand’s blog or news page
642 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_response.rb', line 642 optional :blog, String, nil?: true |
#careers ⇒ String?
URL to the brand’s careers or job opportunities page
648 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_response.rb', line 648 optional :careers, String, nil?: true |
#contact ⇒ String?
URL to the brand’s contact or contact us page
654 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_response.rb', line 654 optional :contact, String, nil?: true |
#pricing ⇒ String?
URL to the brand’s pricing or plans page
660 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_response.rb', line 660 optional :pricing, String, nil?: true |
#privacy ⇒ String?
URL to the brand’s privacy policy page
666 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_response.rb', line 666 optional :privacy, String, nil?: true |
#terms ⇒ String?
URL to the brand’s terms of service or terms and conditions page
672 |
# File 'lib/context_dev/models/brand_retrieve_by_isin_response.rb', line 672 optional :terms, String, nil?: true |