Class: ContextDev::Models::BrandRetrieveByNameResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_retrieve_by_name_response.rb

Overview

Defined Under Namespace

Classes: Brand, KeyMetadata

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(exchange: nil, ticker: nil) ⇒ Object

Stock market information for this brand (will be null if not a publicly traded company)

Parameters:

  • exchange (String) (defaults to: nil)

    Stock exchange name

  • ticker (String) (defaults to: nil)

    Stock ticker symbol



# File 'lib/context_dev/models/brand_retrieve_by_name_response.rb', line 32

Instance Attribute Details

#brandContextDev::Models::BrandRetrieveByNameResponse::Brand?

Detailed brand information



11
# File 'lib/context_dev/models/brand_retrieve_by_name_response.rb', line 11

optional :brand, -> { ContextDev::Models::BrandRetrieveByNameResponse::Brand }

#codeInteger?

HTTP status code

Returns:

  • (Integer, nil)


17
# File 'lib/context_dev/models/brand_retrieve_by_name_response.rb', line 17

optional :code, Integer

#key_metadataContextDev::Models::BrandRetrieveByNameResponse::KeyMetadata?

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.



24
# File 'lib/context_dev/models/brand_retrieve_by_name_response.rb', line 24

optional :key_metadata, -> { ContextDev::Models::BrandRetrieveByNameResponse::KeyMetadata }

#statusString?

Status of the response, e.g., ‘ok’

Returns:

  • (String, nil)


30
# File 'lib/context_dev/models/brand_retrieve_by_name_response.rb', line 30

optional :status, String