Class: ContextDev::Models::BrandRetrieveByTickerParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/brand_retrieve_by_ticker_params.rb

Overview

Defined Under Namespace

Modules: ForceLanguage, TickerExchange

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ticker:, force_language: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveByTickerParams for more details.

Parameters:

  • ticker (String)

    Stock ticker symbol to retrieve brand data for (e.g., ‘AAPL’, ‘GOOGL’, ‘BRK.A’).

  • force_language (Symbol, ContextDev::Models::BrandRetrieveByTickerParams::ForceLanguage) (defaults to: nil)

    Optional parameter to force the language of the retrieved brand data.

  • max_speed (Boolean) (defaults to: nil)

    Optional parameter to optimize the API call for maximum speed. When set to true,

  • ticker_exchange (Symbol, ContextDev::Models::BrandRetrieveByTickerParams::TickerExchange) (defaults to: nil)

    Optional stock exchange for the ticker. Defaults to NASDAQ if not specified.

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 45

Instance Attribute Details

#force_languageSymbol, ...

Optional parameter to force the language of the retrieved brand data.



21
# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 21

optional :force_language, enum: -> { ContextDev::BrandRetrieveByTickerParams::ForceLanguage }

#max_speedBoolean?

Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.

Returns:

  • (Boolean, nil)


29
# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 29

optional :max_speed, ContextDev::Internal::Type::Boolean

#tickerString

Stock ticker symbol to retrieve brand data for (e.g., ‘AAPL’, ‘GOOGL’, ‘BRK.A’). Must be 1-15 characters, letters/numbers/dots only.

Returns:

  • (String)


15
# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 15

required :ticker, String

#ticker_exchangeSymbol, ...

Optional stock exchange for the ticker. Defaults to NASDAQ if not specified.



35
# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 35

optional :ticker_exchange, enum: -> { ContextDev::BrandRetrieveByTickerParams::TickerExchange }

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Returns:

  • (Integer, nil)


43
# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 43

optional :timeout_ms, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/brand_retrieve_by_ticker_params.rb', line 186