Class: ContextDev::Models::BrandRetrieveByTickerResponse::Brand
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveByTickerResponse::Brand
- Defined in:
- lib/context_dev/models/brand_retrieve_by_ticker_response.rb
Overview
Defined Under Namespace
Modules: PrimaryLanguage Classes: Address, Backdrop, Color, Industries, Links, Logo, Social, Stock
Instance Attribute Summary collapse
-
#address ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Address?
Physical address of the brand.
-
#backdrops ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Backdrop>?
An array of backdrop images for the brand.
-
#colors ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Color>?
An array of brand colors.
-
#description ⇒ String?
A brief description of the brand.
-
#domain ⇒ String?
The domain name of the brand.
-
#email ⇒ String?
Company email address.
-
#industries ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Industries?
Industry classification information for the brand.
-
#is_nsfw ⇒ Boolean?
Indicates whether the brand content is not safe for work (NSFW).
-
#links ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Links?
Important website links for the brand.
-
#logos ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Logo>?
An array of logos associated with the brand.
-
#phone ⇒ String?
Company phone number.
-
#primary_language ⇒ Symbol, ...
The primary language of the brand’s website content.
-
#slogan ⇒ String?
The brand’s slogan.
-
#socials ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Social>?
An array of social media links for the brand.
-
#stock ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock?
Stock market information for this brand (will be null if not a publicly traded company).
-
#title ⇒ String?
The title or name of the brand.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(blog: nil, careers: nil, contact: nil, pricing: nil, privacy: nil, terms: nil) ⇒ Object
constructor
Important website links for the brand.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(blog: nil, careers: nil, contact: nil, pricing: nil, privacy: nil, terms: nil) ⇒ Object
Important website links for the brand
|
|
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 150
|
Instance Attribute Details
#address ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Address?
Physical address of the brand
50 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 50 optional :address, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Address } |
#backdrops ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Backdrop>?
An array of backdrop images for the brand
56 57 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 56 optional :backdrops, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Backdrop] } |
#colors ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Color>?
An array of brand colors
63 64 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 63 optional :colors, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Color] } |
#description ⇒ String?
A brief description of the brand
70 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 70 optional :description, String |
#domain ⇒ String?
The domain name of the brand
76 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 76 optional :domain, String |
#email ⇒ String?
Company email address
82 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 82 optional :email, String |
#industries ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Industries?
Industry classification information for the brand
88 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 88 optional :industries, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Industries } |
#is_nsfw ⇒ Boolean?
Indicates whether the brand content is not safe for work (NSFW)
94 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 94 optional :is_nsfw, ContextDev::Internal::Type::Boolean |
#links ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Links?
Important website links for the brand
100 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 100 optional :links, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Links } |
#logos ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Logo>?
An array of logos associated with the brand
106 107 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 106 optional :logos, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Logo] } |
#phone ⇒ String?
Company phone number
113 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 113 optional :phone, String |
#primary_language ⇒ Symbol, ...
The primary language of the brand’s website content. Detected from the HTML lang tag, page content analysis, or social media descriptions.
120 121 122 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 120 optional :primary_language, enum: -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::PrimaryLanguage }, nil?: true |
#slogan ⇒ String?
The brand’s slogan
128 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 128 optional :slogan, String |
#socials ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Social>?
An array of social media links for the brand
134 135 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 134 optional :socials, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Social] } |
#stock ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock?
Stock market information for this brand (will be null if not a publicly traded company)
142 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 142 optional :stock, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock } |
#title ⇒ String?
The title or name of the brand
148 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 148 optional :title, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 643
|