Class: ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock
- Defined in:
- lib/context_dev/models/brand_retrieve_by_ticker_response.rb
Overview
Instance Attribute Summary collapse
-
#exchange ⇒ String?
Stock exchange name.
-
#ticker ⇒ String?
Stock ticker symbol.
Instance Method Summary collapse
-
#initialize(exchange: nil, ticker: nil) ⇒ Object
constructor
Stock market information for this brand (will be null if not a publicly traded company).
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exchange: nil, ticker: nil) ⇒ Object
Stock market information for this brand (will be null if not a publicly traded company)
|
|
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 1026
|
Instance Attribute Details
#exchange ⇒ String?
Stock exchange name
1018 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 1018 optional :exchange, String |
#ticker ⇒ String?
Stock ticker symbol
1024 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 1024 optional :ticker, String |