Class: ContextDev::Models::BrandRetrieveParams::Body::ByName

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs

Defined Under Namespace

Modules: ForceLanguage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, country_gl: nil, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, type: :by_name) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByName for more details.

Retrieve brand data by company name. Cannot be combined with domain, email, or ticker.

Parameters:

  • name (String)

    Company name to retrieve brand data for (e.g., 'Apple Inc').

  • country_gl (String) (defaults to: nil)

    Optional country code hint (GL parameter) to specify the country when looking up

  • force_language (Symbol, ContextDev::Models::BrandRetrieveParams::Body::ByName::ForceLanguage) (defaults to: nil)
  • max_age_ms (Integer) (defaults to: nil)

    Maximum age in milliseconds for cached brand data before the API performs a hard

  • max_speed (Boolean) (defaults to: nil)

    Optional parameter to optimize the API call for maximum speed. When set to true,

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • type (Symbol, :by_name) (defaults to: :by_name)

    Discriminator for name-based brand retrieval.



# File 'lib/context_dev/models/brand_retrieve_params.rb', line 283

Instance Attribute Details

#country_glString?

Optional country code hint (GL parameter) to specify the country when looking up by company name.

Parameters:

  • (String)

Returns:

  • (String, nil)


251
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 251

optional :country_gl, String

#force_languageSymbol, ...



256
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 256

optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByName::ForceLanguage }

#max_age_msInteger?

Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


265
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 265

optional :max_age_ms, Integer, api_name: :maxAgeMs

#max_speedBoolean?

Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


273
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 273

optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed

#nameString

Company name to retrieve brand data for (e.g., 'Apple Inc').

Parameters:

  • value (String)

Returns:

  • (String)


238
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 238

required :name, String

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


281
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 281

optional :timeout_ms, Integer, api_name: :timeoutMS

#typeSymbol, :by_name

Discriminator for name-based brand retrieval.

Parameters:

  • value (:by_name)

Returns:

  • (Symbol, :by_name)


244
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 244

required :type, const: :by_name

Instance Method Details

#to_hash{

Returns:

  • ({)


382
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 382

def to_hash: -> {