Class: ContextDev::Models::BrandRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveResponse
- Defined in:
- lib/context_dev/models/brand_retrieve_response.rb,
sig/context_dev/models/brand_retrieve_response.rbs
Overview
Defined Under Namespace
Classes: Brand, CacheMetadata, KeyMetadata
Instance Attribute Summary collapse
-
#brand ⇒ ContextDev::Models::BrandRetrieveResponse::Brand?
Detailed brand information.
-
#cache_metadata ⇒ ContextDev::Models::BrandRetrieveResponse::CacheMetadata
Cache outcome for this response.
-
#code ⇒ Integer?
HTTP status code.
-
#key_metadata ⇒ ContextDev::Models::BrandRetrieveResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#status ⇒ String?
Status of the response, e.g., 'ok'.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(exchange: nil, ticker: nil) ⇒ Object
constructor
Stock market information for this brand (will be null if not a publicly traded company).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exchange: nil, ticker: nil) ⇒ Object
Stock market information for this brand (will be null if not a publicly traded company)
|
|
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 40
|
Instance Attribute Details
#brand ⇒ ContextDev::Models::BrandRetrieveResponse::Brand?
Detailed brand information
19 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 19 optional :brand, -> { ContextDev::Models::BrandRetrieveResponse::Brand } |
#cache_metadata ⇒ ContextDev::Models::BrandRetrieveResponse::CacheMetadata
Cache outcome for this response. Composite responses are hits only when every cache-controlled fetch contributing to the output was a hit; age_ms is the oldest contributing hit.
13 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 13 required :cache_metadata, -> { ContextDev::Models::BrandRetrieveResponse::CacheMetadata } |
#code ⇒ Integer?
HTTP status code
25 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 25 optional :code, Integer |
#key_metadata ⇒ ContextDev::Models::BrandRetrieveResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
32 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 32 optional :key_metadata, -> { ContextDev::Models::BrandRetrieveResponse::KeyMetadata } |
#status ⇒ String?
Status of the response, e.g., 'ok'
38 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 38 optional :status, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 92
|
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/context_dev/models/brand_retrieve_response.rbs', line 43
def to_hash: -> {
|