Class: ContextDev::Models::BrandRetrieveResponse::Brand

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: PrimaryLanguage Classes: Address, Backdrop, Color, Industries, Links, Logo, Social, Stock

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(blog: nil, careers: nil, contact: nil, pricing: nil, privacy: nil, terms: nil) ⇒ Object

Important website links for the brand

Parameters:

  • blog (String, nil) (defaults to: nil)

    URL to the brand’s blog or news page

  • careers (String, nil) (defaults to: nil)

    URL to the brand’s careers or job opportunities page

  • contact (String, nil) (defaults to: nil)

    URL to the brand’s contact or contact us page

  • pricing (String, nil) (defaults to: nil)

    URL to the brand’s pricing or plans page

  • privacy (String, nil) (defaults to: nil)

    URL to the brand’s privacy policy page

  • terms (String, nil) (defaults to: nil)

    URL to the brand’s terms of service or terms and conditions page



# File 'lib/context_dev/models/brand_retrieve_response.rb', line 138

Instance Attribute Details

#addressContextDev::Models::BrandRetrieveResponse::Brand::Address?

Physical address of the brand



38
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 38

optional :address, -> { ContextDev::Models::BrandRetrieveResponse::Brand::Address }

#backdropsArray<ContextDev::Models::BrandRetrieveResponse::Brand::Backdrop>?

An array of backdrop images for the brand



44
45
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 44

optional :backdrops,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveResponse::Brand::Backdrop] }

#colorsArray<ContextDev::Models::BrandRetrieveResponse::Brand::Color>?

An array of brand colors



51
52
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 51

optional :colors,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveResponse::Brand::Color] }

#descriptionString?

A brief description of the brand

Returns:

  • (String, nil)


58
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 58

optional :description, String

#domainString?

The domain name of the brand

Returns:

  • (String, nil)


64
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 64

optional :domain, String

#emailString?

Company email address

Returns:

  • (String, nil)


70
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 70

optional :email, String

#industriesContextDev::Models::BrandRetrieveResponse::Brand::Industries?

Industry classification information for the brand



76
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 76

optional :industries, -> { ContextDev::Models::BrandRetrieveResponse::Brand::Industries }

#is_nsfwBoolean?

Indicates whether the brand content is not safe for work (NSFW)

Returns:

  • (Boolean, nil)


82
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 82

optional :is_nsfw, ContextDev::Internal::Type::Boolean

Important website links for the brand



88
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 88

optional :links, -> { ContextDev::Models::BrandRetrieveResponse::Brand::Links }

#logosArray<ContextDev::Models::BrandRetrieveResponse::Brand::Logo>?

An array of logos associated with the brand



94
95
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 94

optional :logos,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveResponse::Brand::Logo] }

#phoneString?

Company phone number

Returns:

  • (String, nil)


101
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 101

optional :phone, String

#primary_languageSymbol, ...

The primary language of the brand’s website content. Detected from the HTML lang tag, page content analysis, or social media descriptions.



108
109
110
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 108

optional :primary_language,
enum: -> { ContextDev::Models::BrandRetrieveResponse::Brand::PrimaryLanguage },
nil?: true

#sloganString?

The brand’s slogan

Returns:

  • (String, nil)


116
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 116

optional :slogan, String

#socialsArray<ContextDev::Models::BrandRetrieveResponse::Brand::Social>?

An array of social media links for the brand



122
123
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 122

optional :socials,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveResponse::Brand::Social] }

#stockContextDev::Models::BrandRetrieveResponse::Brand::Stock?

Stock market information for this brand (will be null if not a publicly traded company)



130
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 130

optional :stock, -> { ContextDev::Models::BrandRetrieveResponse::Brand::Stock }

#titleString?

The title or name of the brand

Returns:

  • (String, nil)


136
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 136

optional :title, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/brand_retrieve_response.rb', line 630