Class: ContextDev::Models::BrandRetrieveResponse::Brand::Employees
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveResponse::Brand::Employees
- Defined in:
- lib/context_dev/models/brand_retrieve_response.rb,
sig/context_dev/models/brand_retrieve_response.rbs
Overview
Defined Under Namespace
Modules: Range
Instance Attribute Summary collapse
-
#exact ⇒ Integer?
Exact employee count when a precise headcount is known.
-
#range ⇒ Symbol, ...
Employee count range for the brand (e.g. '11 to 50').
Instance Method Summary collapse
-
#initialize(exact: nil, range: nil) ⇒ Object
constructor
Employee headcount information for the brand (will be null if unknown).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exact: nil, range: nil) ⇒ Object
Employee headcount information for the brand (will be null if unknown)
|
|
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 367
|
Instance Attribute Details
#exact ⇒ Integer?
Exact employee count when a precise headcount is known
359 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 359 optional :exact, Integer |
#range ⇒ Symbol, ...
Employee count range for the brand (e.g. '11 to 50')
365 |
# File 'lib/context_dev/models/brand_retrieve_response.rb', line 365 optional :range, enum: -> { ContextDev::Models::BrandRetrieveResponse::Brand::Employees::Range } |
Instance Method Details
#to_hash ⇒ {
373 |
# File 'sig/context_dev/models/brand_retrieve_response.rbs', line 373
def to_hash: -> {
|