Module: ContextDev::Models::BrandSearchParams::QueryBy

Extended by:
Internal::Type::Enum
Defined in:
lib/context_dev/models/brand_search_params.rb,
sig/context_dev/models/brand_search_params.rbs

Constant Summary collapse

NAME =

Returns:

  • (:name)
:name
DOMAIN =

Returns:

  • (:domain)
:domain

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/brand_search_params.rb', line 69

Instance Method Details

#initialize(query:, autocomplete: nil, query_by: nil, tags: nil, typo_tolerance: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BrandSearchParams for more details.

Parameters:

  • query (String)

    Search term, matched against the fields selected by queryBy (e.g. 'nike', 'nike.

  • autocomplete (Boolean) (defaults to: nil)

    Whether the search term matches by prefix, so partial words match as they are ty

  • query_by (Array<Symbol, ContextDev::Models::BrandSearchParams::QueryBy>) (defaults to: nil)

    Fields to match the search term against, as a comma-separated list or repeated p

  • tags (Array<String>) (defaults to: nil)

    Optional comma-separated caller-defined tags for tracking this request. Tags are

  • typo_tolerance (Integer) (defaults to: nil)

    Maximum number of typos tolerated when matching, from 0 to 2. Defaults to 0 (no

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


63
64
65
66
67
68
69
70
71
# File 'lib/context_dev/models/brand_search_params.rb', line 63

module QueryBy
  extend ContextDev::Internal::Type::Enum

  NAME = :name
  DOMAIN = :domain

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[ContextDev::Models::BrandSearchParams::query_by]

Returns:

  • (::Array[ContextDev::Models::BrandSearchParams::query_by])


63
# File 'sig/context_dev/models/brand_search_params.rbs', line 63

def self?.values: -> ::Array[ContextDev::Models::BrandSearchParams::query_by]