Class: ContextDev::Models::BrandSearchResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_search_response.rb,
sig/context_dev/models/brand_search_response.rbs

Overview

See Also:

  • ContextDev::Resources::Brand#search

Defined Under Namespace

Classes: KeyMetadata, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(domain:, logo:, name:) ⇒ Object

Some parameter documentations has been truncated, see Result for more details.

Parameters:

  • domain (String)

    The brand's domain.

  • logo (String)

    Logo link URL that serves the brand's logo, generated per request for the callin

  • name (String)

    The brand's name. Empty string when unknown.



# File 'lib/context_dev/models/brand_search_response.rb', line 49

Instance Attribute Details

#key_metadataContextDev::Models::BrandSearchResponse::KeyMetadata?

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.



19
# File 'lib/context_dev/models/brand_search_response.rb', line 19

optional :key_metadata, -> { ContextDev::Models::BrandSearchResponse::KeyMetadata }

#resultsArray<ContextDev::Models::BrandSearchResponse::Result>

Up to 10 matching brands, most popular first. Empty when nothing matches.



11
12
# File 'lib/context_dev/models/brand_search_response.rb', line 11

required :results,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandSearchResponse::Result] }

Instance Method Details

#to_hash{

Returns:

  • ({)


23
# File 'sig/context_dev/models/brand_search_response.rbs', line 23

def to_hash: -> {