Class: ContextDev::Models::IndustryRetrieveNaicsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/industry_retrieve_naics_response.rb

Overview

Defined Under Namespace

Classes: Code, KeyMetadata

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from ContextDev::Internal::Type::BaseModel

Instance Attribute Details

#codesArray<ContextDev::Models::IndustryRetrieveNaicsResponse::Code>?

Array of NAICS codes and titles.



11
12
# File 'lib/context_dev/models/industry_retrieve_naics_response.rb', line 11

optional :codes,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::IndustryRetrieveNaicsResponse::Code] }

#domainString?

Domain found for the brand

Returns:

  • (String, nil)


18
# File 'lib/context_dev/models/industry_retrieve_naics_response.rb', line 18

optional :domain, String

#key_metadataContextDev::Models::IndustryRetrieveNaicsResponse::KeyMetadata?

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.



25
# File 'lib/context_dev/models/industry_retrieve_naics_response.rb', line 25

optional :key_metadata, -> { ContextDev::Models::IndustryRetrieveNaicsResponse::KeyMetadata }

#statusString?

Status of the response, e.g., ‘ok’

Returns:

  • (String, nil)


31
# File 'lib/context_dev/models/industry_retrieve_naics_response.rb', line 31

optional :status, String

#typeString?

Industry classification type, for naics api it will be ‘naics`

Returns:

  • (String, nil)


37
# File 'lib/context_dev/models/industry_retrieve_naics_response.rb', line 37

optional :type, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/industry_retrieve_naics_response.rb', line 89