Class: ContextDev::Models::IndustryRetrieveSicResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/industry_retrieve_sic_response.rb

Overview

Defined Under Namespace

Modules: Classification Classes: Code

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(classification: nil, codes: nil, domain: nil, status: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::IndustryRetrieveSicResponse for more details.

Parameters:

  • classification (Symbol, ContextDev::Models::IndustryRetrieveSicResponse::Classification) (defaults to: nil)

    Echoes back which SIC dataset was used to classify the brand.

  • codes (Array<ContextDev::Models::IndustryRetrieveSicResponse::Code>) (defaults to: nil)

    Array of SIC codes with confidence scores. Extra fields depend on the requested

  • domain (String) (defaults to: nil)

    Domain found for the brand

  • status (String) (defaults to: nil)

    Status of the response, e.g., ‘ok’

  • type (String) (defaults to: nil)

    Industry classification type, for sic api it will be ‘sic`



# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 40

Instance Attribute Details

#classificationSymbol, ...

Echoes back which SIC dataset was used to classify the brand.



11
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 11

optional :classification, enum: -> { ContextDev::Models::IndustryRetrieveSicResponse::Classification }

#codesArray<ContextDev::Models::IndustryRetrieveSicResponse::Code>?

Array of SIC codes with confidence scores. Extra fields depend on the requested classification: ‘original_sic` results include `majorGroup` and `majorGroupName`; `latest_sec` results include `office`.



19
20
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 19

optional :codes,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::IndustryRetrieveSicResponse::Code] }

#domainString?

Domain found for the brand

Returns:

  • (String, nil)


26
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 26

optional :domain, String

#statusString?

Status of the response, e.g., ‘ok’

Returns:

  • (String, nil)


32
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 32

optional :status, String

#typeString?

Industry classification type, for sic api it will be ‘sic`

Returns:

  • (String, nil)


38
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 38

optional :type, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 63