Class: ContextDev::Models::IndustryRetrieveSicResponse::Code

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/industry_retrieve_sic_response.rb

Defined Under Namespace

Modules: Confidence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code:, confidence:, name:, major_group: nil, major_group_name: nil, office: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::IndustryRetrieveSicResponse::Code for more details.

Parameters:

  • code (String)

    SIC code (4-digit).

  • confidence (Symbol, ContextDev::Models::IndustryRetrieveSicResponse::Code::Confidence)

    Confidence level for how well this SIC code matches the company description.

  • name (String)

    SIC industry title.

  • major_group (String) (defaults to: nil)

    2-digit major group identifier (the leading two digits of the code). Only presen

  • major_group_name (String) (defaults to: nil)

    Description of the 2-digit major group. Only present when ‘classification` is `o

  • office (String) (defaults to: nil)

    SEC review office responsible for filings under this code. Only present when ‘cl



# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 107

Instance Attribute Details

#codeString

SIC code (4-digit).

Returns:

  • (String)


72
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 72

required :code, String

#confidenceSymbol, ContextDev::Models::IndustryRetrieveSicResponse::Code::Confidence

Confidence level for how well this SIC code matches the company description.



78
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 78

required :confidence, enum: -> { ContextDev::Models::IndustryRetrieveSicResponse::Code::Confidence }

#major_groupString?

2-digit major group identifier (the leading two digits of the code). Only present when ‘classification` is `original_sic`.

Returns:

  • (String, nil)


91
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 91

optional :major_group, String, api_name: :majorGroup

#major_group_nameString?

Description of the 2-digit major group. Only present when ‘classification` is `original_sic`.

Returns:

  • (String, nil)


98
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 98

optional :major_group_name, String, api_name: :majorGroupName

#nameString

SIC industry title.

Returns:

  • (String)


84
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 84

required :name, String

#officeString?

SEC review office responsible for filings under this code. Only present when ‘classification` is `latest_sec`.

Returns:

  • (String, nil)


105
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 105

optional :office, String