Class: ContextDev::Models::MonitorGetCreditUsageResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/monitor_get_credit_usage_response.rb,
sig/context_dev/models/monitor_get_credit_usage_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credits:, monitor_id:, name:, runs:) ⇒ Object

Parameters:

  • credits (Integer)

    Credits charged to this monitor over the window.

  • monitor_id (String)
  • name (String)

    Monitor name (falls back to the id when the monitor was deleted).

  • runs (Integer)

    Number of billed runs over the window.



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/context_dev/models/monitor_get_credit_usage_response.rb', line 24

class Data < ContextDev::Internal::Type::BaseModel
  # @!attribute credits
  #   Credits charged to this monitor over the window.
  #
  #   @return [Integer]
  required :credits, Integer

  # @!attribute monitor_id
  #
  #   @return [String]
  required :monitor_id, String

  # @!attribute name
  #   Monitor name (falls back to the id when the monitor was deleted).
  #
  #   @return [String]
  required :name, String

  # @!attribute runs
  #   Number of billed runs over the window.
  #
  #   @return [Integer]
  required :runs, Integer

  # @!method initialize(credits:, monitor_id:, name:, runs:)
  #   @param credits [Integer] Credits charged to this monitor over the window.
  #
  #   @param monitor_id [String]
  #
  #   @param name [String] Monitor name (falls back to the id when the monitor was deleted).
  #
  #   @param runs [Integer] Number of billed runs over the window.
end

Instance Attribute Details

#creditsInteger

Credits charged to this monitor over the window.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


29
# File 'lib/context_dev/models/monitor_get_credit_usage_response.rb', line 29

required :credits, Integer

#monitor_idString

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/context_dev/models/monitor_get_credit_usage_response.rb', line 34

required :monitor_id, String

#nameString

Monitor name (falls back to the id when the monitor was deleted).

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/context_dev/models/monitor_get_credit_usage_response.rb', line 40

required :name, String

#runsInteger

Number of billed runs over the window.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


46
# File 'lib/context_dev/models/monitor_get_credit_usage_response.rb', line 46

required :runs, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/context_dev/models/monitor_get_credit_usage_response.rbs', line 43

def to_hash: -> {