Class: ContextDev::Models::MonitorListAccountChangesParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/monitor_list_account_changes_params.rb,
sig/context_dev/models/monitor_list_account_changes_params.rbs

Overview

See Also:

  • ContextDev::Resources::Monitors#list_account_changes

Defined Under Namespace

Modules: ChangeDetectionType, TargetType

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(change_detection_type: nil, cursor: nil, limit: nil, monitor_id: nil, since: nil, tag: nil, target_type: nil, until_: nil, request_options: {}) ⇒ Object

Parameters:

  • change_detection_type (Symbol, ContextDev::Models::MonitorListAccountChangesParams::ChangeDetectionType) (defaults to: nil)

    Filter by change detection type.

  • cursor (String) (defaults to: nil)

    Opaque pagination cursor from a previous response.

  • limit (Integer) (defaults to: nil)

    Maximum number of items to return per page (1-100). Defaults to 25.

  • monitor_id (String) (defaults to: nil)

    Filter changes to a single monitor.

  • since (Time) (defaults to: nil)

    Only include items at or after this ISO 8601 timestamp.

  • tag (String) (defaults to: nil)

    Filter to items that have this tag.

  • target_type (Symbol, ContextDev::Models::MonitorListAccountChangesParams::TargetType) (defaults to: nil)

    Filter by target type.

  • until_ (Time) (defaults to: nil)

    Only include items before this ISO 8601 timestamp.

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 59

Instance Attribute Details

#change_detection_typeSymbol, ...

Filter by change detection type.



14
15
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 14

optional :change_detection_type,
enum: -> { ContextDev::MonitorListAccountChangesParams::ChangeDetectionType }

#cursorString?

Opaque pagination cursor from a previous response.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 21

optional :cursor, String

#limitInteger?

Maximum number of items to return per page (1-100). Defaults to 25.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


27
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 27

optional :limit, Integer

#monitor_idString?

Filter changes to a single monitor.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 33

optional :monitor_id, String

#sinceTime?

Only include items at or after this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


39
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 39

optional :since, Time

#tagString?

Filter to items that have this tag.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 45

optional :tag, String

#target_typeSymbol, ...

Filter by target type.



51
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 51

optional :target_type, enum: -> { ContextDev::MonitorListAccountChangesParams::TargetType }

#until_Time?

Only include items before this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


57
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 57

optional :until_, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 85

Instance Method Details

#to_hash{

Returns:

  • ({)


68
# File 'sig/context_dev/models/monitor_list_account_changes_params.rbs', line 68

def to_hash: -> {