Class: ContextDev::Models::MonitorListAccountChangesResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/monitor_list_account_changes_response.rb,
sig/context_dev/models/monitor_list_account_changes_response.rbs

Defined Under Namespace

Modules: ChangeDetectionType, Importance, Mode, TargetType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, change_detection_type:, detected_at:, mode:, monitor_id:, summary:, target_type:, title:, url:, added_url_count: nil, confidence: nil, importance: nil, matched_url_count: nil, removed_url_count: nil, tags: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::MonitorListAccountChangesResponse::Data for more details.

A lightweight change summary. mode is the constant web; target_type and change_detection_type describe the change, and which optional fields are present depends on them (e.g. sitemap changes include added_url_count/removed_url_count; semantic changes include confidence/importance).

Parameters:



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 28

class Data < ContextDev::Internal::Type::BaseModel
  # @!attribute id
  #
  #   @return [String]
  required :id, String

  # @!attribute change_detection_type
  #
  #   @return [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType]
  required :change_detection_type,
           enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType }

  # @!attribute detected_at
  #
  #   @return [Time]
  required :detected_at, Time

  # @!attribute mode
  #   Top-level monitor category. Always `web` today; the concrete behavior is
  #   described by `target` and `change_detection`.
  #
  #   @return [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode]
  required :mode, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode }

  # @!attribute monitor_id
  #
  #   @return [String]
  required :monitor_id, String

  # @!attribute summary
  #
  #   @return [String]
  required :summary, String

  # @!attribute target_type
  #
  #   @return [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType]
  required :target_type,
           enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType }

  # @!attribute title
  #
  #   @return [String]
  required :title, String

  # @!attribute url
  #
  #   @return [String]
  required :url, String

  # @!attribute added_url_count
  #
  #   @return [Integer, nil]
  optional :added_url_count, Integer

  # @!attribute confidence
  #
  #   @return [Float, nil]
  optional :confidence, Float

  # @!attribute importance
  #
  #   @return [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::Importance, nil]
  optional :importance, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Importance }

  # @!attribute matched_url_count
  #
  #   @return [Integer, nil]
  optional :matched_url_count, Integer

  # @!attribute removed_url_count
  #
  #   @return [Integer, nil]
  optional :removed_url_count, Integer

  # @!attribute tags
  #   User-defined tags for grouping and filtering monitors and their changes.
  #
  #   @return [Array<String>, nil]
  optional :tags, ContextDev::Internal::Type::ArrayOf[String]

  # @!method initialize(id:, change_detection_type:, detected_at:, mode:, monitor_id:, summary:, target_type:, title:, url:, added_url_count: nil, confidence: nil, importance: nil, matched_url_count: nil, removed_url_count: nil, tags: nil)
  #   Some parameter documentations has been truncated, see
  #   {ContextDev::Models::MonitorListAccountChangesResponse::Data} for more details.
  #
  #   A lightweight change summary. `mode` is the constant `web`; `target_type` and
  #   `change_detection_type` describe the change, and which optional fields are
  #   present depends on them (e.g. sitemap changes include
  #   `added_url_count`/`removed_url_count`; semantic changes include
  #   `confidence`/`importance`).
  #
  #   @param id [String]
  #
  #   @param change_detection_type [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType]
  #
  #   @param detected_at [Time]
  #
  #   @param mode [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode] Top-level monitor category. Always `web` today; the concrete behavior is describ
  #
  #   @param monitor_id [String]
  #
  #   @param summary [String]
  #
  #   @param target_type [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType]
  #
  #   @param title [String]
  #
  #   @param url [String]
  #
  #   @param added_url_count [Integer]
  #
  #   @param confidence [Float]
  #
  #   @param importance [Symbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::Importance]
  #
  #   @param matched_url_count [Integer]
  #
  #   @param removed_url_count [Integer]
  #
  #   @param tags [Array<String>] User-defined tags for grouping and filtering monitors and their changes.

  # @see ContextDev::Models::MonitorListAccountChangesResponse::Data#change_detection_type
  module ChangeDetectionType
    extend ContextDev::Internal::Type::Enum

    EXACT = :exact
    SEMANTIC = :semantic

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # Top-level monitor category. Always `web` today; the concrete behavior is
  # described by `target` and `change_detection`.
  #
  # @see ContextDev::Models::MonitorListAccountChangesResponse::Data#mode
  module Mode
    extend ContextDev::Internal::Type::Enum

    WEB = :web

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see ContextDev::Models::MonitorListAccountChangesResponse::Data#target_type
  module TargetType
    extend ContextDev::Internal::Type::Enum

    PAGE = :page
    SITEMAP = :sitemap
    EXTRACT = :extract

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see ContextDev::Models::MonitorListAccountChangesResponse::Data#importance
  module Importance
    extend ContextDev::Internal::Type::Enum

    LOW = :low
    MEDIUM = :medium
    HIGH = :high

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#added_url_countInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


81
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 81

optional :added_url_count, Integer

#change_detection_typeSymbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType

Parameters:

  • value (ContextDev::Models::MonitorListAccountChangesResponse::Data::change_detection_type)

Returns:



37
38
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 37

required :change_detection_type,
enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType }

#confidenceFloat?

Parameters:

  • (Float)

Returns:

  • (Float, nil)


86
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 86

optional :confidence, Float

#detected_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


43
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 43

required :detected_at, Time

#idString

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 32

required :id, String

#importanceSymbol, ...



91
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 91

optional :importance, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Importance }

#matched_url_countInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


96
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 96

optional :matched_url_count, Integer

#modeSymbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode

Top-level monitor category. Always web today; the concrete behavior is described by target and change_detection.

Parameters:

  • value (ContextDev::Models::MonitorListAccountChangesResponse::Data::mode)

Returns:



50
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 50

required :mode, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode }

#monitor_idString

Parameters:

  • value (String)

Returns:

  • (String)


55
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 55

required :monitor_id, String

#removed_url_countInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


101
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 101

optional :removed_url_count, Integer

#summaryString

Parameters:

  • value (String)

Returns:

  • (String)


60
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 60

required :summary, String

#tagsArray<String>?

User-defined tags for grouping and filtering monitors and their changes.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


107
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 107

optional :tags, ContextDev::Internal::Type::ArrayOf[String]

#target_typeSymbol, ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType

Parameters:

  • value (ContextDev::Models::MonitorListAccountChangesResponse::Data::target_type)

Returns:



65
66
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 65

required :target_type,
enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType }

#titleString

Parameters:

  • value (String)

Returns:

  • (String)


71
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 71

required :title, String

#urlString

Parameters:

  • value (String)

Returns:

  • (String)


76
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 76

required :url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 156

Instance Method Details

#to_hash{

Returns:

  • ({)


111
# File 'sig/context_dev/models/monitor_list_account_changes_response.rbs', line 111

def to_hash: -> {