Class: ContextDev::Models::MonitorListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/monitor_list_params.rb,
sig/context_dev/models/monitor_list_params.rbs

Overview

See Also:

  • ContextDev::Resources::Monitors#list

Defined Under Namespace

Modules: ChangeDetectionType, SearchBy, SearchType, Status, TargetType

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(change_detection_type: nil, cursor: nil, limit: nil, q: nil, search_by: nil, search_type: nil, status: nil, tag: nil, tags: nil, target_type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::MonitorListParams for more details.

Parameters:



# File 'lib/context_dev/models/monitor_list_params.rb', line 74

Instance Attribute Details

#change_detection_typeSymbol, ...

Filter by change detection type.



14
# File 'lib/context_dev/models/monitor_list_params.rb', line 14

optional :change_detection_type, enum: -> { ContextDev::MonitorListParams::ChangeDetectionType }

#cursorString?

Opaque pagination cursor from a previous response.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/context_dev/models/monitor_list_params.rb', line 20

optional :cursor, String

#limitInteger?

Maximum number of items to return per page (1-100). Defaults to 25.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/context_dev/models/monitor_list_params.rb', line 26

optional :limit, Integer

#qString?

Free-text search term, matched against the fields named in search_by.

Parameters:

  • (String)

Returns:

  • (String, nil)


32
# File 'lib/context_dev/models/monitor_list_params.rb', line 32

optional :q, String

#search_byArray<Symbol, ContextDev::Models::MonitorListParams::SearchBy>?

Comma-separated fields to search with q. Defaults to all of them. Note instructions only exists on extract monitors.

Parameters:

  • value (::Array[ContextDev::Models::MonitorListParams::search_by], nil)

Returns:



39
40
41
# File 'lib/context_dev/models/monitor_list_params.rb', line 39

optional :search_by,
-> { ContextDev::Internal::Type::ArrayOf[enum: ContextDev::MonitorListParams::SearchBy] },
nil?: true

#search_typeSymbol, ...

prefix for as-you-type prefix matching (default), exact for full-token matching.



48
# File 'lib/context_dev/models/monitor_list_params.rb', line 48

optional :search_type, enum: -> { ContextDev::MonitorListParams::SearchType }

#statusSymbol, ...

Filter monitors by lifecycle status.



54
# File 'lib/context_dev/models/monitor_list_params.rb', line 54

optional :status, enum: -> { ContextDev::MonitorListParams::Status }

#tagString?

Filter to items that have this tag.

Parameters:

  • (String)

Returns:

  • (String, nil)


60
# File 'lib/context_dev/models/monitor_list_params.rb', line 60

optional :tag, String

#tagsArray<String>?

Comma-separated list of tags to filter by (matches monitors having any of them).

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


66
# File 'lib/context_dev/models/monitor_list_params.rb', line 66

optional :tags, ContextDev::Internal::Type::ArrayOf[String], nil?: true

#target_typeSymbol, ...

Filter by target type.



72
# File 'lib/context_dev/models/monitor_list_params.rb', line 72

optional :target_type, enum: -> { ContextDev::MonitorListParams::TargetType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/monitor_list_params.rb', line 107

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/context_dev/models/monitor_list_params.rbs', line 80

def to_hash: -> {