Class: ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery
- Defined in:
- lib/context_dev/models/monitor_list_runs_response.rb,
sig/context_dev/models/monitor_list_runs_response.rbs
Overview
Defined Under Namespace
Modules: Status Classes: Error
Instance Attribute Summary collapse
- #attempted_at ⇒ Time
- #error ⇒ ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery::Error?
-
#event_id ⇒ String
Identifier sent in the X-Context-Id header.
-
#http_status ⇒ Integer?
The endpoint's final HTTP response status, or null when no response was received.
-
#status ⇒ Symbol, ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery::Status
Delivery outcome.
Instance Method Summary collapse
- #initialize(code:, message:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, message:) ⇒ Object
|
|
# File 'lib/context_dev/models/monitor_list_runs_response.rb', line 270
|
Instance Attribute Details
#attempted_at ⇒ Time
240 |
# File 'lib/context_dev/models/monitor_list_runs_response.rb', line 240 required :attempted_at, Time |
#error ⇒ ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery::Error?
245 246 247 |
# File 'lib/context_dev/models/monitor_list_runs_response.rb', line 245 required :error, -> { ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery::Error }, nil?: true |
#event_id ⇒ String
Identifier sent in the X-Context-Id header.
253 |
# File 'lib/context_dev/models/monitor_list_runs_response.rb', line 253 required :event_id, String |
#http_status ⇒ Integer?
The endpoint's final HTTP response status, or null when no response was received.
260 |
# File 'lib/context_dev/models/monitor_list_runs_response.rb', line 260 required :http_status, Integer, nil?: true |
#status ⇒ Symbol, ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery::Status
Delivery outcome. delivered means any 2xx response; rejected means a non-2xx response; failed means no HTTP response was received; skipped_unsafe_url means the URL failed the public-endpoint safety check.
268 |
# File 'lib/context_dev/models/monitor_list_runs_response.rb', line 268 required :status, enum: -> { ContextDev::Models::MonitorListRunsResponse::Data::WebhookDelivery::Status } |
Instance Method Details
#to_hash ⇒ {
219 |
# File 'sig/context_dev/models/monitor_list_runs_response.rbs', line 219
def to_hash: -> {
|