Class: ContextDev::Models::MonitorRetrieveChangeResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/monitor_retrieve_change_response.rb,
sig/context_dev/models/monitor_retrieve_change_response.rbs

Overview

See Also:

  • ContextDev::Resources::Monitors#retrieve_change

Defined Under Namespace

Modules: ChangeDetectionType, Importance, Mode, TargetType Classes: Evidence

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after:, before:, url: nil) ⇒ Object

Parameters:

  • after (String)

    Snapshot of the content after the change.

  • before (String)

    Snapshot of the content before the change.

  • url (String) (defaults to: nil)

    Optional URL the evidence relates to. Absent for whole-target diffs.



# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 137

Instance Attribute Details

#added_url_countInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


64
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 64

optional :added_url_count, Integer

#added_urlsArray<String>?

At most 500 URLs are included; the corresponding count field is always exact.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


70
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 70

optional :added_urls, ContextDev::Internal::Type::ArrayOf[String]

#after_text_excerptString?

Parameters:

  • (String)

Returns:

  • (String, nil)


75
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 75

optional :after_text_excerpt, String

#before_text_excerptString?

Parameters:

  • (String)

Returns:

  • (String, nil)


80
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 80

optional :before_text_excerpt, String

#change_detection_typeSymbol, ContextDev::Models::MonitorRetrieveChangeResponse::ChangeDetectionType

Parameters:

  • value (ContextDev::Models::MonitorRetrieveChangeResponse::change_detection_type)

Returns:



15
16
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 15

required :change_detection_type,
enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::ChangeDetectionType }

#confidenceFloat?

Parameters:

  • (Float)

Returns:

  • (Float, nil)


85
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 85

optional :confidence, Float

#detected_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


21
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 21

required :detected_at, Time

#diffString?

Text diff between the previous and current page baseline (page targets).

Parameters:

  • (String)

Returns:

  • (String, nil)


91
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 91

optional :diff, String

#evidenceArray<ContextDev::Models::MonitorRetrieveChangeResponse::Evidence>?



96
97
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 96

optional :evidence,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::MonitorRetrieveChangeResponse::Evidence] }

#idString

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 10

required :id, String

#importanceSymbol, ...



102
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 102

optional :importance, enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::Importance }

#matched_url_countInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


107
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 107

optional :matched_url_count, Integer

#matched_urlsArray<String>?

At most 500 URLs are included; the corresponding count field is always exact.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


113
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 113

optional :matched_urls, ContextDev::Internal::Type::ArrayOf[String]

#modeSymbol, ContextDev::Models::MonitorRetrieveChangeResponse::Mode

Top-level monitor category. Always web today; the concrete behavior is described by target and change_detection.

Parameters:

  • value (ContextDev::Models::MonitorRetrieveChangeResponse::mode)

Returns:



28
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 28

required :mode, enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::Mode }

#monitor_idString

Parameters:

  • value (String)

Returns:

  • (String)


33
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 33

required :monitor_id, String

#queryString?

Parameters:

  • (String)

Returns:

  • (String, nil)


118
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 118

optional :query, String

#removed_url_countInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


123
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 123

optional :removed_url_count, Integer

#removed_urlsArray<String>?

At most 500 URLs are included; the corresponding count field is always exact.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


129
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 129

optional :removed_urls, ContextDev::Internal::Type::ArrayOf[String]

#run_idString

The run that detected this change.

Parameters:

  • value (String)

Returns:

  • (String)


39
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 39

required :run_id, String

#summaryString

Parameters:

  • value (String)

Returns:

  • (String)


44
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 44

required :summary, String

#tagsArray<String>?

User-defined tags for grouping and filtering monitors and their changes.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


135
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 135

optional :tags, ContextDev::Internal::Type::ArrayOf[String]

#target_typeSymbol, ContextDev::Models::MonitorRetrieveChangeResponse::TargetType

Parameters:

  • value (ContextDev::Models::MonitorRetrieveChangeResponse::target_type)

Returns:



49
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 49

required :target_type, enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::TargetType }

#titleString

Parameters:

  • value (String)

Returns:

  • (String)


54
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 54

required :title, String

#urlString

Parameters:

  • value (String)

Returns:

  • (String)


59
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 59

required :url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 202

Instance Method Details

#to_hash{

Returns:

  • ({)


139
# File 'sig/context_dev/models/monitor_retrieve_change_response.rbs', line 139

def to_hash: -> {