Class: ContextDev::Models::MonitorRetrieveResponse::Schedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorRetrieveResponse::Schedule
- Defined in:
- lib/context_dev/models/monitor_retrieve_response.rb,
sig/context_dev/models/monitor_retrieve_response.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#frequency ⇒ Integer
Number of units between runs.
- #type ⇒ Symbol, ContextDev::Models::MonitorRetrieveResponse::Schedule::Type
- #unit ⇒ Symbol, ContextDev::Models::MonitorRetrieveResponse::Schedule::Unit
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(frequency:, type:, unit:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Schedule for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(frequency:, type:, unit:) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::MonitorRetrieveResponse::Schedule for more details.
Run the monitor on a fixed interval defined by a frequency and a unit, e.g. every 6 hours or every 2 days. The total interval (frequency × unit) must be between 10 minutes and 1 year.
|
|
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 222
|
Instance Attribute Details
#frequency ⇒ Integer
Number of units between runs. The resulting interval (frequency × unit) must be at least 10 minutes and at most 1 year (e.g. minimum 10 when unit is minutes; maximum 365 when unit is days).
210 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 210 required :frequency, Integer |
#type ⇒ Symbol, ContextDev::Models::MonitorRetrieveResponse::Schedule::Type
215 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 215 required :type, enum: -> { ContextDev::Models::MonitorRetrieveResponse::Schedule::Type } |
#unit ⇒ Symbol, ContextDev::Models::MonitorRetrieveResponse::Schedule::Unit
220 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 220 required :unit, enum: -> { ContextDev::Models::MonitorRetrieveResponse::Schedule::Unit } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 242
|
Instance Method Details
#to_hash ⇒ {
166 |
# File 'sig/context_dev/models/monitor_retrieve_response.rbs', line 166
def to_hash: -> {
|