Class: ContextDev::Models::MonitorRetrieveResponse::Target::Extract
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorRetrieveResponse::Target::Extract
- Defined in:
- lib/context_dev/models/monitor_retrieve_response.rb,
sig/context_dev/models/monitor_retrieve_response.rbs
Instance Attribute Summary collapse
- #follow_subdomains ⇒ Boolean?
-
#instructions ⇒ String
Natural-language instructions guiding which pages and facts to track and which changes to report.
-
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
-
#max_pages ⇒ Integer?
Maximum number of pages to track.
-
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the data you care about.
- #type ⇒ Symbol, :extract
-
#url ⇒ String
Root URL to extract structured data from.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
318 |
# File 'sig/context_dev/models/monitor_retrieve_response.rbs', line 318
def initialize: (
|
Instance Attribute Details
#follow_subdomains ⇒ Boolean?
408 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 408 optional :follow_subdomains, ContextDev::Internal::Type::Boolean |
#instructions ⇒ String
Natural-language instructions guiding which pages and facts to track and which changes to report.
392 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 392 required :instructions, String |
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
414 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 414 optional :max_depth, Integer |
#max_pages ⇒ Integer?
Maximum number of pages to track.
420 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 420 optional :max_pages, Integer |
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the data you care about. It is used three ways: it guides
which pages are selected for tracking, it gives the change judge extra context
on which changes matter (alongside instructions), and it defines the shape of
the baseline data snapshot on GET /monitors/monitor_id (refreshed at most
about once a day). It is not a response format for changes: change events and
webhook payloads always contain diffs, summaries, and evidence excerpts — never
data in this schema's shape. If omitted, a default summary + key-points schema
is used.
433 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 433 optional :schema, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#type ⇒ Symbol, :extract
397 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 397 required :type, const: :extract |
#url ⇒ String
Root URL to extract structured data from.
403 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 403 required :url, String |
Instance Method Details
#to_hash ⇒ {
328 |
# File 'sig/context_dev/models/monitor_retrieve_response.rbs', line 328
def to_hash: -> {
|