Class: ContextDev::Models::MonitorRetrieveResponse::WebhookFailure
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorRetrieveResponse::WebhookFailure
- Defined in:
- lib/context_dev/models/monitor_retrieve_response.rb,
sig/context_dev/models/monitor_retrieve_response.rbs
Overview
Defined Under Namespace
Modules: LastStatus
Instance Attribute Summary collapse
-
#consecutive_failures ⇒ Integer
Number of consecutive delivery attempts that did not succeed.
- #last_failed_at ⇒ Time
-
#last_message ⇒ String
Human-readable description of the most recent failure.
-
#last_status ⇒ Symbol, ContextDev::Models::MonitorRetrieveResponse::WebhookFailure::LastStatus
Outcome of the most recent failed delivery.
Instance Method Summary collapse
-
#initialize(consecutive_failures:, last_failed_at:, last_message:, last_status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookFailure for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(consecutive_failures:, last_failed_at:, last_message:, last_status:) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::MonitorRetrieveResponse::WebhookFailure for more details.
Present while webhook deliveries are failing consecutively; null when deliveries are healthy or no webhook is configured. Cleared on the next successful delivery and when the webhook URL changes.
|
|
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 672
|
Instance Attribute Details
#consecutive_failures ⇒ Integer
Number of consecutive delivery attempts that did not succeed.
650 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 650 required :consecutive_failures, Integer |
#last_failed_at ⇒ Time
655 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 655 required :last_failed_at, Time |
#last_message ⇒ String
Human-readable description of the most recent failure.
661 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 661 required :last_message, String |
#last_status ⇒ Symbol, ContextDev::Models::MonitorRetrieveResponse::WebhookFailure::LastStatus
Outcome of the most recent failed delivery. rejected means a non-2xx response; failed means no HTTP response was received; skipped_unsafe_url means the URL failed the public-endpoint safety check.
669 670 |
# File 'lib/context_dev/models/monitor_retrieve_response.rb', line 669 required :last_status, enum: -> { ContextDev::Models::MonitorRetrieveResponse::WebhookFailure::LastStatus } |
Instance Method Details
#to_hash ⇒ {
491 |
# File 'sig/context_dev/models/monitor_retrieve_response.rbs', line 491
def to_hash: -> {
|