Class: ContextDev::Models::MonitorUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/monitor_update_params.rb,
sig/context_dev/models/monitor_update_params.rbs

Overview

See Also:

  • ContextDev::Resources::Monitors#update

Defined Under Namespace

Modules: ChangeDetection, Status, Target Classes: Schedule, Webhook

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url:, follow_subdomains: nil, instructions: nil, max_depth: nil, max_pages: nil, schema: nil, type: :extract) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::MonitorUpdateParams::Target::Extract for more details.

Watch a site's extracted structured data.

Parameters:

  • url (String)

    Root URL to extract structured data from.

  • follow_subdomains (Boolean) (defaults to: nil)
  • instructions (String) (defaults to: nil)

    Optional natural-language instructions guiding what to extract.

  • max_depth (Integer) (defaults to: nil)

    Optional maximum link depth from the starting URL (0 = only the starting page).

  • max_pages (Integer) (defaults to: nil)

    Maximum number of pages to analyze during extraction.

  • schema (Hash{Symbol=>Object}) (defaults to: nil)

    JSON Schema describing the structured data to extract and watch for changes. If

  • type (Symbol, :extract) (defaults to: :extract)


# File 'lib/context_dev/models/monitor_update_params.rb', line 57

Instance Attribute Details

#change_detectionContextDev::Models::MonitorUpdateParams::ChangeDetection::Exact, ...

Discriminated union describing how changes are detected.



19
# File 'lib/context_dev/models/monitor_update_params.rb', line 19

optional :change_detection, union: -> { ContextDev::MonitorUpdateParams::ChangeDetection }

#monitor_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/context_dev/models/monitor_update_params.rb', line 13

required :monitor_id, String

#nameString?

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/context_dev/models/monitor_update_params.rb', line 24

optional :name, String

#scheduleContextDev::Models::MonitorUpdateParams::Schedule?

Run the monitor on a fixed interval defined by a frequency and a unit, e.g. every 6 hours or every 2 days. The total interval (frequency × unit) must be between 10 minutes and 1 year.



32
# File 'lib/context_dev/models/monitor_update_params.rb', line 32

optional :schedule, -> { ContextDev::MonitorUpdateParams::Schedule }

#statusSymbol, ...



37
# File 'lib/context_dev/models/monitor_update_params.rb', line 37

optional :status, enum: -> { ContextDev::MonitorUpdateParams::Status }

#tagsArray<String>?

User-defined tags for grouping and filtering monitors and their changes.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


43
# File 'lib/context_dev/models/monitor_update_params.rb', line 43

optional :tags, ContextDev::Internal::Type::ArrayOf[String]

#targetContextDev::Models::MonitorUpdateParams::Target::Page, ...

Discriminated union describing what the monitor watches.



49
# File 'lib/context_dev/models/monitor_update_params.rb', line 49

optional :target, union: -> { ContextDev::MonitorUpdateParams::Target }

#webhookContextDev::Models::MonitorUpdateParams::Webhook?

Set to null to remove the webhook.

Parameters:

  • value (ContextDev::MonitorUpdateParams::Webhook, nil)

Returns:



55
# File 'lib/context_dev/models/monitor_update_params.rb', line 55

optional :webhook, -> { ContextDev::MonitorUpdateParams::Webhook }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/monitor_update_params.rb', line 183

Instance Method Details

#to_hash{

Returns:

  • ({)


68
# File 'sig/context_dev/models/monitor_update_params.rbs', line 68

def to_hash: -> {