Class: ContextDev::Models::MonitorUpdateParams::Target::Extract
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorUpdateParams::Target::Extract
- Defined in:
- lib/context_dev/models/monitor_update_params.rb,
sig/context_dev/models/monitor_update_params.rbs
Instance Attribute Summary collapse
- #follow_subdomains ⇒ Boolean?
-
#instructions ⇒ String
Natural-language instructions guiding which pages and facts to track and which changes to report.
-
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
-
#max_pages ⇒ Integer?
Maximum number of pages to track.
-
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the data you care about.
- #type ⇒ Symbol, :extract
-
#url ⇒ String
Root URL to extract structured data from.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
298 |
# File 'sig/context_dev/models/monitor_update_params.rbs', line 298
def initialize: (
|
Instance Attribute Details
#follow_subdomains ⇒ Boolean?
321 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 321 optional :follow_subdomains, ContextDev::Internal::Type::Boolean |
#instructions ⇒ String
Natural-language instructions guiding which pages and facts to track and which changes to report.
305 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 305 required :instructions, String |
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
327 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 327 optional :max_depth, Integer |
#max_pages ⇒ Integer?
Maximum number of pages to track.
333 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 333 optional :max_pages, Integer |
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the data you care about. It is used three ways: it guides
which pages are selected for tracking, it gives the change judge extra context
on which changes matter (alongside instructions), and it defines the shape of
the baseline data snapshot on GET /monitors/monitor_id (refreshed at most
about once a day). It is not a response format for changes: change events and
webhook payloads always contain diffs, summaries, and evidence excerpts — never
data in this schema's shape. If omitted, a default summary + key-points schema
is used.
346 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 346 optional :schema, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#type ⇒ Symbol, :extract
310 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 310 required :type, const: :extract |
#url ⇒ String
Root URL to extract structured data from.
316 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 316 required :url, String |
Instance Method Details
#to_hash ⇒ {
308 |
# File 'sig/context_dev/models/monitor_update_params.rbs', line 308
def to_hash: -> {
|