Class: ContextDev::Models::MonitorUpdateResponse::WebhookFailure

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/monitor_update_response.rb,
sig/context_dev/models/monitor_update_response.rbs

Overview

See Also:

  • ContextDev::Models::MonitorUpdateResponse#webhook_failure

Defined Under Namespace

Modules: LastStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(consecutive_failures:, last_failed_at:, last_message:, last_status:) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::MonitorUpdateResponse::WebhookFailure for more details.

Present while webhook deliveries are failing consecutively; null when deliveries are healthy or no webhook is configured. Cleared on the next successful delivery and when the webhook URL changes.

Parameters:

  • consecutive_failures (Integer)

    Number of consecutive delivery attempts that did not succeed.

  • last_failed_at (Time)
  • last_message (String)

    Human-readable description of the most recent failure.

  • last_status (Symbol, ContextDev::Models::MonitorUpdateResponse::WebhookFailure::LastStatus)

    Outcome of the most recent failed delivery. rejected means a non-2xx response; f



# File 'lib/context_dev/models/monitor_update_response.rb', line 671

Instance Attribute Details

#consecutive_failuresInteger

Number of consecutive delivery attempts that did not succeed.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


650
# File 'lib/context_dev/models/monitor_update_response.rb', line 650

required :consecutive_failures, Integer

#last_failed_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


655
# File 'lib/context_dev/models/monitor_update_response.rb', line 655

required :last_failed_at, Time

#last_messageString

Human-readable description of the most recent failure.

Parameters:

  • value (String)

Returns:

  • (String)


661
# File 'lib/context_dev/models/monitor_update_response.rb', line 661

required :last_message, String

#last_statusSymbol, ContextDev::Models::MonitorUpdateResponse::WebhookFailure::LastStatus

Outcome of the most recent failed delivery. rejected means a non-2xx response; failed means no HTTP response was received; skipped_unsafe_url means the URL failed the public-endpoint safety check.

Parameters:

  • value (ContextDev::Models::MonitorUpdateResponse::WebhookFailure::last_status)

Returns:



669
# File 'lib/context_dev/models/monitor_update_response.rb', line 669

required :last_status, enum: -> { ContextDev::Models::MonitorUpdateResponse::WebhookFailure::LastStatus }

Instance Method Details

#to_hash{

Returns:

  • ({)


491
# File 'sig/context_dev/models/monitor_update_response.rbs', line 491

def to_hash: -> {