Class: ContextDev::Models::NewsSearchParams::SearchBy::Entity::Ticker

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/news_search_params.rb,
sig/context_dev/models/news_search_params.rbs

Defined Under Namespace

Modules: Exchange

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ticker:, exchange: nil, type: :ticker) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::NewsSearchParams::SearchBy::Entity::Ticker for more details.

Identify the company by stock ticker, optionally scoped to an exchange.

Parameters:



# File 'lib/context_dev/models/news_search_params.rb', line 160

Instance Attribute Details

#exchangeSymbol, ...

Stock exchange the ticker trades on, used to disambiguate tickers listed on multiple exchanges.



158
# File 'lib/context_dev/models/news_search_params.rb', line 158

optional :exchange, enum: -> { ContextDev::NewsSearchParams::SearchBy::Entity::Ticker::Exchange }

#tickerString

Public-company ticker.

Parameters:

  • value (String)

Returns:

  • (String)


146
# File 'lib/context_dev/models/news_search_params.rb', line 146

required :ticker, String

#typeSymbol, :ticker

Parameters:

  • value (:ticker)

Returns:

  • (Symbol, :ticker)


151
# File 'lib/context_dev/models/news_search_params.rb', line 151

required :type, const: :ticker

Instance Method Details

#to_hash{

Returns:

  • ({)


140
# File 'sig/context_dev/models/news_search_params.rbs', line 140

def to_hash: -> {