Class: ContextDev::Models::NewsSearchResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::NewsSearchResponse
- Defined in:
- lib/context_dev/models/news_search_response.rb,
sig/context_dev/models/news_search_response.rbs
Overview
Defined Under Namespace
Classes: Data, KeyMetadata, Meta
Instance Attribute Summary collapse
-
#data ⇒ Array<ContextDev::Models::NewsSearchResponse::Data>
Articles matching the search, in the requested order.
-
#has_more ⇒ Boolean
True when more results are available beyond this page.
-
#key_metadata ⇒ ContextDev::Models::NewsSearchResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#meta ⇒ ContextDev::Models::NewsSearchResponse::Meta
Summary information about this response.
-
#next_cursor ⇒ String?
Pass as cursor in the next request to fetch the following page.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(count:) ⇒ Object
constructor
Summary information about this response.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(count:) ⇒ Object
Summary information about this response.
|
|
# File 'lib/context_dev/models/news_search_response.rb', line 254
|
Instance Attribute Details
#data ⇒ Array<ContextDev::Models::NewsSearchResponse::Data>
Articles matching the search, in the requested order.
11 |
# File 'lib/context_dev/models/news_search_response.rb', line 11 required :data, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::NewsSearchResponse::Data] } |
#has_more ⇒ Boolean
True when more results are available beyond this page.
17 |
# File 'lib/context_dev/models/news_search_response.rb', line 17 required :has_more, ContextDev::Internal::Type::Boolean |
#key_metadata ⇒ ContextDev::Models::NewsSearchResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
37 |
# File 'lib/context_dev/models/news_search_response.rb', line 37 optional :key_metadata, -> { ContextDev::Models::NewsSearchResponse::KeyMetadata } |
#meta ⇒ ContextDev::Models::NewsSearchResponse::Meta
Summary information about this response.
23 |
# File 'lib/context_dev/models/news_search_response.rb', line 23 required :meta, -> { ContextDev::Models::NewsSearchResponse::Meta } |
#next_cursor ⇒ String?
Pass as cursor in the next request to fetch the following page. Null when there are no more results.
30 |
# File 'lib/context_dev/models/news_search_response.rb', line 30 required :next_cursor, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/news_search_response.rb', line 241
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/context_dev/models/news_search_response.rbs', line 35
def to_hash: -> {
|