Class: ContextDev::Models::ParseHandleParams::Pdf
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::ParseHandleParams::Pdf
- Defined in:
- lib/context_dev/models/parse_handle_params.rb,
sig/context_dev/models/parse_handle_params.rbs
Instance Attribute Summary collapse
-
#end_ ⇒ Integer?
Last 1-based PDF page to parse.
-
#start ⇒ Integer?
First 1-based PDF page to parse.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Pdf
constructor
Some parameter documentations has been truncated, see Pdf for more details.
- #to_hash ⇒ { end_: Integer, start: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Pdf
Some parameter documentations has been truncated, see ContextDev::Models::ParseHandleParams::Pdf for more details.
PDF page-range controls. Use start/end to limit parsing (and OCR when ocr=true) to an inclusive 1-based page range.
|
|
# File 'lib/context_dev/models/parse_handle_params.rb', line 181
|
Instance Attribute Details
#end_ ⇒ Integer?
Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Must be greater than or equal to start when both are provided.
173 |
# File 'lib/context_dev/models/parse_handle_params.rb', line 173 optional :end_, Integer, api_name: :end |
#start ⇒ Integer?
First 1-based PDF page to parse. When omitted, parsing starts at the first page.
179 |
# File 'lib/context_dev/models/parse_handle_params.rb', line 179 optional :start, Integer |
Instance Method Details
#to_hash ⇒ { end_: Integer, start: Integer }
240 |
# File 'sig/context_dev/models/parse_handle_params.rbs', line 240
def to_hash: -> { end_: Integer, start: Integer }
|