Class: ContextDev::Models::UtilityPrefetchResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::UtilityPrefetchResponse
- Defined in:
- lib/context_dev/models/utility_prefetch_response.rb,
sig/context_dev/models/utility_prefetch_response.rbs
Overview
Defined Under Namespace
Modules: Type Classes: KeyMetadata
Instance Attribute Summary collapse
-
#domain ⇒ String?
The domain that was queued for prefetching.
-
#key_metadata ⇒ ContextDev::Models::UtilityPrefetchResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#message ⇒ String?
Success message.
-
#status ⇒ String?
Status of the response, e.g., 'ok'.
-
#type ⇒ Symbol, ...
The type of prefetch that was queued, echoed from the request (currently always 'brand').
Instance Method Summary collapse
-
#initialize(credits_consumed:, credits_remaining:) ⇒ Object
constructor
Metadata about the API key used for the request.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credits_consumed:, credits_remaining:) ⇒ Object
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
|
|
# File 'lib/context_dev/models/utility_prefetch_response.rb', line 39
|
Instance Attribute Details
#domain ⇒ String?
The domain that was queued for prefetching
11 |
# File 'lib/context_dev/models/utility_prefetch_response.rb', line 11 optional :domain, String |
#key_metadata ⇒ ContextDev::Models::UtilityPrefetchResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
18 |
# File 'lib/context_dev/models/utility_prefetch_response.rb', line 18 optional :key_metadata, -> { ContextDev::Models::UtilityPrefetchResponse::KeyMetadata } |
#message ⇒ String?
Success message
24 |
# File 'lib/context_dev/models/utility_prefetch_response.rb', line 24 optional :message, String |
#status ⇒ String?
Status of the response, e.g., 'ok'
30 |
# File 'lib/context_dev/models/utility_prefetch_response.rb', line 30 optional :status, String |
#type ⇒ Symbol, ...
The type of prefetch that was queued, echoed from the request (currently always 'brand')
37 |
# File 'lib/context_dev/models/utility_prefetch_response.rb', line 37 optional :type, enum: -> { ContextDev::Models::UtilityPrefetchResponse::Type } |
Instance Method Details
#to_hash ⇒ {
45 |
# File 'sig/context_dev/models/utility_prefetch_response.rbs', line 45
def to_hash: -> {
|