Class: ContextDev::Models::WebExtractCompetitorsResponse::Target

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_extract_competitors_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from ContextDev::Internal::Type::BaseModel

Instance Attribute Details

#company_nameString

Company or product name inferred from the landing page.

Returns:

  • (String)


136
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 136

required :company_name, String, api_name: :companyName

#fieldString

Specific operating field, product category, or market.

Returns:

  • (String)


142
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 142

required :field, String

#field_descriptionString

One-sentence description of what the target company sells and who it serves.

Returns:

  • (String)


148
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 148

required :field_description, String, api_name: :fieldDescription

#website_urlString

Resolved URL used for the landing page analysis.

Returns:

  • (String)


154
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 154

required :website_url, String, api_name: :websiteUrl