Class: ContextDev::Models::WebExtractFontsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/web_extract_fonts_params.rb,
sig/context_dev/models/web_extract_fonts_params.rbs

Overview

See Also:

  • ContextDev::Resources::Web#extract_fonts

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(direct_url: nil, domain: nil, max_age_ms: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebExtractFontsParams for more details.

Parameters:

  • direct_url (String) (defaults to: nil)

    A specific URL to fetch fonts from directly, bypassing domain resolution (e.g.,

  • domain (String) (defaults to: nil)

    Domain name to extract fonts from (e.g., 'example.com', 'google.com'). The domai

  • max_age_ms (Integer, nil) (defaults to: nil)

    Maximum age in milliseconds for cached brand data before the API performs a hard

  • tags (Array<String>) (defaults to: nil)

    Optional comma-separated caller-defined tags for tracking this request. Tags are

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 51

Instance Attribute Details

#direct_urlString?

A specific URL to fetch fonts from directly, bypassing domain resolution (e.g., 'https://example.com/design-system'). When provided, fonts are extracted from this exact URL. You must provide either 'domain' or 'directUrl', but not both.

Parameters:

  • (String)

Returns:

  • (String, nil)


16
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 16

optional :direct_url, String

#domainString?

Domain name to extract fonts from (e.g., 'example.com', 'google.com'). The domain will be automatically normalized and validated. You must provide either 'domain' or 'directUrl', but not both.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 24

optional :domain, String

#max_age_msInteger?

Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


33
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 33

optional :max_age_ms, Integer, nil?: true

#tagsArray<String>?

Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


41
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 41

optional :tags, ContextDev::Internal::Type::ArrayOf[String]

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


49
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 49

optional :timeout_ms, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/context_dev/models/web_extract_fonts_params.rbs', line 44

def to_hash: -> {