Class: ContextDev::Models::WebExtractFontsResponse::Font
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractFontsResponse::Font
- Defined in:
- lib/context_dev/models/web_extract_fonts_response.rb,
sig/context_dev/models/web_extract_fonts_response.rbs
Instance Attribute Summary collapse
-
#fallbacks ⇒ Array<String>
Array of fallback font families.
-
#font ⇒ String
Font family name.
-
#num_elements ⇒ Float
Number of elements using this font.
-
#num_words ⇒ Float
Number of words using this font.
-
#percent_elements ⇒ Float
Percentage of elements using this font.
-
#percent_words ⇒ Float
Percentage of words using this font.
-
#uses ⇒ Array<String>
Array of CSS selectors or element types where this font is used.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
117 |
# File 'sig/context_dev/models/web_extract_fonts_response.rbs', line 117
def initialize: (
|
Instance Attribute Details
#fallbacks ⇒ Array<String>
Array of fallback font families
123 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 123 required :fallbacks, ContextDev::Internal::Type::ArrayOf[String] |
#font ⇒ String
Font family name
129 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 129 required :font, String |
#num_elements ⇒ Float
Number of elements using this font
135 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 135 required :num_elements, Float |
#num_words ⇒ Float
Number of words using this font
141 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 141 required :num_words, Float |
#percent_elements ⇒ Float
Percentage of elements using this font
147 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 147 required :percent_elements, Float |
#percent_words ⇒ Float
Percentage of words using this font
153 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 153 required :percent_words, Float |
#uses ⇒ Array<String>
Array of CSS selectors or element types where this font is used
159 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 159 required :uses, ContextDev::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
127 |
# File 'sig/context_dev/models/web_extract_fonts_response.rbs', line 127
def to_hash: -> {
|