Class: ContextDev::Models::WebExtractResponse::CacheMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractResponse::CacheMetadata
- Defined in:
- lib/context_dev/models/web_extract_response.rb,
sig/context_dev/models/web_extract_response.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#age_ms ⇒ Integer
Age of the cached data in milliseconds.
-
#status ⇒ Symbol, ContextDev::Models::WebExtractResponse::CacheMetadata::Status
Whether the response was served from cache, required fresh work, or honored zero-data-retention cache bypass.
Instance Method Summary collapse
-
#initialize(age_ms:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CacheMetadata for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(age_ms:, status:) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractResponse::CacheMetadata for more details.
Cache outcome for this response. Composite responses are hits only when every cache-controlled fetch contributing to the output was a hit; age_ms is the oldest contributing hit.
|
|
# File 'lib/context_dev/models/web_extract_response.rb', line 84
|
Instance Attribute Details
#age_ms ⇒ Integer
Age of the cached data in milliseconds. Zero for miss and zdr responses.
75 |
# File 'lib/context_dev/models/web_extract_response.rb', line 75 required :age_ms, Integer |
#status ⇒ Symbol, ContextDev::Models::WebExtractResponse::CacheMetadata::Status
Whether the response was served from cache, required fresh work, or honored zero-data-retention cache bypass.
82 |
# File 'lib/context_dev/models/web_extract_response.rb', line 82 required :status, enum: -> { ContextDev::Models::WebExtractResponse::CacheMetadata::Status } |
Instance Method Details
#to_hash ⇒ {
69 |
# File 'sig/context_dev/models/web_extract_response.rbs', line 69
def to_hash: -> {
|