Class: ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied
- Defined in:
- lib/context_dev/models/web_extract_response.rb,
sig/context_dev/models/web_extract_response.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completion_evidence ⇒ String?
Visible page evidence used to verify an applied action.
- #duration_ms ⇒ Float?
- #error ⇒ String?
- #instruction ⇒ String
- #method_ ⇒ String?
-
#status ⇒ Symbol, ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied::Status
Applied means the requested page state was visibly verified.
- #target_description ⇒ String?
Instance Method Summary collapse
-
#initialize(instruction:, status:, completion_evidence: nil, duration_ms: nil, error: nil, method_: nil, target_description: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionsApplied for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(instruction:, status:, completion_evidence: nil, duration_ms: nil, error: nil, method_: nil, target_description: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied for more details.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/context_dev/models/web_extract_response.rb', line 172 class ActionsApplied < ContextDev::Internal::Type::BaseModel # @!attribute instruction # # @return [String] required :instruction, String # @!attribute status # Applied means the requested page state was visibly verified. Failed means it was # not verified. Skipped means it was not attempted. # # @return [Symbol, ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied::Status] required :status, enum: -> { ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied::Status } # @!attribute completion_evidence # Visible page evidence used to verify an applied action. # # @return [String, nil] optional :completion_evidence, String, api_name: :completionEvidence # @!attribute duration_ms # # @return [Float, nil] optional :duration_ms, Float, api_name: :durationMs # @!attribute error # # @return [String, nil] optional :error, String # @!attribute method_ # # @return [String, nil] optional :method_, String, api_name: :method # @!attribute target_description # # @return [String, nil] optional :target_description, String, api_name: :targetDescription # @!method initialize(instruction:, status:, completion_evidence: nil, duration_ms: nil, error: nil, method_: nil, target_description: nil) # Some parameter documentations has been truncated, see # {ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied} for more # details. # # @param instruction [String] # # @param status [Symbol, ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied::Status] Applied means the requested page state was visibly verified. Failed means it was # # @param completion_evidence [String] Visible page evidence used to verify an applied action. # # @param duration_ms [Float] # # @param error [String] # # @param method_ [String] # # @param target_description [String] # Applied means the requested page state was visibly verified. Failed means it was # not verified. Skipped means it was not attempted. # # @see ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied#status module Status extend ContextDev::Internal::Type::Enum APPLIED = :applied FAILED = :failed SKIPPED = :skipped # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#completion_evidence ⇒ String?
Visible page evidence used to verify an applied action.
189 |
# File 'lib/context_dev/models/web_extract_response.rb', line 189 optional :completion_evidence, String, api_name: :completionEvidence |
#duration_ms ⇒ Float?
194 |
# File 'lib/context_dev/models/web_extract_response.rb', line 194 optional :duration_ms, Float, api_name: :durationMs |
#error ⇒ String?
199 |
# File 'lib/context_dev/models/web_extract_response.rb', line 199 optional :error, String |
#instruction ⇒ String
176 |
# File 'lib/context_dev/models/web_extract_response.rb', line 176 required :instruction, String |
#method_ ⇒ String?
204 |
# File 'lib/context_dev/models/web_extract_response.rb', line 204 optional :method_, String, api_name: :method |
#status ⇒ Symbol, ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied::Status
Applied means the requested page state was visibly verified. Failed means it was not verified. Skipped means it was not attempted.
183 |
# File 'lib/context_dev/models/web_extract_response.rb', line 183 required :status, enum: -> { ContextDev::Models::WebExtractResponse::Metadata::ActionsApplied::Status } |
#target_description ⇒ String?
209 |
# File 'lib/context_dev/models/web_extract_response.rb', line 209 optional :target_description, String, api_name: :targetDescription |
Instance Method Details
#to_hash ⇒ {
183 |
# File 'sig/context_dev/models/web_extract_response.rbs', line 183
def to_hash: -> {
|