Class: ContextDev::Models::WebExtractStyleguideResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_extract_styleguide_response.rb

Overview

Defined Under Namespace

Classes: KeyMetadata, Styleguide

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credits_consumed:, credits_remaining:) ⇒ Object

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.

Parameters:

  • credits_consumed (Integer)

    The number of credits consumed by this request.

  • credits_remaining (Integer)

    The number of credits remaining for your organization after this request.



# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 38

Instance Attribute Details

#codeInteger?

HTTP status code

Returns:

  • (Integer, nil)


11
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 11

optional :code, Integer

#domainString?

The normalized domain that was processed

Returns:

  • (String, nil)


17
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 17

optional :domain, String

#key_metadataContextDev::Models::WebExtractStyleguideResponse::KeyMetadata?

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.



24
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 24

optional :key_metadata, -> { ContextDev::Models::WebExtractStyleguideResponse::KeyMetadata }

#statusString?

Status of the response, e.g., ‘ok’

Returns:

  • (String, nil)


30
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 30

optional :status, String

#styleguideContextDev::Models::WebExtractStyleguideResponse::Styleguide?

Comprehensive styleguide data extracted from the website



36
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 36

optional :styleguide, -> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide }