Class: ContextDev::Models::WebExtractStyleguideResponse::Styleguide

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_extract_styleguide_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Mode Classes: Colors, Components, ElementSpacing, FontLink, Shadows, Typography

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inner:, lg:, md:, sm:, xl:) ⇒ Object

Shadow styles used on the website

Parameters:

  • inner (String)
  • lg (String)
  • md (String)
  • sm (String)
  • xl (String)


# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 125

Instance Attribute Details

#colorsContextDev::Models::WebExtractStyleguideResponse::Styleguide::Colors

Primary colors used on the website



81
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 81

required :colors, -> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Colors }

#componentsContextDev::Models::WebExtractStyleguideResponse::Styleguide::Components

UI component styles



87
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 87

required :components, -> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Components }

#element_spacingContextDev::Models::WebExtractStyleguideResponse::Styleguide::ElementSpacing

Spacing system used on the website



93
94
95
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 93

required :element_spacing,
-> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide::ElementSpacing },
api_name: :elementSpacing

Font assets keyed by family name as it appears in fontFamily/fontFallbacks (non-generic names only). Clients match typography.fontFamily / fontWeight or button styles to pick a file URL from files.



103
104
105
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 103

required :font_links,
-> { ContextDev::Internal::Type::HashOf[ContextDev::Models::WebExtractStyleguideResponse::Styleguide::FontLink] },
api_name: :fontLinks

#modeSymbol, ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Mode

The primary color mode of the website design



111
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 111

required :mode, enum: -> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Mode }

#shadowsContextDev::Models::WebExtractStyleguideResponse::Styleguide::Shadows

Shadow styles used on the website



117
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 117

required :shadows, -> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Shadows }

#typographyContextDev::Models::WebExtractStyleguideResponse::Styleguide::Typography

Typography styles used on the website



123
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 123

required :typography, -> { ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Typography }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 794