Class: ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Components::Button::Primary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractStyleguideResponse::Styleguide::Components::Button::Primary
- Defined in:
- lib/context_dev/models/web_extract_styleguide_response.rb,
sig/context_dev/models/web_extract_styleguide_response.rbs
Overview
Instance Attribute Summary collapse
- #background_color ⇒ String
-
#border_color ⇒ String
Border color as CSS hex (#RRGGBB or #RRGGBBAA when computed border-color has alpha).
- #border_radius ⇒ String
- #border_style ⇒ String
- #border_width ⇒ String
-
#box_shadow ⇒ String
Computed box-shadow (comma-separated layers when present).
- #color ⇒ String
-
#css ⇒ String
Ready-to-use CSS declaration block for this component style.
-
#font_fallbacks ⇒ Array<String>?
Full ordered font list from computed font-family.
-
#font_family ⇒ String?
Primary button typeface (first in fontFallbacks).
- #font_size ⇒ String
- #font_weight ⇒ Float
-
#min_height ⇒ String
Sampled minimum height of the button box (typically px).
-
#min_width ⇒ String
Sampled minimum width of the button box (typically px).
- #padding ⇒ String
- #text_decoration ⇒ String
-
#text_decoration_color ⇒ String?
Hex color of the underline when it differs from the text color.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
403 |
# File 'sig/context_dev/models/web_extract_styleguide_response.rbs', line 403
def initialize: (
|
Instance Attribute Details
#background_color ⇒ String
418 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 418 required :background_color, String, api_name: :backgroundColor |
#border_color ⇒ String
Border color as CSS hex (#RRGGBB or #RRGGBBAA when computed border-color has alpha)
425 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 425 required :border_color, String, api_name: :borderColor |
#border_radius ⇒ String
430 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 430 required :border_radius, String, api_name: :borderRadius |
#border_style ⇒ String
435 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 435 required :border_style, String, api_name: :borderStyle |
#border_width ⇒ String
440 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 440 required :border_width, String, api_name: :borderWidth |
#box_shadow ⇒ String
Computed box-shadow (comma-separated layers when present)
446 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 446 required :box_shadow, String, api_name: :boxShadow |
#color ⇒ String
451 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 451 required :color, String |
#css ⇒ String
Ready-to-use CSS declaration block for this component style
457 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 457 required :css, String |
#font_fallbacks ⇒ Array<String>?
Full ordered font list from computed font-family
495 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 495 optional :font_fallbacks, ContextDev::Internal::Type::ArrayOf[String], api_name: :fontFallbacks |
#font_family ⇒ String?
Primary button typeface (first in fontFallbacks)
501 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 501 optional :font_family, String, api_name: :fontFamily |
#font_size ⇒ String
462 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 462 required :font_size, String, api_name: :fontSize |
#font_weight ⇒ Float
467 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 467 required :font_weight, Float, api_name: :fontWeight |
#min_height ⇒ String
Sampled minimum height of the button box (typically px)
473 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 473 required :min_height, String, api_name: :minHeight |
#min_width ⇒ String
Sampled minimum width of the button box (typically px)
479 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 479 required :min_width, String, api_name: :minWidth |
#padding ⇒ String
484 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 484 required :padding, String |
#text_decoration ⇒ String
489 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 489 required :text_decoration, String, api_name: :textDecoration |
#text_decoration_color ⇒ String?
Hex color of the underline when it differs from the text color
507 |
# File 'lib/context_dev/models/web_extract_styleguide_response.rb', line 507 optional :text_decoration_color, String, api_name: :textDecorationColor |
Instance Method Details
#to_hash ⇒ {
423 |
# File 'sig/context_dev/models/web_extract_styleguide_response.rbs', line 423
def to_hash: -> {
|