Module: ContextDev::Models::WebWebCrawlMdParams::Zdr
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/context_dev/models/web_web_crawl_md_params.rb,
sig/context_dev/models/web_web_crawl_md_params.rbs
Overview
Set to enabled to bypass shared caches and omit request and response content from retained usage logs. Requires zero data retention to be enabled for your organization (contact support@context.dev), otherwise the request fails with ZDR_NOT_ENABLED. Successful ZDR responses include X-Context-ZDR: true.
Constant Summary collapse
- ENABLED =
:enabled- DISABLED =
:disabled
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 479
|
Instance Method Details
#self?.values ⇒ ::Array[ContextDev::Models::WebWebCrawlMdParams::zdr]
631 |
# File 'sig/context_dev/models/web_web_crawl_md_params.rbs', line 631
def self?.values: -> ::Array[ContextDev::Models::WebWebCrawlMdParams::zdr]
|