Class: ContextDev::Models::WebWebCrawlMdResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_web_crawl_md_response.rb

Overview

Defined Under Namespace

Classes: KeyMetadata, Metadata, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(crawl_depth:, status_code:, success:, title:, url:) ⇒ Object

Parameters:

  • crawl_depth (Integer)

    Depth relative to the start URL. 0 = start URL, 1 = one link away.

  • status_code (Integer)

    HTTP status code of the response

  • success (Boolean)

    true if the page was fetched and parsed successfully

  • title (String)

    The page’s <title> content (empty string if unavailable)

  • url (String)

    The URL that was fetched



# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 25

Instance Attribute Details

#key_metadataContextDev::Models::WebWebCrawlMdResponse::KeyMetadata?

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.



23
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 23

optional :key_metadata, -> { ContextDev::Models::WebWebCrawlMdResponse::KeyMetadata }

#metadataContextDev::Models::WebWebCrawlMdResponse::Metadata



10
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 10

required :metadata, -> { ContextDev::Models::WebWebCrawlMdResponse::Metadata }

#resultsArray<ContextDev::Models::WebWebCrawlMdResponse::Result>



15
16
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 15

required :results,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::WebWebCrawlMdResponse::Result] }