Class: ContextDev::Models::WebWebScrapeHTMLResponse::ActionsApplied

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_web_scrape_html_response.rb,
sig/context_dev/models/web_web_scrape_html_response.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(instruction:, status:, completion_evidence: nil, duration_ms: nil, error: nil, method_: nil, target_description: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeHTMLResponse::ActionsApplied for more details.

Parameters:

  • instruction (String)
  • status (Symbol, ContextDev::Models::WebWebScrapeHTMLResponse::ActionsApplied::Status)

    Applied means the requested page state was visibly verified. Failed means it was

  • completion_evidence (String) (defaults to: nil)

    Visible page evidence used to verify an applied action.

  • duration_ms (Float) (defaults to: nil)
  • error (String) (defaults to: nil)
  • method_ (String) (defaults to: nil)
  • target_description (String) (defaults to: nil)


# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 410

Instance Attribute Details

#completion_evidenceString?

Visible page evidence used to verify an applied action.

Parameters:

  • (String)

Returns:

  • (String, nil)


388
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 388

optional :completion_evidence, String, api_name: :completionEvidence

#duration_msFloat?

Parameters:

  • (Float)

Returns:

  • (Float, nil)


393
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 393

optional :duration_ms, Float, api_name: :durationMs

#errorString?

Parameters:

  • (String)

Returns:

  • (String, nil)


398
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 398

optional :error, String

#instructionString

Parameters:

  • value (String)

Returns:

  • (String)


375
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 375

required :instruction, String

#method_String?

Parameters:

  • (String)

Returns:

  • (String, nil)


403
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 403

optional :method_, String, api_name: :method

#statusSymbol, ContextDev::Models::WebWebScrapeHTMLResponse::ActionsApplied::Status

Applied means the requested page state was visibly verified. Failed means it was not verified. Skipped means it was not attempted.

Parameters:

  • value (ContextDev::Models::WebWebScrapeHTMLResponse::ActionsApplied::status)

Returns:



382
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 382

required :status, enum: -> { ContextDev::Models::WebWebScrapeHTMLResponse::ActionsApplied::Status }

#target_descriptionString?

Parameters:

  • (String)

Returns:

  • (String, nil)


408
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 408

optional :target_description, String, api_name: :targetDescription

Instance Method Details

#to_hash{

Returns:

  • ({)


371
# File 'sig/context_dev/models/web_web_scrape_html_response.rbs', line 371

def to_hash: -> {