Class: ContextDev::Models::WebWebScrapeHTMLResponse::KeyMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeHTMLResponse::KeyMetadata
- Defined in:
- lib/context_dev/models/web_web_scrape_html_response.rb
Overview
Instance Attribute Summary collapse
-
#credits_consumed ⇒ Integer
The number of credits consumed by this request.
-
#credits_remaining ⇒ Integer
The number of credits remaining for your organization after this request.
Instance Method Summary collapse
-
#initialize(credits_consumed:, credits_remaining:) ⇒ Object
constructor
Metadata about the API key used for the request.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credits_consumed:, credits_remaining:) ⇒ Object
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
|
|
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 101
|
Instance Attribute Details
#credits_consumed ⇒ Integer
The number of credits consumed by this request.
93 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 93 required :credits_consumed, Integer |
#credits_remaining ⇒ Integer
The number of credits remaining for your organization after this request.
99 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 99 required :credits_remaining, Integer |