Class: ContextDev::Models::WebWebScrapeHTMLResponse::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeHTMLResponse::Metadata
- Defined in:
- lib/context_dev/models/web_web_scrape_html_response.rb,
sig/context_dev/models/web_web_scrape_html_response.rbs
Overview
Defined Under Namespace
Modules: AdditionalMeta, OpenGraph, Twitter Classes: Alternate
Instance Attribute Summary collapse
-
#additional_meta ⇒ Hash{Symbol=>String, Array<String>}?
Additional non-social meta tags not promoted to top-level metadata fields.
-
#alternates ⇒ Array<ContextDev::Models::WebWebScrapeHTMLResponse::Metadata::Alternate>?
Resolved alternate links from link rel=alternate tags.
-
#author ⇒ String?
Author metadata, when present.
-
#canonical_url ⇒ String?
Resolved canonical URL, when present.
-
#description ⇒ String?
Best description extracted from standard, Open Graph, or Twitter metadata.
-
#favicon ⇒ String?
Resolved favicon URL, when present.
-
#final_url ⇒ String
Final URL scraped after redirects or scraper fallback, when known.
-
#image ⇒ String?
Primary resolved preview image from Open Graph, Twitter, or image metadata.
-
#json_ld ⇒ Array<Hash{Symbol=>Object}>?
JSON-LD structured data blocks parsed from the page.
-
#keywords ⇒ Array<String>?
Keywords extracted from the page's keywords meta tag.
-
#language ⇒ String?
Language extracted from html lang or language meta tags.
-
#modified_time ⇒ String?
Modified timestamp/date from page metadata, when present.
-
#open_graph ⇒ Hash{Symbol=>String, Array<String>}?
Open Graph metadata with the og: prefix removed and keys camel-cased.
-
#published_time ⇒ String?
Published timestamp/date from page metadata, when present.
-
#robots ⇒ String?
Robots meta directive, when present.
-
#site_name ⇒ String?
Site or application name from page metadata.
-
#source_url ⇒ String
Original URL requested by the caller.
-
#title ⇒ String?
Best title extracted from the page.
-
#twitter ⇒ Hash{Symbol=>String, Array<String>}?
Twitter card metadata with the twitter: prefix removed and keys camel-cased.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(href:, hreflang: nil, title: nil, type: nil) ⇒ Object
|
|
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 292
|
Instance Attribute Details
#additional_meta ⇒ Hash{Symbol=>String, Array<String>}?
Additional non-social meta tags not promoted to top-level metadata fields.
103 104 105 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 103 optional :additional_meta, -> { ContextDev::Internal::Type::HashOf[union: ContextDev::Models::WebWebScrapeHTMLResponse::Metadata::AdditionalMeta] }, api_name: :additionalMeta |
#alternates ⇒ Array<ContextDev::Models::WebWebScrapeHTMLResponse::Metadata::Alternate>?
Resolved alternate links from link rel=alternate tags.
111 112 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 111 optional :alternates, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::WebWebScrapeHTMLResponse::Metadata::Alternate] } |
#author ⇒ String?
Author metadata, when present.
118 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 118 optional :author, String |
#canonical_url ⇒ String?
Resolved canonical URL, when present.
124 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 124 optional :canonical_url, String, api_name: :canonicalUrl |
#description ⇒ String?
Best description extracted from standard, Open Graph, or Twitter metadata.
130 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 130 optional :description, String |
#favicon ⇒ String?
Resolved favicon URL, when present.
136 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 136 optional :favicon, String |
#final_url ⇒ String
Final URL scraped after redirects or scraper fallback, when known. Falls back to sourceUrl when unavailable.
91 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 91 required :final_url, String, api_name: :finalUrl |
#image ⇒ String?
Primary resolved preview image from Open Graph, Twitter, or image metadata.
142 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 142 optional :image, String |
#json_ld ⇒ Array<Hash{Symbol=>Object}>?
JSON-LD structured data blocks parsed from the page.
148 149 150 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 148 optional :json_ld, ContextDev::Internal::Type::ArrayOf[ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown]], api_name: :jsonLd |
#keywords ⇒ Array<String>?
Keywords extracted from the page's keywords meta tag.
156 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 156 optional :keywords, ContextDev::Internal::Type::ArrayOf[String] |
#language ⇒ String?
Language extracted from html lang or language meta tags.
162 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 162 optional :language, String |
#modified_time ⇒ String?
Modified timestamp/date from page metadata, when present.
168 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 168 optional :modified_time, String, api_name: :modifiedTime |
#open_graph ⇒ Hash{Symbol=>String, Array<String>}?
Open Graph metadata with the og: prefix removed and keys camel-cased.
174 175 176 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 174 optional :open_graph, -> { ContextDev::Internal::Type::HashOf[union: ContextDev::Models::WebWebScrapeHTMLResponse::Metadata::OpenGraph] }, api_name: :openGraph |
#published_time ⇒ String?
Published timestamp/date from page metadata, when present.
182 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 182 optional :published_time, String, api_name: :publishedTime |
#robots ⇒ String?
Robots meta directive, when present.
188 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 188 optional :robots, String |
#site_name ⇒ String?
Site or application name from page metadata.
194 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 194 optional :site_name, String, api_name: :siteName |
#source_url ⇒ String
Original URL requested by the caller.
97 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 97 required :source_url, String, api_name: :sourceUrl |
#title ⇒ String?
Best title extracted from the page.
200 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 200 optional :title, String |
#twitter ⇒ Hash{Symbol=>String, Array<String>}?
Twitter card metadata with the twitter: prefix removed and keys camel-cased.
206 207 |
# File 'lib/context_dev/models/web_web_scrape_html_response.rb', line 206 optional :twitter, -> { ContextDev::Internal::Type::HashOf[union: ContextDev::Models::WebWebScrapeHTMLResponse::Metadata::Twitter] } |
Instance Method Details
#to_hash ⇒ {
192 |
# File 'sig/context_dev/models/web_web_scrape_html_response.rbs', line 192
def to_hash: -> {
|