Class: ContextDev::Models::WebWebScrapeImagesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeImagesResponse
- Defined in:
- lib/context_dev/models/web_web_scrape_images_response.rb,
sig/context_dev/models/web_web_scrape_images_response.rbs
Overview
Defined Under Namespace
Modules: Success Classes: ActionsApplied, CacheMetadata, Image, KeyMetadata
Instance Attribute Summary collapse
-
#actions_applied ⇒ Array<ContextDev::Models::WebWebScrapeImagesResponse::ActionsApplied>?
One verified outcome per requested browser action, in request order.
-
#cache_metadata ⇒ ContextDev::Models::WebWebScrapeImagesResponse::CacheMetadata
Cache outcome for this response.
-
#images ⇒ Array<ContextDev::Models::WebWebScrapeImagesResponse::Image>
Images found on the page.
-
#key_metadata ⇒ ContextDev::Models::WebWebScrapeImagesResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#success ⇒ Boolean, ContextDev::Models::WebWebScrapeImagesResponse::Success
Always true on success.
-
#url ⇒ String
Page URL that was scraped.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cache_metadata:, images:, success:, url:, actions_applied: nil, key_metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebWebScrapeImagesResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cache_metadata:, images:, success:, url:, actions_applied: nil, key_metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeImagesResponse for more details.
|
|
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 49
|
Instance Attribute Details
#actions_applied ⇒ Array<ContextDev::Models::WebWebScrapeImagesResponse::ActionsApplied>?
One verified outcome per requested browser action, in request order.
38 39 40 |
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 38 optional :actions_applied, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::WebWebScrapeImagesResponse::ActionsApplied] }, api_name: :actionsApplied |
#cache_metadata ⇒ ContextDev::Models::WebWebScrapeImagesResponse::CacheMetadata
Cache outcome for this response. Composite responses are hits only when every cache-controlled fetch contributing to the output was a hit; age_ms is the oldest contributing hit.
13 |
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 13 required :cache_metadata, -> { ContextDev::Models::WebWebScrapeImagesResponse::CacheMetadata } |
#images ⇒ Array<ContextDev::Models::WebWebScrapeImagesResponse::Image>
Images found on the page.
19 20 |
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 19 required :images, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::WebWebScrapeImagesResponse::Image] } |
#key_metadata ⇒ ContextDev::Models::WebWebScrapeImagesResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
47 |
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 47 optional :key_metadata, -> { ContextDev::Models::WebWebScrapeImagesResponse::KeyMetadata } |
#success ⇒ Boolean, ContextDev::Models::WebWebScrapeImagesResponse::Success
Always true on success.
26 |
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 26 required :success, enum: -> { ContextDev::Models::WebWebScrapeImagesResponse::Success } |
#url ⇒ String
Page URL that was scraped.
32 |
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 32 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/web_web_scrape_images_response.rb', line 104
|
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/context_dev/models/web_web_scrape_images_response.rbs', line 43
def to_hash: -> {
|