Class: ContextDev::Models::WebWebScrapeMdResponse::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeMdResponse::Metadata
- Defined in:
- lib/context_dev/models/web_web_scrape_md_response.rb,
sig/context_dev/models/web_web_scrape_md_response.rbs
Overview
Defined Under Namespace
Modules: AdditionalMeta, OpenGraph, Twitter Classes: Alternate
Instance Attribute Summary collapse
-
#additional_meta ⇒ Hash{Symbol=>String, Array<String>}?
Additional non-social meta tags not promoted to top-level metadata fields.
-
#alternates ⇒ Array<ContextDev::Models::WebWebScrapeMdResponse::Metadata::Alternate>?
Resolved alternate links from link rel=alternate tags.
-
#author ⇒ String?
Author metadata, when present.
-
#canonical_url ⇒ String?
Resolved canonical URL, when present.
-
#description ⇒ String?
Best description extracted from standard, Open Graph, or Twitter metadata.
-
#favicon ⇒ String?
Resolved favicon URL, when present.
-
#final_url ⇒ String
Final URL scraped after redirects or scraper fallback, when known.
-
#image ⇒ String?
Primary resolved preview image from Open Graph, Twitter, or image metadata.
-
#json_ld ⇒ Array<Hash{Symbol=>Object}>?
JSON-LD structured data blocks parsed from the page.
-
#keywords ⇒ Array<String>?
Keywords extracted from the page's keywords meta tag.
-
#language ⇒ String?
Language extracted from html lang or language meta tags.
-
#modified_time ⇒ String?
Modified timestamp/date from page metadata, when present.
-
#open_graph ⇒ Hash{Symbol=>String, Array<String>}?
Open Graph metadata with the og: prefix removed and keys camel-cased.
-
#published_time ⇒ String?
Published timestamp/date from page metadata, when present.
-
#robots ⇒ String?
Robots meta directive, when present.
-
#site_name ⇒ String?
Site or application name from page metadata.
-
#source_url ⇒ String
Original URL requested by the caller.
-
#title ⇒ String?
Best title extracted from the page.
-
#twitter ⇒ Hash{Symbol=>String, Array<String>}?
Twitter card metadata with the twitter: prefix removed and keys camel-cased.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(href:, hreflang: nil, title: nil, type: nil) ⇒ Object
|
|
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 289
|
Instance Attribute Details
#additional_meta ⇒ Hash{Symbol=>String, Array<String>}?
Additional non-social meta tags not promoted to top-level metadata fields.
100 101 102 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 100 optional :additional_meta, -> { ContextDev::Internal::Type::HashOf[union: ContextDev::Models::WebWebScrapeMdResponse::Metadata::AdditionalMeta] }, api_name: :additionalMeta |
#alternates ⇒ Array<ContextDev::Models::WebWebScrapeMdResponse::Metadata::Alternate>?
Resolved alternate links from link rel=alternate tags.
108 109 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 108 optional :alternates, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::WebWebScrapeMdResponse::Metadata::Alternate] } |
#author ⇒ String?
Author metadata, when present.
115 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 115 optional :author, String |
#canonical_url ⇒ String?
Resolved canonical URL, when present.
121 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 121 optional :canonical_url, String, api_name: :canonicalUrl |
#description ⇒ String?
Best description extracted from standard, Open Graph, or Twitter metadata.
127 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 127 optional :description, String |
#favicon ⇒ String?
Resolved favicon URL, when present.
133 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 133 optional :favicon, String |
#final_url ⇒ String
Final URL scraped after redirects or scraper fallback, when known. Falls back to sourceUrl when unavailable.
88 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 88 required :final_url, String, api_name: :finalUrl |
#image ⇒ String?
Primary resolved preview image from Open Graph, Twitter, or image metadata.
139 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 139 optional :image, String |
#json_ld ⇒ Array<Hash{Symbol=>Object}>?
JSON-LD structured data blocks parsed from the page.
145 146 147 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 145 optional :json_ld, ContextDev::Internal::Type::ArrayOf[ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown]], api_name: :jsonLd |
#keywords ⇒ Array<String>?
Keywords extracted from the page's keywords meta tag.
153 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 153 optional :keywords, ContextDev::Internal::Type::ArrayOf[String] |
#language ⇒ String?
Language extracted from html lang or language meta tags.
159 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 159 optional :language, String |
#modified_time ⇒ String?
Modified timestamp/date from page metadata, when present.
165 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 165 optional :modified_time, String, api_name: :modifiedTime |
#open_graph ⇒ Hash{Symbol=>String, Array<String>}?
Open Graph metadata with the og: prefix removed and keys camel-cased.
171 172 173 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 171 optional :open_graph, -> { ContextDev::Internal::Type::HashOf[union: ContextDev::Models::WebWebScrapeMdResponse::Metadata::OpenGraph] }, api_name: :openGraph |
#published_time ⇒ String?
Published timestamp/date from page metadata, when present.
179 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 179 optional :published_time, String, api_name: :publishedTime |
#robots ⇒ String?
Robots meta directive, when present.
185 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 185 optional :robots, String |
#site_name ⇒ String?
Site or application name from page metadata.
191 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 191 optional :site_name, String, api_name: :siteName |
#source_url ⇒ String
Original URL requested by the caller.
94 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 94 required :source_url, String, api_name: :sourceUrl |
#title ⇒ String?
Best title extracted from the page.
197 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 197 optional :title, String |
#twitter ⇒ Hash{Symbol=>String, Array<String>}?
Twitter card metadata with the twitter: prefix removed and keys camel-cased.
203 204 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 203 optional :twitter, -> { ContextDev::Internal::Type::HashOf[union: ContextDev::Models::WebWebScrapeMdResponse::Metadata::Twitter] } |
Instance Method Details
#to_hash ⇒ {
192 |
# File 'sig/context_dev/models/web_web_scrape_md_response.rbs', line 192
def to_hash: -> {
|