Class: ContextDev::Resources::People

Inherits:
Object
  • Object
show all
Defined in:
lib/context_dev/resources/people.rb,
sig/context_dev/resources/people.rbs

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ People

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of People.

Parameters:



51
52
53
# File 'lib/context_dev/resources/people.rb', line 51

def initialize(client:)
  @client = client
end

Instance Method Details

#enrich(company: nil, education: nil, email: nil, location: nil, name: nil, social_urls: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::PersonEnrichResponse

Some parameter documentations has been truncated, see Models::PersonEnrichParams for more details.

Finds and normalizes the best available person candidate from additive identity clues, then assigns an identity match score from 0 to 100. Available on all paid plans. Successful requests cost 20 credits. Disposable and free email addresses (like gmail.com, yahoo.com) will throw a 422 error.

Parameters:

Returns:

See Also:



37
38
39
40
41
42
43
44
45
46
# File 'lib/context_dev/resources/people.rb', line 37

def enrich(params = {})
  parsed, options = ContextDev::PersonEnrichParams.dump_request(params)
  @client.request(
    method: :post,
    path: "people/enrich",
    body: parsed,
    model: ContextDev::Models::PersonEnrichResponse,
    options: options
  )
end