Class: ContextDev::Client
- Inherits:
-
Internal::Transport::BaseClient
- Object
- Internal::Transport::BaseClient
- ContextDev::Client
- Defined in:
- lib/context_dev/client.rb
Constant Summary collapse
- DEFAULT_MAX_RETRIES =
Default max number of retries to attempt after a failed retryable request.
2- DEFAULT_TIMEOUT_IN_SECONDS =
Default per-request timeout.
60.0- DEFAULT_INITIAL_RETRY_DELAY =
Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.
0.5- DEFAULT_MAX_RETRY_DELAY =
Default max retry delay in seconds.
8.0
Constants inherited from Internal::Transport::BaseClient
Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS
Instance Attribute Summary collapse
- #ai ⇒ ContextDev::Resources::AI readonly
- #api_key ⇒ String readonly
- #brand ⇒ ContextDev::Resources::Brand readonly
- #industry ⇒ ContextDev::Resources::Industry readonly
- #utility ⇒ ContextDev::Resources::Utility readonly
- #web ⇒ ContextDev::Resources::Web readonly
Attributes inherited from Internal::Transport::BaseClient
#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout
Instance Method Summary collapse
-
#initialize(api_key: ENV["CONTEXT_DEV_API_KEY"], base_url: ENV["CONTEXT_DEV_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
constructor
Creates and returns a new client for interacting with the API.
Methods inherited from Internal::Transport::BaseClient
follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_key: ENV["CONTEXT_DEV_API_KEY"], base_url: ENV["CONTEXT_DEV_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
Creates and returns a new client for interacting with the API.
‘“api.example.com/v2/”`. Defaults to `ENV`
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/context_dev/client.rb', line 59 def initialize( api_key: ENV["CONTEXT_DEV_API_KEY"], base_url: ENV["CONTEXT_DEV_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY ) base_url ||= "https://api.context.dev/v1" if api_key.nil? raise ArgumentError.new("api_key is required, and can be set via environ: \"CONTEXT_DEV_API_KEY\"") end @api_key = api_key.to_s super( base_url: base_url, timeout: timeout, max_retries: max_retries, initial_retry_delay: initial_retry_delay, max_retry_delay: max_retry_delay ) @web = ContextDev::Resources::Web.new(client: self) @ai = ContextDev::Resources::AI.new(client: self) @brand = ContextDev::Resources::Brand.new(client: self) @industry = ContextDev::Resources::Industry.new(client: self) @utility = ContextDev::Resources::Utility.new(client: self) end |
Instance Attribute Details
#ai ⇒ ContextDev::Resources::AI (readonly)
25 26 27 |
# File 'lib/context_dev/client.rb', line 25 def ai @ai end |
#api_key ⇒ String (readonly)
19 20 21 |
# File 'lib/context_dev/client.rb', line 19 def api_key @api_key end |
#brand ⇒ ContextDev::Resources::Brand (readonly)
28 29 30 |
# File 'lib/context_dev/client.rb', line 28 def brand @brand end |
#industry ⇒ ContextDev::Resources::Industry (readonly)
31 32 33 |
# File 'lib/context_dev/client.rb', line 31 def industry @industry end |
#utility ⇒ ContextDev::Resources::Utility (readonly)
34 35 36 |
# File 'lib/context_dev/client.rb', line 34 def utility @utility end |
#web ⇒ ContextDev::Resources::Web (readonly)
22 23 24 |
# File 'lib/context_dev/client.rb', line 22 def web @web end |