Class: ContextDev::Models::AIAIQueryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::AIAIQueryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/ai_ai_query_params.rb
Overview
Defined Under Namespace
Classes: DataToExtract, SpecificPages
Instance Attribute Summary collapse
-
#data_to_extract ⇒ Array<ContextDev::Models::AIAIQueryParams::DataToExtract>
Array of data points to extract from the website.
-
#domain ⇒ String
The domain name to analyze.
-
#specific_pages ⇒ ContextDev::Models::AIAIQueryParams::SpecificPages?
Optional object specifying which pages to analyze.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ContextDev::Internal::Type::BaseModel
Instance Attribute Details
#data_to_extract ⇒ Array<ContextDev::Models::AIAIQueryParams::DataToExtract>
Array of data points to extract from the website
14 15 |
# File 'lib/context_dev/models/ai_ai_query_params.rb', line 14 required :data_to_extract, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::AIAIQueryParams::DataToExtract] } |
#domain ⇒ String
The domain name to analyze
21 |
# File 'lib/context_dev/models/ai_ai_query_params.rb', line 21 required :domain, String |
#specific_pages ⇒ ContextDev::Models::AIAIQueryParams::SpecificPages?
Optional object specifying which pages to analyze
27 |
# File 'lib/context_dev/models/ai_ai_query_params.rb', line 27 optional :specific_pages, -> { ContextDev::AIAIQueryParams::SpecificPages } |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
35 |
# File 'lib/context_dev/models/ai_ai_query_params.rb', line 35 optional :timeout_ms, Integer, api_name: :timeoutMS |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/ai_ai_query_params.rb', line 152
|