Class: ContextDev::Models::AIExtractProductResponse::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::AIExtractProductResponse::Product
- Defined in:
- lib/context_dev/models/ai_extract_product_response.rb
Overview
Defined Under Namespace
Modules: BillingFrequency, PricingModel
Instance Attribute Summary collapse
-
#billing_frequency ⇒ Symbol, ...
Billing frequency for the product.
-
#category ⇒ String?
Category of the product.
-
#currency ⇒ String?
Currency code for the price (e.g., USD, EUR).
-
#description ⇒ String
Description of the product.
-
#features ⇒ Array<String>
List of product features.
-
#image_url ⇒ String?
URL to the product image.
-
#images ⇒ Array<String>
URLs to product images on the page (up to 7).
-
#name ⇒ String
Name of the product.
-
#price ⇒ Float?
Price of the product.
-
#pricing_model ⇒ Symbol, ...
Pricing model for the product.
-
#tags ⇒ Array<String>
Tags associated with the product.
-
#target_audience ⇒ Array<String>
Target audience for the product (array of strings).
-
#url ⇒ String?
URL to the product page.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(description:, features:, images:, name:, tags:, target_audience:, billing_frequency: nil, category: nil, currency: nil, image_url: nil, price: nil, pricing_model: nil, url: nil) ⇒ Object
constructor
The extracted product data, or null if not a product page.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, features:, images:, name:, tags:, target_audience:, billing_frequency: nil, category: nil, currency: nil, image_url: nil, price: nil, pricing_model: nil, url: nil) ⇒ Object
The extracted product data, or null if not a product page
|
|
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 131
|
Instance Attribute Details
#billing_frequency ⇒ Symbol, ...
Billing frequency for the product
89 90 91 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 89 optional :billing_frequency, enum: -> { ContextDev::Models::AIExtractProductResponse::Product::BillingFrequency }, nil?: true |
#category ⇒ String?
Category of the product
97 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 97 optional :category, String, nil?: true |
#currency ⇒ String?
Currency code for the price (e.g., USD, EUR)
103 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 103 optional :currency, String, nil?: true |
#description ⇒ String
Description of the product
53 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 53 required :description, String |
#features ⇒ Array<String>
List of product features
59 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 59 required :features, ContextDev::Internal::Type::ArrayOf[String] |
#image_url ⇒ String?
URL to the product image
109 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 109 optional :image_url, String, nil?: true |
#images ⇒ Array<String>
URLs to product images on the page (up to 7)
65 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 65 required :images, ContextDev::Internal::Type::ArrayOf[String] |
#name ⇒ String
Name of the product
71 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 71 required :name, String |
#price ⇒ Float?
Price of the product
115 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 115 optional :price, Float, nil?: true |
#pricing_model ⇒ Symbol, ...
Pricing model for the product
121 122 123 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 121 optional :pricing_model, enum: -> { ContextDev::Models::AIExtractProductResponse::Product::PricingModel }, nil?: true |
#tags ⇒ Array<String>
Tags associated with the product
77 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 77 required :tags, ContextDev::Internal::Type::ArrayOf[String] |
#target_audience ⇒ Array<String>
Target audience for the product (array of strings)
83 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 83 required :target_audience, ContextDev::Internal::Type::ArrayOf[String] |
#url ⇒ String?
URL to the product page
129 |
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 129 optional :url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/ai_extract_product_response.rb', line 171
|