Class: ContextDev::Models::BatchGetResultsResponse::Data::Ok
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BatchGetResultsResponse::Data::Ok
- Defined in:
- lib/context_dev/models/batch_get_results_response.rb,
sig/context_dev/models/batch_get_results_response.rbs
Defined Under Namespace
Classes: CacheMetadata, Metadata
Instance Attribute Summary collapse
-
#cache_metadata ⇒ ContextDev::Models::BatchGetResultsResponse::Data::Ok::CacheMetadata
Cache outcome for this response.
-
#final_url ⇒ String
URL the content was read from, after redirects.
-
#html ⇒ String?
Page HTML.
-
#http_status ⇒ Integer?
HTTP status of the final response, when known.
-
#item_id ⇒ String?
Caller-supplied identifier echoed from submission.
-
#markdown ⇒ String?
Page content as Markdown.
-
#meta ⇒ Hash{Symbol=>Object}?
Caller-supplied metadata echoed from submission.
-
#metadata ⇒ ContextDev::Models::BatchGetResultsResponse::Data::Ok::Metadata
Metadata extracted from the scraped page HTML.
-
#ocr_pages ⇒ Integer?
PDF pages of this document recovered by OCR (pdf.ocr=true).
-
#status ⇒ Symbol, :ok
The page was scraped.
-
#url ⇒ String
URL as submitted, or as discovered by the crawl.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cache_metadata:, final_url:, http_status:, metadata:, url:, html: nil, item_id: nil, markdown: nil, meta: nil, ocr_pages: nil, status: :ok) ⇒ Object
constructor
Some parameter documentations has been truncated, see Ok for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cache_metadata:, final_url:, http_status:, metadata:, url:, html: nil, item_id: nil, markdown: nil, meta: nil, ocr_pages: nil, status: :ok) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BatchGetResultsResponse::Data::Ok for more details.
A page the batch fetched successfully.
|
|
# File 'lib/context_dev/models/batch_get_results_response.rb', line 128
|
Instance Attribute Details
#cache_metadata ⇒ ContextDev::Models::BatchGetResultsResponse::Data::Ok::CacheMetadata
Cache outcome for this response. Composite responses are hits only when every cache-controlled fetch contributing to the output was a hit; age_ms is the oldest contributing hit.
64 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 64 required :cache_metadata, -> { ContextDev::Models::BatchGetResultsResponse::Data::Ok::CacheMetadata } |
#final_url ⇒ String
URL the content was read from, after redirects.
70 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 70 required :final_url, String |
#html ⇒ String?
Page HTML. Present on html batches, and on markdown batches submitted with
options.includeHTML.
101 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 101 optional :html, String |
#http_status ⇒ Integer?
HTTP status of the final response, when known.
76 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 76 required :http_status, Integer, nil?: true |
#item_id ⇒ String?
Caller-supplied identifier echoed from submission.
107 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 107 optional :item_id, String, api_name: :itemId |
#markdown ⇒ String?
Page content as Markdown. Present on markdown batches.
113 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 113 optional :markdown, String |
#meta ⇒ Hash{Symbol=>Object}?
Caller-supplied metadata echoed from submission.
119 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 119 optional :meta, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#metadata ⇒ ContextDev::Models::BatchGetResultsResponse::Data::Ok::Metadata
Metadata extracted from the scraped page HTML.
82 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 82 required :metadata, -> { ContextDev::Models::BatchGetResultsResponse::Data::Ok::Metadata } |
#ocr_pages ⇒ Integer?
PDF pages of this document recovered by OCR (pdf.ocr=true). Each recovered page bills 1 credit on top of the page base credit; absent when no OCR ran.
126 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 126 optional :ocr_pages, Integer |
#status ⇒ Symbol, :ok
The page was scraped.
88 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 88 required :status, const: :ok |
#url ⇒ String
URL as submitted, or as discovered by the crawl.
94 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 94 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/batch_get_results_response.rb', line 196
|
Instance Method Details
#to_hash ⇒ {
113 |
# File 'sig/context_dev/models/batch_get_results_response.rbs', line 113
def to_hash: -> {
|