Class: ContextDev::Models::BatchGetResultsResponse::Data::Ok
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BatchGetResultsResponse::Data::Ok
- Defined in:
- lib/context_dev/models/batch_get_results_response.rb,
sig/context_dev/models/batch_get_results_response.rbs
Defined Under Namespace
Classes: Metadata
Instance Attribute Summary collapse
-
#final_url ⇒ String
URL the content was read from, after redirects.
-
#html ⇒ String?
Raw page HTML.
-
#http_status ⇒ Integer?
HTTP status of the final response, when known.
-
#item_id ⇒ String?
Caller-supplied identifier echoed from submission.
-
#markdown ⇒ String?
Page content as Markdown.
-
#meta ⇒ Hash{Symbol=>Object}?
Caller-supplied metadata echoed from submission.
-
#metadata ⇒ ContextDev::Models::BatchGetResultsResponse::Data::Ok::Metadata
Metadata extracted from the scraped page HTML.
-
#status ⇒ Symbol, :ok
The page was scraped.
-
#url ⇒ String
URL as submitted, or as discovered by the crawl.
Instance Method Summary collapse
-
#initialize(final_url:, http_status:, metadata:, url:, html: nil, item_id: nil, markdown: nil, meta: nil, status: :ok) ⇒ Object
constructor
A page the batch fetched successfully.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(final_url:, http_status:, metadata:, url:, html: nil, item_id: nil, markdown: nil, meta: nil, status: :ok) ⇒ Object
A page the batch fetched successfully.
|
|
# File 'lib/context_dev/models/batch_get_results_response.rb', line 112
|
Instance Attribute Details
#final_url ⇒ String
URL the content was read from, after redirects.
62 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 62 required :final_url, String |
#html ⇒ String?
Raw page HTML. Present on html batches.
92 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 92 optional :html, String |
#http_status ⇒ Integer?
HTTP status of the final response, when known.
68 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 68 required :http_status, Integer, nil?: true |
#item_id ⇒ String?
Caller-supplied identifier echoed from submission.
98 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 98 optional :item_id, String, api_name: :itemId |
#markdown ⇒ String?
Page content as Markdown. Present on markdown batches.
104 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 104 optional :markdown, String |
#meta ⇒ Hash{Symbol=>Object}?
Caller-supplied metadata echoed from submission.
110 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 110 optional :meta, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#metadata ⇒ ContextDev::Models::BatchGetResultsResponse::Data::Ok::Metadata
Metadata extracted from the scraped page HTML.
74 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 74 required :metadata, -> { ContextDev::Models::BatchGetResultsResponse::Data::Ok::Metadata } |
#status ⇒ Symbol, :ok
The page was scraped.
80 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 80 required :status, const: :ok |
#url ⇒ String
URL as submitted, or as discovered by the crawl.
86 |
# File 'lib/context_dev/models/batch_get_results_response.rb', line 86 required :url, String |
Instance Method Details
#to_hash ⇒ {
103 |
# File 'sig/context_dev/models/batch_get_results_response.rbs', line 103
def to_hash: -> {
|