Class: ContextDev::Models::BatchListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BatchListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/batch_list_params.rb,
sig/context_dev/models/batch_list_params.rbs
Overview
Defined Under Namespace
Modules: SearchType, Status
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Cursor from the previous page.
-
#limit ⇒ Integer?
Batches per page.
-
#q ⇒ String?
Free-text search term, matched against the batch id, crawl source (start URL or sitemap domain), and tags.
-
#search_type ⇒ Symbol, ...
prefixfor as-you-type prefix matching (default),exactfor full-token matching. -
#status ⇒ Symbol, ...
Filter by status.
-
#tags ⇒ String?
Comma-separated list of tags to filter by (matches batches having any of them).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cursor: nil, limit: nil, q: nil, search_type: nil, status: nil, tags: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor: nil, limit: nil, q: nil, search_type: nil, status: nil, tags: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BatchListParams for more details.
|
|
# File 'lib/context_dev/models/batch_list_params.rb', line 48
|
Instance Attribute Details
#cursor ⇒ String?
Cursor from the previous page.
14 |
# File 'lib/context_dev/models/batch_list_params.rb', line 14 optional :cursor, String |
#limit ⇒ Integer?
Batches per page. Defaults to 25.
20 |
# File 'lib/context_dev/models/batch_list_params.rb', line 20 optional :limit, Integer |
#q ⇒ String?
Free-text search term, matched against the batch id, crawl source (start URL or sitemap domain), and tags.
27 |
# File 'lib/context_dev/models/batch_list_params.rb', line 27 optional :q, String |
#search_type ⇒ Symbol, ...
prefix for as-you-type prefix matching (default), exact for full-token
matching.
34 |
# File 'lib/context_dev/models/batch_list_params.rb', line 34 optional :search_type, enum: -> { ContextDev::BatchListParams::SearchType } |
#status ⇒ Symbol, ...
Filter by status.
40 |
# File 'lib/context_dev/models/batch_list_params.rb', line 40 optional :status, enum: -> { ContextDev::BatchListParams::Status } |
#tags ⇒ String?
Comma-separated list of tags to filter by (matches batches having any of them).
46 |
# File 'lib/context_dev/models/batch_list_params.rb', line 46 optional :tags, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/batch_list_params.rb', line 74
|
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/context_dev/models/batch_list_params.rbs', line 56
def to_hash: -> {
|