Class: ContextDev::Models::BrandRetrieveByNameParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveByNameParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/brand_retrieve_by_name_params.rb
Overview
Defined Under Namespace
Modules: CountryGl, ForceLanguage
Instance Attribute Summary collapse
-
#country_gl ⇒ Symbol, ...
Optional country code hint (GL parameter) to specify the country for the company name.
-
#force_language ⇒ Symbol, ...
Optional parameter to force the language of the retrieved brand data.
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#name ⇒ String
Company name to retrieve brand data for (e.g., ‘Apple Inc’, ‘Microsoft Corporation’).
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name:, country_gl: nil, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandRetrieveByNameParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, country_gl: nil, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveByNameParams for more details.
|
|
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 46
|
Instance Attribute Details
#country_gl ⇒ Symbol, ...
Optional country code hint (GL parameter) to specify the country for the company name.
22 |
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 22 optional :country_gl, enum: -> { ContextDev::BrandRetrieveByNameParams::CountryGl } |
#force_language ⇒ Symbol, ...
Optional parameter to force the language of the retrieved brand data.
28 |
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 28 optional :force_language, enum: -> { ContextDev::BrandRetrieveByNameParams::ForceLanguage } |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
36 |
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 36 optional :max_speed, ContextDev::Internal::Type::Boolean |
#name ⇒ String
Company name to retrieve brand data for (e.g., ‘Apple Inc’, ‘Microsoft Corporation’). Must be 3-30 characters.
15 |
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 15 required :name, String |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
44 |
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 44 optional :timeout_ms, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_retrieve_by_name_params.rb', line 307
|