Class: ContextDev::Models::BrandRetrieveByTickerResponse::Brand
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveByTickerResponse::Brand
- Defined in:
- lib/context_dev/models/brand_retrieve_by_ticker_response.rb
Overview
Defined Under Namespace
Modules: PrimaryLanguage Classes: Address, Backdrop, Color, Industries, Links, Logo, Social, Stock
Instance Attribute Summary collapse
-
#address ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Address?
Physical address of the brand.
-
#backdrops ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Backdrop>?
An array of backdrop images for the brand.
-
#colors ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Color>?
An array of brand colors.
-
#description ⇒ String?
A brief description of the brand.
-
#domain ⇒ String?
The domain name of the brand.
-
#email ⇒ String?
Company email address.
-
#industries ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Industries?
Industry classification information for the brand.
-
#is_nsfw ⇒ Boolean?
Indicates whether the brand content is not safe for work (NSFW).
-
#links ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Links?
Important website links for the brand.
-
#logos ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Logo>?
An array of logos associated with the brand.
-
#phone ⇒ String?
Company phone number.
-
#primary_language ⇒ Symbol, ...
The primary language of the brand’s website content.
-
#slogan ⇒ String?
The brand’s slogan.
-
#socials ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Social>?
An array of social media links for the brand.
-
#stock ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock?
Stock market information for this brand (will be null if not a publicly traded company).
-
#title ⇒ String?
The title or name of the brand.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(blog: nil, careers: nil, contact: nil, pricing: nil, privacy: nil, terms: nil) ⇒ Object
constructor
Important website links for the brand.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(blog: nil, careers: nil, contact: nil, pricing: nil, privacy: nil, terms: nil) ⇒ Object
Important website links for the brand
|
|
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 138
|
Instance Attribute Details
#address ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Address?
Physical address of the brand
38 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 38 optional :address, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Address } |
#backdrops ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Backdrop>?
An array of backdrop images for the brand
44 45 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 44 optional :backdrops, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Backdrop] } |
#colors ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Color>?
An array of brand colors
51 52 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 51 optional :colors, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Color] } |
#description ⇒ String?
A brief description of the brand
58 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 58 optional :description, String |
#domain ⇒ String?
The domain name of the brand
64 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 64 optional :domain, String |
#email ⇒ String?
Company email address
70 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 70 optional :email, String |
#industries ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Industries?
Industry classification information for the brand
76 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 76 optional :industries, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Industries } |
#is_nsfw ⇒ Boolean?
Indicates whether the brand content is not safe for work (NSFW)
82 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 82 optional :is_nsfw, ContextDev::Internal::Type::Boolean |
#links ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Links?
Important website links for the brand
88 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 88 optional :links, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Links } |
#logos ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Logo>?
An array of logos associated with the brand
94 95 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 94 optional :logos, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Logo] } |
#phone ⇒ String?
Company phone number
101 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 101 optional :phone, String |
#primary_language ⇒ Symbol, ...
The primary language of the brand’s website content. Detected from the HTML lang tag, page content analysis, or social media descriptions.
108 109 110 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 108 optional :primary_language, enum: -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::PrimaryLanguage }, nil?: true |
#slogan ⇒ String?
The brand’s slogan
116 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 116 optional :slogan, String |
#socials ⇒ Array<ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Social>?
An array of social media links for the brand
122 123 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 122 optional :socials, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Social] } |
#stock ⇒ ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock?
Stock market information for this brand (will be null if not a publicly traded company)
130 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 130 optional :stock, -> { ContextDev::Models::BrandRetrieveByTickerResponse::Brand::Stock } |
#title ⇒ String?
The title or name of the brand
136 |
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 136 optional :title, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_retrieve_by_ticker_response.rb', line 631
|