Module: ContextDev::Models::BrandRetrieveParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs
Overview
Exactly one lookup type must be provided.
Defined Under Namespace
Classes: ByDirectURL, ByDomain, ByEmail, ByName, ByTicker, ByTransaction
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(ContextDev::Models::BrandRetrieveParams::Body::ByDomain, ContextDev::Models::BrandRetrieveParams::Body::ByName, ContextDev::Models::BrandRetrieveParams::Body::ByEmail, ContextDev::Models::BrandRetrieveParams::Body::ByTicker, ContextDev::Models::BrandRetrieveParams::Body::ByDirectURL, ContextDev::Models::BrandRetrieveParams::Body::ByTransaction)
Instance Method Summary collapse
-
#initialize(direct_url:, timeout_ms: nil, type: :by_direct_url) ⇒ Object
Some parameter documentations has been truncated, see ByDirectURL for more details.
- #self?.variants ⇒ ::Array[ContextDev::Models::BrandRetrieveParams::body]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 231
|
.variants ⇒ Array(ContextDev::Models::BrandRetrieveParams::Body::ByDomain, ContextDev::Models::BrandRetrieveParams::Body::ByName, ContextDev::Models::BrandRetrieveParams::Body::ByEmail, ContextDev::Models::BrandRetrieveParams::Body::ByTicker, ContextDev::Models::BrandRetrieveParams::Body::ByDirectURL, ContextDev::Models::BrandRetrieveParams::Body::ByTransaction)
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 1094
|
Instance Method Details
#initialize(direct_url:, timeout_ms: nil, type: :by_direct_url) ⇒ Object
Some parameter documentations has been truncated, see ByDirectURL for more details.
Retrieve brand data by fetching the provided URL directly. Note: if you use this, brand data is fetched only from the provided URL — not from the entire internet — so results are limited to what that single page contains. No domain resolution, database lookup, or cross-source enrichment is performed. Cannot be combined with domain, name, email, or ticker.
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 853
|
#self?.variants ⇒ ::Array[ContextDev::Models::BrandRetrieveParams::body]
1606 |
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 1606
def self?.variants: -> ::Array[ContextDev::Models::BrandRetrieveParams::body]
|