Class: ContextDev::Models::BrandRetrieveParams::Body::ByDomain
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveParams::Body::ByDomain
- Defined in:
- lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs
Defined Under Namespace
Modules: ForceLanguage
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain name to retrieve brand data for (e.g., 'stripe.com').
- #force_language ⇒ Symbol, ...
-
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh.
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#type ⇒ Symbol, :by_domain
Discriminator for domain-based brand retrieval.
Instance Method Summary collapse
-
#initialize(domain:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, type: :by_domain) ⇒ Object
constructor
Some parameter documentations has been truncated, see ByDomain for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, type: :by_domain) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByDomain for more details.
Retrieve brand data by domain. Cannot be combined with name, email, or ticker.
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 85
|
Instance Attribute Details
#domain ⇒ String
Domain name to retrieve brand data for (e.g., 'stripe.com').
47 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 47 required :domain, String |
#force_language ⇒ Symbol, ...
58 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 58 optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByDomain::ForceLanguage } |
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.
67 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 67 optional :max_age_ms, Integer, api_name: :maxAgeMs |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
75 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 75 optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
83 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 83 optional :timeout_ms, Integer, api_name: :timeoutMS |
#type ⇒ Symbol, :by_domain
Discriminator for domain-based brand retrieval.
53 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 53 required :type, const: :by_domain |
Instance Method Details
#to_hash ⇒ {
75 |
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 75
def to_hash: -> {
|