Class: ContextDev::Models::BrandRetrieveParams::Body::ByEmail

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs

Defined Under Namespace

Modules: ForceLanguage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, type: :by_email) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByEmail for more details.

Retrieve brand data by email address. The domain is extracted from the email. Free and disposable email providers are rejected with 422. Cannot be combined with domain, name, or ticker.

Parameters:

  • email (String)

    Email address to retrieve brand data for (e.g., 'jane@stripe.com').

  • force_language (Symbol, ContextDev::Models::BrandRetrieveParams::Body::ByEmail::ForceLanguage) (defaults to: nil)
  • max_age_ms (Integer) (defaults to: nil)

    Maximum age in milliseconds for cached brand data before the API performs a hard

  • max_speed (Boolean) (defaults to: nil)

    Optional parameter to optimize the API call for maximum speed. When set to true,

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • type (Symbol, :by_email) (defaults to: :by_email)

    Discriminator for email-based brand retrieval.



# File 'lib/context_dev/models/brand_retrieve_params.rb', line 477

Instance Attribute Details

#emailString

Email address to retrieve brand data for (e.g., 'jane@stripe.com').

Parameters:

  • value (String)

Returns:

  • (String)


439
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 439

required :email, String

#force_languageSymbol, ...



450
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 450

optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByEmail::ForceLanguage }

#max_age_msInteger?

Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


459
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 459

optional :max_age_ms, Integer, api_name: :maxAgeMs

#max_speedBoolean?

Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


467
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 467

optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


475
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 475

optional :timeout_ms, Integer, api_name: :timeoutMS

#typeSymbol, :by_email

Discriminator for email-based brand retrieval.

Parameters:

  • value (:by_email)

Returns:

  • (Symbol, :by_email)


445
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 445

required :type, const: :by_email

Instance Method Details

#to_hash{

Returns:

  • ({)


684
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 684

def to_hash: -> {