Class: ContextDev::Models::BrandRetrieveParams::Body::ByTicker
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveParams::Body::ByTicker
- Defined in:
- lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs
Defined Under Namespace
Modules: ForceLanguage
Instance Attribute Summary collapse
- #force_language ⇒ Symbol, ...
-
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh.
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#ticker ⇒ String
Stock ticker symbol to retrieve brand data for (e.g., 'AAPL').
-
#ticker_exchange ⇒ String?
Optional stock exchange for the ticker.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#type ⇒ Symbol, :by_ticker
Discriminator for ticker-based brand retrieval.
Instance Method Summary collapse
-
#initialize(ticker:, force_language: nil, max_age_ms: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, type: :by_ticker) ⇒ Object
constructor
Some parameter documentations has been truncated, see ByTicker for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ticker:, force_language: nil, max_age_ms: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, type: :by_ticker) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByTicker for more details.
Retrieve brand data by stock ticker. Cannot be combined with domain, name, or email.
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 676
|
Instance Attribute Details
#force_language ⇒ Symbol, ...
643 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 643 optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByTicker::ForceLanguage } |
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.
652 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 652 optional :max_age_ms, Integer, api_name: :maxAgeMs |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
660 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 660 optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed |
#ticker ⇒ String
Stock ticker symbol to retrieve brand data for (e.g., 'AAPL').
632 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 632 required :ticker, String |
#ticker_exchange ⇒ String?
Optional stock exchange for the ticker. Defaults to NASDAQ if not specified.
666 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 666 optional :ticker_exchange, String |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
674 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 674 optional :timeout_ms, Integer, api_name: :timeoutMS |
#type ⇒ Symbol, :by_ticker
Discriminator for ticker-based brand retrieval.
638 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 638 required :type, const: :by_ticker |
Instance Method Details
#to_hash ⇒ {
991 |
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 991
def to_hash: -> {
|