Class: ContextDev::Models::BrandRetrieveParams::Body::ByTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveParams::Body::ByTransaction
- Defined in:
- lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs
Defined Under Namespace
Modules: ForceLanguage, Mcc, Phone
Instance Attribute Summary collapse
-
#city ⇒ String?
Optional city name to prioritize when searching for the brand.
-
#country_gl ⇒ String?
Optional country code hint (GL parameter) to specify the country when identifying a transaction.
- #force_language ⇒ Symbol, ...
-
#high_confidence_only ⇒ Boolean?
When set to true, the API performs additional verification to ensure the identified brand matches the transaction with high confidence.
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#mcc ⇒ String, ...
Optional Merchant Category Code (MCC) to help identify the business category or industry.
-
#phone ⇒ String, ...
Optional phone number from the transaction to help verify brand match.
-
#tags ⇒ Array<String>?
Optional tags for tracking usage.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#transaction_info ⇒ String
Transaction information to identify the brand.
-
#type ⇒ Symbol, :by_transaction
Discriminator for transaction-based brand retrieval.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, tags: nil, timeout_ms: nil, type: :by_transaction) ⇒ Object
constructor
Some parameter documentations has been truncated, see ByTransaction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, tags: nil, timeout_ms: nil, type: :by_transaction) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByTransaction for more details.
Identify brand data from a transaction descriptor. Cannot be combined with domain, name, email, or ticker.
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 993
|
Instance Attribute Details
#city ⇒ String?
Optional city name to prioritize when searching for the brand.
935 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 935 optional :city, String |
#country_gl ⇒ String?
Optional country code hint (GL parameter) to specify the country when identifying a transaction.
942 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 942 optional :country_gl, String |
#force_language ⇒ Symbol, ...
947 948 949 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 947 optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByTransaction::ForceLanguage }, nil?: true |
#high_confidence_only ⇒ Boolean?
When set to true, the API performs additional verification to ensure the identified brand matches the transaction with high confidence.
956 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 956 optional :high_confidence_only, ContextDev::Internal::Type::Boolean |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
964 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 964 optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed |
#mcc ⇒ String, ...
Optional Merchant Category Code (MCC) to help identify the business category or industry.
971 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 971 optional :mcc, union: -> { ContextDev::BrandRetrieveParams::Body::ByTransaction::Mcc } |
#phone ⇒ String, ...
Optional phone number from the transaction to help verify brand match.
977 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 977 optional :phone, union: -> { ContextDev::BrandRetrieveParams::Body::ByTransaction::Phone } |
#tags ⇒ Array<String>?
Optional tags for tracking usage. Up to 20 tags, each 1 to 50 characters.
983 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 983 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
991 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 991 optional :timeout_ms, Integer, api_name: :timeoutMS |
#transaction_info ⇒ String
Transaction information to identify the brand.
923 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 923 required :transaction_info, String |
#type ⇒ Symbol, :by_transaction
Discriminator for transaction-based brand retrieval.
929 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 929 required :type, const: :by_transaction |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 1147
|
.variants ⇒ Array(String, Float)
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 1162
|
Instance Method Details
#to_hash ⇒ {
1372 |
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 1372
def to_hash: -> {
|