Class: ContextDev::Models::BrandRetrieveParams::Body::ByTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs

Defined Under Namespace

Modules: ForceLanguage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, type: :by_transaction) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByTransaction for more details.

Identify brand data from a transaction descriptor. Cannot be combined with domain, name, email, or ticker.

Parameters:

  • transaction_info (String)

    Transaction information to identify the brand.

  • city (String) (defaults to: nil)

    Optional city name to prioritize when searching for the brand.

  • country_gl (String) (defaults to: nil)

    Optional country code hint (GL parameter) to specify the country when identifyin

  • force_language (Symbol, ContextDev::Models::BrandRetrieveParams::Body::ByTransaction::ForceLanguage) (defaults to: nil)
  • high_confidence_only (Boolean) (defaults to: nil)

    When set to true, the API performs additional verification to ensure the identif

  • max_speed (Boolean) (defaults to: nil)

    Optional parameter to optimize the API call for maximum speed. When set to true,

  • mcc (Integer) (defaults to: nil)

    Optional Merchant Category Code (MCC) to help identify the business category or

  • phone (Float) (defaults to: nil)

    Optional phone number from the transaction to help verify brand match.

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • type (Symbol, :by_transaction) (defaults to: :by_transaction)

    Discriminator for transaction-based brand retrieval.



# File 'lib/context_dev/models/brand_retrieve_params.rb', line 894

Instance Attribute Details

#cityString?

Optional city name to prioritize when searching for the brand.

Parameters:

  • (String)

Returns:

  • (String, nil)


844
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 844

optional :city, String

#country_glString?

Optional country code hint (GL parameter) to specify the country when identifying a transaction.

Parameters:

  • (String)

Returns:

  • (String, nil)


851
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 851

optional :country_gl, String

#force_languageSymbol, ...



856
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 856

optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByTransaction::ForceLanguage }

#high_confidence_onlyBoolean?

When set to true, the API performs additional verification to ensure the identified brand matches the transaction with high confidence.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


863
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 863

optional :high_confidence_only, ContextDev::Internal::Type::Boolean

#max_speedBoolean?

Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


871
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 871

optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed

#mccInteger?

Optional Merchant Category Code (MCC) to help identify the business category or industry.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


878
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 878

optional :mcc, Integer

#phoneFloat?

Optional phone number from the transaction to help verify brand match.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


884
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 884

optional :phone, Float

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


892
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 892

optional :timeout_ms, Integer, api_name: :timeoutMS

#transaction_infoString

Transaction information to identify the brand.

Parameters:

  • value (String)

Returns:

  • (String)


832
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 832

required :transaction_info, String

#typeSymbol, :by_transaction

Discriminator for transaction-based brand retrieval.

Parameters:

  • value (:by_transaction)

Returns:

  • (Symbol, :by_transaction)


838
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 838

required :type, const: :by_transaction

Instance Method Details

#to_hash{

Returns:

  • ({)


1317
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 1317

def to_hash: -> {