Class: ContextDev::Models::BrandRetrieveParams::Body::ByTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveParams::Body::ByTransaction
- Defined in:
- lib/context_dev/models/brand_retrieve_params.rb,
sig/context_dev/models/brand_retrieve_params.rbs
Defined Under Namespace
Modules: ForceLanguage
Instance Attribute Summary collapse
-
#city ⇒ String?
Optional city name to prioritize when searching for the brand.
-
#country_gl ⇒ String?
Optional country code hint (GL parameter) to specify the country when identifying a transaction.
- #force_language ⇒ Symbol, ...
-
#high_confidence_only ⇒ Boolean?
When set to true, the API performs additional verification to ensure the identified brand matches the transaction with high confidence.
-
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed.
-
#mcc ⇒ Integer?
Optional Merchant Category Code (MCC) to help identify the business category or industry.
-
#phone ⇒ Float?
Optional phone number from the transaction to help verify brand match.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#transaction_info ⇒ String
Transaction information to identify the brand.
-
#type ⇒ Symbol, :by_transaction
Discriminator for transaction-based brand retrieval.
Instance Method Summary collapse
-
#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, type: :by_transaction) ⇒ Object
constructor
Some parameter documentations has been truncated, see ByTransaction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, type: :by_transaction) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveParams::Body::ByTransaction for more details.
Identify brand data from a transaction descriptor. Cannot be combined with domain, name, email, or ticker.
|
|
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 894
|
Instance Attribute Details
#city ⇒ String?
Optional city name to prioritize when searching for the brand.
844 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 844 optional :city, String |
#country_gl ⇒ String?
Optional country code hint (GL parameter) to specify the country when identifying a transaction.
851 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 851 optional :country_gl, String |
#force_language ⇒ Symbol, ...
856 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 856 optional :force_language, enum: -> { ContextDev::BrandRetrieveParams::Body::ByTransaction::ForceLanguage } |
#high_confidence_only ⇒ Boolean?
When set to true, the API performs additional verification to ensure the identified brand matches the transaction with high confidence.
863 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 863 optional :high_confidence_only, ContextDev::Internal::Type::Boolean |
#max_speed ⇒ Boolean?
Optional parameter to optimize the API call for maximum speed. When set to true, the API will skip time-consuming operations for faster response at the cost of less comprehensive data.
871 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 871 optional :max_speed, ContextDev::Internal::Type::Boolean, api_name: :maxSpeed |
#mcc ⇒ Integer?
Optional Merchant Category Code (MCC) to help identify the business category or industry.
878 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 878 optional :mcc, Integer |
#phone ⇒ Float?
Optional phone number from the transaction to help verify brand match.
884 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 884 optional :phone, Float |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
892 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 892 optional :timeout_ms, Integer, api_name: :timeoutMS |
#transaction_info ⇒ String
Transaction information to identify the brand.
832 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 832 required :transaction_info, String |
#type ⇒ Symbol, :by_transaction
Discriminator for transaction-based brand retrieval.
838 |
# File 'lib/context_dev/models/brand_retrieve_params.rb', line 838 required :type, const: :by_transaction |
Instance Method Details
#to_hash ⇒ {
1317 |
# File 'sig/context_dev/models/brand_retrieve_params.rbs', line 1317
def to_hash: -> {
|