Class: ContextDev::Models::BrandRetrieveSimplifiedParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandRetrieveSimplifiedParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/brand_retrieve_simplified_params.rb,
sig/context_dev/models/brand_retrieve_simplified_params.rbs
Overview
Defined Under Namespace
Modules: Theme
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain name to retrieve simplified brand data for.
-
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh.
-
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request.
-
#theme ⇒ Symbol, ...
Optional theme preference used when selecting brand assets.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(domain:, max_age_ms: nil, tags: nil, theme: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandRetrieveSimplifiedParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain:, max_age_ms: nil, tags: nil, theme: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandRetrieveSimplifiedParams for more details.
|
|
# File 'lib/context_dev/models/brand_retrieve_simplified_params.rb', line 47
|
Instance Attribute Details
#domain ⇒ String
Domain name to retrieve simplified brand data for
14 |
# File 'lib/context_dev/models/brand_retrieve_simplified_params.rb', line 14 required :domain, String |
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.
23 |
# File 'lib/context_dev/models/brand_retrieve_simplified_params.rb', line 23 optional :max_age_ms, Integer, nil?: true |
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.
31 |
# File 'lib/context_dev/models/brand_retrieve_simplified_params.rb', line 31 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#theme ⇒ Symbol, ...
Optional theme preference used when selecting brand assets.
37 |
# File 'lib/context_dev/models/brand_retrieve_simplified_params.rb', line 37 optional :theme, enum: -> { ContextDev::BrandRetrieveSimplifiedParams::Theme } |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
45 |
# File 'lib/context_dev/models/brand_retrieve_simplified_params.rb', line 45 optional :timeout_ms, Integer |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/context_dev/models/brand_retrieve_simplified_params.rbs', line 44
def to_hash: -> {
|