Class: ContextDev::Models::BrandSearchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/brand_search_params.rb,
sig/context_dev/models/brand_search_params.rbs

Overview

See Also:

  • ContextDev::Resources::Brand#search

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ContextDev

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(query:, tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::BrandSearchParams for more details.

Parameters:

  • query (String)

    Search term, matched against brand names and domains by prefix (e.g. 'nike', 'ni

  • tags (Array<String>) (defaults to: nil)

    Optional comma-separated caller-defined tags for tracking this request. Tags are

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/brand_search_params.rb', line 25

Instance Attribute Details

#queryString

Search term, matched against brand names and domains by prefix (e.g. 'nike', 'nike.com', 'nik').

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/context_dev/models/brand_search_params.rb', line 15

required :query, String

#tagsArray<String>?

Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


23
# File 'lib/context_dev/models/brand_search_params.rb', line 23

optional :tags, ContextDev::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


23
# File 'sig/context_dev/models/brand_search_params.rbs', line 23

def to_hash: -> {