Class: ContextDev::Models::BrandSearchParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandSearchParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/brand_search_params.rb,
sig/context_dev/models/brand_search_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#query ⇒ String
Search term, matched against brand names and domains by prefix (e.g. 'nike', 'nike.com', 'nik').
-
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(query:, tags: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandSearchParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(query:, tags: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::BrandSearchParams for more details.
|
|
# File 'lib/context_dev/models/brand_search_params.rb', line 25
|
Instance Attribute Details
#query ⇒ String
Search term, matched against brand names and domains by prefix (e.g. 'nike', 'nike.com', 'nik').
15 |
# File 'lib/context_dev/models/brand_search_params.rb', line 15 required :query, String |
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.
23 |
# File 'lib/context_dev/models/brand_search_params.rb', line 23 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/context_dev/models/brand_search_params.rbs', line 23
def to_hash: -> {
|