Class: ContextDev::Models::BrandSearchResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::BrandSearchResponse
- Defined in:
- lib/context_dev/models/brand_search_response.rb,
sig/context_dev/models/brand_search_response.rbs
Overview
Defined Under Namespace
Classes: KeyMetadata, Result
Instance Attribute Summary collapse
-
#key_metadata ⇒ ContextDev::Models::BrandSearchResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#results ⇒ Array<ContextDev::Models::BrandSearchResponse::Result>
Up to 10 matching brands, most popular first.
Instance Method Summary collapse
-
#initialize(domain:, logo:, name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Result for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain:, logo:, name:) ⇒ Object
Some parameter documentations has been truncated, see Result for more details.
|
|
# File 'lib/context_dev/models/brand_search_response.rb', line 49
|
Instance Attribute Details
#key_metadata ⇒ ContextDev::Models::BrandSearchResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
19 |
# File 'lib/context_dev/models/brand_search_response.rb', line 19 optional :key_metadata, -> { ContextDev::Models::BrandSearchResponse::KeyMetadata } |
#results ⇒ Array<ContextDev::Models::BrandSearchResponse::Result>
Up to 10 matching brands, most popular first. Empty when nothing matches.
11 12 |
# File 'lib/context_dev/models/brand_search_response.rb', line 11 required :results, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::BrandSearchResponse::Result] } |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/context_dev/models/brand_search_response.rbs', line 23
def to_hash: -> {
|