Class: ContextDev::Models::IndustryRetrieveNaicsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::IndustryRetrieveNaicsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/industry_retrieve_naics_params.rb,
sig/context_dev/models/industry_retrieve_naics_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#input ⇒ String
Brand domain or title to retrieve NAICS code for.
-
#max_results ⇒ Integer?
Maximum number of NAICS codes to return.
-
#min_results ⇒ Integer?
Minimum number of NAICS codes to return.
-
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(input:, max_results: nil, min_results: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see IndustryRetrieveNaicsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input:, max_results: nil, min_results: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::IndustryRetrieveNaicsParams for more details.
|
|
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 47
|
Instance Attribute Details
#input ⇒ String
Brand domain or title to retrieve NAICS code for. If a valid domain is provided, it will be used for classification, otherwise, we will search for the brand using the provided title.
16 |
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 16 required :input, String |
#max_results ⇒ Integer?
Maximum number of NAICS codes to return. Must be between 1 and 10. Defaults to 5.
23 |
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 23 optional :max_results, Integer |
#min_results ⇒ Integer?
Minimum number of NAICS codes to return. Must be at least 1. Defaults to 1.
29 |
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 29 optional :min_results, Integer |
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.
37 |
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 37 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
45 |
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 45 optional :timeout_ms, Integer |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/context_dev/models/industry_retrieve_naics_params.rbs', line 44
def to_hash: -> {
|