Class: ContextDev::Models::IndustryRetrieveNaicsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/industry_retrieve_naics_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, max_results: nil, min_results: nil, timeout_ms: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::IndustryRetrieveNaicsParams for more details.

Parameters:

  • input (String)

    Brand domain or title to retrieve NAICS code for. If a valid domain is provided,

  • max_results (Integer) (defaults to: nil)

    Maximum number of NAICS codes to return. Must be between 1 and 10. Defaults to 5

  • min_results (Integer) (defaults to: nil)

    Minimum number of NAICS codes to return. Must be at least 1. Defaults to 1.

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 39

Instance Attribute Details

#inputString

Brand domain or title to retrieve NAICS code for. If a valid domain is provided, it will be used for classification, otherwise, we will search for the brand using the provided title.

Returns:

  • (String)


16
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 16

required :input, String

#max_resultsInteger?

Maximum number of NAICS codes to return. Must be between 1 and 10. Defaults to 5.

Returns:

  • (Integer, nil)


23
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 23

optional :max_results, Integer

#min_resultsInteger?

Minimum number of NAICS codes to return. Must be at least 1. Defaults to 1.

Returns:

  • (Integer, nil)


29
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 29

optional :min_results, Integer

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Returns:

  • (Integer, nil)


37
# File 'lib/context_dev/models/industry_retrieve_naics_params.rb', line 37

optional :timeout_ms, Integer