Class: ContextDev::Models::IndustryRetrieveSicResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::IndustryRetrieveSicResponse
- Defined in:
- lib/context_dev/models/industry_retrieve_sic_response.rb
Overview
Defined Under Namespace
Modules: Classification Classes: Code
Instance Attribute Summary collapse
-
#classification ⇒ Symbol, ...
Echoes back which SIC dataset was used to classify the brand.
-
#codes ⇒ Array<ContextDev::Models::IndustryRetrieveSicResponse::Code>?
Array of SIC codes with confidence scores.
-
#domain ⇒ String?
Domain found for the brand.
-
#status ⇒ String?
Status of the response, e.g., ‘ok’.
-
#type ⇒ String?
Industry classification type, for sic api it will be ‘sic`.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(classification: nil, codes: nil, domain: nil, status: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see IndustryRetrieveSicResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(classification: nil, codes: nil, domain: nil, status: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::IndustryRetrieveSicResponse for more details.
|
|
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 40
|
Instance Attribute Details
#classification ⇒ Symbol, ...
Echoes back which SIC dataset was used to classify the brand.
11 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 11 optional :classification, enum: -> { ContextDev::Models::IndustryRetrieveSicResponse::Classification } |
#codes ⇒ Array<ContextDev::Models::IndustryRetrieveSicResponse::Code>?
Array of SIC codes with confidence scores. Extra fields depend on the requested classification: ‘original_sic` results include `majorGroup` and `majorGroupName`; `latest_sec` results include `office`.
19 20 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 19 optional :codes, -> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::IndustryRetrieveSicResponse::Code] } |
#domain ⇒ String?
Domain found for the brand
26 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 26 optional :domain, String |
#status ⇒ String?
Status of the response, e.g., ‘ok’
32 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 32 optional :status, String |
#type ⇒ String?
Industry classification type, for sic api it will be ‘sic`
38 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 38 optional :type, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 63
|