Class: ContextDev::Models::IndustryRetrieveSicResponse::Code
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::IndustryRetrieveSicResponse::Code
- Defined in:
- lib/context_dev/models/industry_retrieve_sic_response.rb
Defined Under Namespace
Modules: Confidence
Instance Attribute Summary collapse
-
#code ⇒ String
SIC code (4-digit).
-
#confidence ⇒ Symbol, ContextDev::Models::IndustryRetrieveSicResponse::Code::Confidence
Confidence level for how well this SIC code matches the company description.
-
#major_group ⇒ String?
2-digit major group identifier (the leading two digits of the code).
-
#major_group_name ⇒ String?
Description of the 2-digit major group.
-
#name ⇒ String
SIC industry title.
-
#office ⇒ String?
SEC review office responsible for filings under this code.
Instance Method Summary collapse
-
#initialize(code:, confidence:, name:, major_group: nil, major_group_name: nil, office: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Code for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, confidence:, name:, major_group: nil, major_group_name: nil, office: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::IndustryRetrieveSicResponse::Code for more details.
|
|
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 107
|
Instance Attribute Details
#code ⇒ String
SIC code (4-digit).
72 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 72 required :code, String |
#confidence ⇒ Symbol, ContextDev::Models::IndustryRetrieveSicResponse::Code::Confidence
Confidence level for how well this SIC code matches the company description.
78 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 78 required :confidence, enum: -> { ContextDev::Models::IndustryRetrieveSicResponse::Code::Confidence } |
#major_group ⇒ String?
2-digit major group identifier (the leading two digits of the code). Only present when ‘classification` is `original_sic`.
91 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 91 optional :major_group, String, api_name: :majorGroup |
#major_group_name ⇒ String?
Description of the 2-digit major group. Only present when ‘classification` is `original_sic`.
98 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 98 optional :major_group_name, String, api_name: :majorGroupName |
#name ⇒ String
SIC industry title.
84 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 84 required :name, String |
#office ⇒ String?
SEC review office responsible for filings under this code. Only present when ‘classification` is `latest_sec`.
105 |
# File 'lib/context_dev/models/industry_retrieve_sic_response.rb', line 105 optional :office, String |