Class: ContextDev::Models::MonitorCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/monitor_create_params.rb,
sig/context_dev/models/monitor_create_params.rbs
Overview
Defined Under Namespace
Modules: ChangeDetection, Mode, Target Classes: Schedule, Webhook
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#change_detection ⇒ ContextDev::Models::MonitorCreateParams::ChangeDetection::Exact, ...
Discriminated union describing how changes are detected.
-
#mode ⇒ Symbol, ...
Top-level monitor category.
- #name ⇒ String
-
#schedule ⇒ ContextDev::Models::MonitorCreateParams::Schedule?
Run the monitor on a fixed interval defined by a frequency and a unit, e.g.
-
#tags ⇒ Array<String>?
User-defined tags for grouping and filtering monitors and their changes.
-
#target ⇒ ContextDev::Models::MonitorCreateParams::Target::Page, ...
Discriminated union describing what the monitor watches.
- #webhook ⇒ ContextDev::Models::MonitorCreateParams::Webhook?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(ContextDev::Models::MonitorCreateParams::ChangeDetection::Exact, ContextDev::Models::MonitorCreateParams::ChangeDetection::Semantic)
Instance Method Summary collapse
-
#initialize(confidence_threshold: nil, type: :semantic) ⇒ Object
constructor
Detect meaning-level changes to page content, ignoring cosmetic or instruction-irrelevant differences.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(confidence_threshold: nil, type: :semantic) ⇒ Object
Detect meaning-level changes to page content, ignoring cosmetic or
instruction-irrelevant differences. Which changes are meaningful is judged
against the page or extract target's instructions (and an extract target's
schema, when provided).
|
|
# File 'lib/context_dev/models/monitor_create_params.rb', line 54
|
Instance Attribute Details
#change_detection ⇒ ContextDev::Models::MonitorCreateParams::ChangeDetection::Exact, ...
Discriminated union describing how changes are detected.
25 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 25 optional :change_detection, union: -> { ContextDev::MonitorCreateParams::ChangeDetection } |
#mode ⇒ Symbol, ...
Top-level monitor category. Always web today; the concrete behavior is
described by target and change_detection.
32 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 32 optional :mode, enum: -> { ContextDev::MonitorCreateParams::Mode } |
#name ⇒ String
13 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 13 required :name, String |
#schedule ⇒ ContextDev::Models::MonitorCreateParams::Schedule?
Run the monitor on a fixed interval defined by a frequency and a unit, e.g. every 6 hours or every 2 days. The total interval (frequency × unit) must be between 10 minutes and 1 year.
40 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 40 optional :schedule, -> { ContextDev::MonitorCreateParams::Schedule } |
#tags ⇒ Array<String>?
User-defined tags for grouping and filtering monitors and their changes. Duplicates are removed.
47 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 47 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#target ⇒ ContextDev::Models::MonitorCreateParams::Target::Page, ...
Discriminated union describing what the monitor watches.
19 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 19 required :target, union: -> { ContextDev::MonitorCreateParams::Target } |
#webhook ⇒ ContextDev::Models::MonitorCreateParams::Webhook?
52 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 52 optional :webhook, -> { ContextDev::MonitorCreateParams::Webhook }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/monitor_create_params.rb', line 312
|
.variants ⇒ Array(ContextDev::Models::MonitorCreateParams::ChangeDetection::Exact, ContextDev::Models::MonitorCreateParams::ChangeDetection::Semantic)
|
|
# File 'lib/context_dev/models/monitor_create_params.rb', line 251
|
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/context_dev/models/monitor_create_params.rbs', line 58
def to_hash: -> {
|