Class: ContextDev::Models::MonitorCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/monitor_create_params.rb,
sig/context_dev/models/monitor_create_params.rbs
Overview
Defined Under Namespace
Modules: ChangeDetection, Mode, Target Classes: Schedule, Webhook
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#change_detection ⇒ ContextDev::Models::MonitorCreateParams::ChangeDetection::Exact, ContextDev::Models::MonitorCreateParams::ChangeDetection::Semantic
Discriminated union describing how changes are detected.
-
#mode ⇒ Symbol, ...
Top-level monitor category.
- #name ⇒ String
-
#schedule ⇒ ContextDev::Models::MonitorCreateParams::Schedule
Run the monitor on a fixed interval defined by a frequency and a unit, e.g.
-
#tags ⇒ Array<String>?
User-defined tags for grouping and filtering monitors and their changes.
-
#target ⇒ ContextDev::Models::MonitorCreateParams::Target::Page, ...
Discriminated union describing what the monitor watches.
- #webhook ⇒ ContextDev::Models::MonitorCreateParams::Webhook?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(ContextDev::Models::MonitorCreateParams::Target::Page, ContextDev::Models::MonitorCreateParams::Target::Sitemap, ContextDev::Models::MonitorCreateParams::Target::Extract)
Instance Method Summary collapse
-
#initialize(url:, follow_subdomains: nil, instructions: nil, max_depth: nil, max_pages: nil, schema: nil, type: :extract) ⇒ Object
constructor
Some parameter documentations has been truncated, see Target::Extract for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, follow_subdomains: nil, instructions: nil, max_depth: nil, max_pages: nil, schema: nil, type: :extract) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::MonitorCreateParams::Target::Extract for more details.
Watch a site's extracted structured data.
|
|
# File 'lib/context_dev/models/monitor_create_params.rb', line 53
|
Instance Attribute Details
#change_detection ⇒ ContextDev::Models::MonitorCreateParams::ChangeDetection::Exact, ContextDev::Models::MonitorCreateParams::ChangeDetection::Semantic
Discriminated union describing how changes are detected.
14 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 14 required :change_detection, union: -> { ContextDev::MonitorCreateParams::ChangeDetection } |
#mode ⇒ Symbol, ...
Top-level monitor category. Always web today; the concrete behavior is
described by target and change_detection.
40 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 40 optional :mode, enum: -> { ContextDev::MonitorCreateParams::Mode } |
#name ⇒ String
19 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 19 required :name, String |
#schedule ⇒ ContextDev::Models::MonitorCreateParams::Schedule
Run the monitor on a fixed interval defined by a frequency and a unit, e.g. every 6 hours or every 2 days. The total interval (frequency × unit) must be between 10 minutes and 1 year.
27 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 27 required :schedule, -> { ContextDev::MonitorCreateParams::Schedule } |
#tags ⇒ Array<String>?
User-defined tags for grouping and filtering monitors and their changes.
46 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 46 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#target ⇒ ContextDev::Models::MonitorCreateParams::Target::Page, ...
Discriminated union describing what the monitor watches.
33 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 33 required :target, union: -> { ContextDev::MonitorCreateParams::Target } |
#webhook ⇒ ContextDev::Models::MonitorCreateParams::Webhook?
51 |
# File 'lib/context_dev/models/monitor_create_params.rb', line 51 optional :webhook, -> { ContextDev::MonitorCreateParams::Webhook }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/monitor_create_params.rb', line 177
|
.variants ⇒ Array(ContextDev::Models::MonitorCreateParams::Target::Page, ContextDev::Models::MonitorCreateParams::Target::Sitemap, ContextDev::Models::MonitorCreateParams::Target::Extract)
|
|
# File 'lib/context_dev/models/monitor_create_params.rb', line 122
|
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/context_dev/models/monitor_create_params.rbs', line 50
def to_hash: -> {
|