Class: ContextDev::Models::MonitorListAccountChangesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorListAccountChangesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/monitor_list_account_changes_params.rb,
sig/context_dev/models/monitor_list_account_changes_params.rbs
Overview
Defined Under Namespace
Modules: ChangeDetectionType, TargetType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#change_detection_type ⇒ Symbol, ...
Filter by change detection type.
-
#cursor ⇒ String?
Opaque pagination cursor from a previous response.
-
#limit ⇒ Integer?
Maximum number of items to return per page (1-100).
-
#monitor_id ⇒ String?
Filter changes to a single monitor.
-
#since ⇒ Time?
Only include items at or after this ISO 8601 timestamp.
-
#tag ⇒ String?
Filter to items that have this tag.
-
#target_type ⇒ Symbol, ...
Filter by target type.
-
#until_ ⇒ Time?
Only include items before this ISO 8601 timestamp.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(change_detection_type: nil, cursor: nil, limit: nil, monitor_id: nil, since: nil, tag: nil, target_type: nil, until_: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(change_detection_type: nil, cursor: nil, limit: nil, monitor_id: nil, since: nil, tag: nil, target_type: nil, until_: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 59
|
Instance Attribute Details
#change_detection_type ⇒ Symbol, ...
Filter by change detection type.
14 15 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 14 optional :change_detection_type, enum: -> { ContextDev::MonitorListAccountChangesParams::ChangeDetectionType } |
#cursor ⇒ String?
Opaque pagination cursor from a previous response.
21 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 21 optional :cursor, String |
#limit ⇒ Integer?
Maximum number of items to return per page (1-100). Defaults to 25.
27 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 27 optional :limit, Integer |
#monitor_id ⇒ String?
Filter changes to a single monitor.
33 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 33 optional :monitor_id, String |
#since ⇒ Time?
Only include items at or after this ISO 8601 timestamp.
39 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 39 optional :since, Time |
#tag ⇒ String?
Filter to items that have this tag.
45 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 45 optional :tag, String |
#target_type ⇒ Symbol, ...
Filter by target type.
51 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 51 optional :target_type, enum: -> { ContextDev::MonitorListAccountChangesParams::TargetType } |
#until_ ⇒ Time?
Only include items before this ISO 8601 timestamp.
57 |
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 57 optional :until_, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/monitor_list_account_changes_params.rb', line 85
|
Instance Method Details
#to_hash ⇒ {
68 |
# File 'sig/context_dev/models/monitor_list_account_changes_params.rbs', line 68
def to_hash: -> {
|