Class: ContextDev::Models::MonitorListAccountChangesResponse::Data
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/context_dev/models/monitor_list_account_changes_response.rb,
sig/context_dev/models/monitor_list_account_changes_response.rbs
Defined Under Namespace
Modules: ChangeDetectionType, Importance, Mode, TargetType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, change_detection_type:, detected_at:, mode:, monitor_id:, summary:, target_type:, title:, url:, added_url_count: nil, confidence: nil, importance: nil, matched_url_count: nil, removed_url_count: nil, tags: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, change_detection_type:, detected_at:, mode:, monitor_id:, summary:, target_type:, title:, url:, added_url_count: nil, confidence: nil, importance: nil, matched_url_count: nil, removed_url_count: nil, tags: nil) ⇒ Object
Some parameter documentations has been truncated, see
ContextDev::Models::MonitorListAccountChangesResponse::Data for more details.
A lightweight change summary. mode is the constant web; target_type and
change_detection_type describe the change, and which optional fields are
present depends on them (e.g. sitemap changes include
added_url_count/removed_url_count; semantic changes include
confidence/importance).
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 28
class Data < ContextDev::Internal::Type::BaseModel
required :id, String
required :change_detection_type,
enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType }
required :detected_at, Time
required :mode, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode }
required :monitor_id, String
required :summary, String
required :target_type,
enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType }
required :title, String
required :url, String
optional :added_url_count, Integer
optional :confidence, Float
optional :importance, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Importance }
optional :matched_url_count, Integer
optional :removed_url_count, Integer
optional :tags, ContextDev::Internal::Type::ArrayOf[String]
module ChangeDetectionType
extend ContextDev::Internal::Type::Enum
EXACT = :exact
SEMANTIC = :semantic
end
module Mode
extend ContextDev::Internal::Type::Enum
WEB = :web
end
module TargetType
extend ContextDev::Internal::Type::Enum
PAGE = :page
SITEMAP = :sitemap
EXTRACT = :extract
end
module Importance
extend ContextDev::Internal::Type::Enum
LOW = :low
MEDIUM = :medium
HIGH = :high
end
end
|
Instance Attribute Details
#added_url_count ⇒ Integer?
81
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 81
optional :added_url_count, Integer
|
37
38
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 37
required :change_detection_type,
enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::ChangeDetectionType }
|
#confidence ⇒ Float?
86
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 86
optional :confidence, Float
|
#detected_at ⇒ Time
43
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 43
required :detected_at, Time
|
#id ⇒ String
32
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 32
required :id, String
|
#importance ⇒ Symbol, ...
91
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 91
optional :importance, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Importance }
|
#matched_url_count ⇒ Integer?
96
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 96
optional :matched_url_count, Integer
|
Top-level monitor category. Always web today; the concrete behavior is
described by target and change_detection.
50
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 50
required :mode, enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::Mode }
|
#monitor_id ⇒ String
55
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 55
required :monitor_id, String
|
#removed_url_count ⇒ Integer?
101
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 101
optional :removed_url_count, Integer
|
#summary ⇒ String
60
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 60
required :summary, String
|
User-defined tags for grouping and filtering monitors and their changes.
107
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 107
optional :tags, ContextDev::Internal::Type::ArrayOf[String]
|
65
66
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 65
required :target_type,
enum: -> { ContextDev::Models::MonitorListAccountChangesResponse::Data::TargetType }
|
#title ⇒ String
71
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 71
required :title, String
|
#url ⇒ String
76
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 76
required :url, String
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/context_dev/models/monitor_list_account_changes_response.rb', line 156
|
Instance Method Details
#to_hash ⇒ {
111
|
# File 'sig/context_dev/models/monitor_list_account_changes_response.rbs', line 111
def to_hash: -> {
|