Class: ContextDev::Models::MonitorListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/monitor_list_params.rb,
sig/context_dev/models/monitor_list_params.rbs
Overview
Defined Under Namespace
Modules: ChangeDetectionType, SearchBy, SearchType, Status, TargetType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
- #change_detection_type ⇒ Symbol, ...
- #cursor ⇒ String?
- #limit ⇒ Integer?
-
#q ⇒ String?
Free-text search term, matched against the fields named in
search_by. -
#search_by ⇒ Array<Symbol, ContextDev::Models::MonitorListParams::SearchBy>?
Comma-separated fields to search with
q. -
#search_type ⇒ Symbol, ...
prefixfor as-you-type prefix matching (default),exactfor full-token matching. -
#status ⇒ Symbol, ...
Monitor lifecycle status.
-
#tag ⇒ String?
Filter to items that have this tag.
-
#tags ⇒ Array<String>?
Comma-separated list of tags to filter by (matches monitors having any of them).
- #target_type ⇒ Symbol, ...
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
72 |
# File 'sig/context_dev/models/monitor_list_params.rbs', line 72
def initialize: (
|
Instance Attribute Details
#change_detection_type ⇒ Symbol, ...
13 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 13 optional :change_detection_type, enum: -> { ContextDev::MonitorListParams::ChangeDetectionType } |
#cursor ⇒ String?
18 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 18 optional :cursor, String |
#limit ⇒ Integer?
23 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 23 optional :limit, Integer |
#q ⇒ String?
Free-text search term, matched against the fields named in search_by.
29 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 29 optional :q, String |
#search_by ⇒ Array<Symbol, ContextDev::Models::MonitorListParams::SearchBy>?
Comma-separated fields to search with q. Defaults to all of them. Note query
only exists on semantic monitors.
36 37 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 36 optional :search_by, -> { ContextDev::Internal::Type::ArrayOf[enum: ContextDev::MonitorListParams::SearchBy] } |
#search_type ⇒ Symbol, ...
prefix for as-you-type prefix matching (default), exact for full-token
matching.
44 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 44 optional :search_type, enum: -> { ContextDev::MonitorListParams::SearchType } |
#status ⇒ Symbol, ...
Monitor lifecycle status. failed means the most recent run failed (see the
monitor's last_error); failed monitors keep running on schedule and flip back
to active on the next successful run. Monitors are auto-paused after
repeated consecutive failures or insufficient-credit skips; resume by PATCHing
status to active.
54 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 54 optional :status, enum: -> { ContextDev::MonitorListParams::Status } |
#tag ⇒ String?
Filter to items that have this tag.
60 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 60 optional :tag, String |
#tags ⇒ Array<String>?
Comma-separated list of tags to filter by (matches monitors having any of them).
66 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 66 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#target_type ⇒ Symbol, ...
71 |
# File 'lib/context_dev/models/monitor_list_params.rb', line 71 optional :target_type, enum: -> { ContextDev::MonitorListParams::TargetType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/monitor_list_params.rb', line 105
|
Instance Method Details
#to_hash ⇒ {
86 |
# File 'sig/context_dev/models/monitor_list_params.rbs', line 86
def to_hash: -> {
|