Class: ContextDev::Models::MonitorListResponse::Data::Target::Extract
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorListResponse::Data::Target::Extract
- Defined in:
- lib/context_dev/models/monitor_list_response.rb,
sig/context_dev/models/monitor_list_response.rbs
Instance Attribute Summary collapse
- #follow_subdomains ⇒ Boolean?
-
#instructions ⇒ String?
Optional natural-language instructions guiding what to extract.
-
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
-
#max_pages ⇒ Integer?
Maximum number of pages to analyze during extraction.
-
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the structured data to extract and watch for changes.
- #type ⇒ Symbol, :extract
-
#url ⇒ String
Root URL to extract structured data from.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
344 |
# File 'sig/context_dev/models/monitor_list_response.rbs', line 344
def initialize: (
|
Instance Attribute Details
#follow_subdomains ⇒ Boolean?
404 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 404 optional :follow_subdomains, ContextDev::Internal::Type::Boolean |
#instructions ⇒ String?
Optional natural-language instructions guiding what to extract.
410 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 410 optional :instructions, String |
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
416 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 416 optional :max_depth, Integer |
#max_pages ⇒ Integer?
Maximum number of pages to analyze during extraction.
422 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 422 optional :max_pages, Integer |
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the structured data to extract and watch for changes. If omitted, a default summary + key-points schema is used.
429 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 429 optional :schema, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#type ⇒ Symbol, :extract
393 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 393 required :type, const: :extract |
#url ⇒ String
Root URL to extract structured data from.
399 |
# File 'lib/context_dev/models/monitor_list_response.rb', line 399 required :url, String |
Instance Method Details
#to_hash ⇒ {
354 |
# File 'sig/context_dev/models/monitor_list_response.rbs', line 354
def to_hash: -> {
|