Class: ContextDev::Models::MonitorRetrieveChangeResponse
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/context_dev/models/monitor_retrieve_change_response.rb,
sig/context_dev/models/monitor_retrieve_change_response.rbs
Overview
Defined Under Namespace
Modules: ChangeDetectionType, Importance, Mode, TargetType
Classes: Evidence
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after:, before:, url: nil) ⇒ Object
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 137
|
Instance Attribute Details
#added_url_count ⇒ Integer?
64
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 64
optional :added_url_count, Integer
|
#added_urls ⇒ Array<String>?
At most 500 URLs are included; the corresponding count field is always exact.
70
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 70
optional :added_urls, ContextDev::Internal::Type::ArrayOf[String]
|
#after_text_excerpt ⇒ String?
75
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 75
optional :after_text_excerpt, String
|
#before_text_excerpt ⇒ String?
80
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 80
optional :before_text_excerpt, String
|
15
16
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 15
required :change_detection_type,
enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::ChangeDetectionType }
|
#confidence ⇒ Float?
85
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 85
optional :confidence, Float
|
#detected_at ⇒ Time
21
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 21
required :detected_at, Time
|
#diff ⇒ String?
Text diff between the previous and current page baseline (page targets).
91
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 91
optional :diff, String
|
96
97
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 96
optional :evidence,
-> { ContextDev::Internal::Type::ArrayOf[ContextDev::Models::MonitorRetrieveChangeResponse::Evidence] }
|
#id ⇒ String
10
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 10
required :id, String
|
#importance ⇒ Symbol, ...
102
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 102
optional :importance, enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::Importance }
|
#matched_url_count ⇒ Integer?
107
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 107
optional :matched_url_count, Integer
|
#matched_urls ⇒ Array<String>?
At most 500 URLs are included; the corresponding count field is always exact.
113
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 113
optional :matched_urls, ContextDev::Internal::Type::ArrayOf[String]
|
Top-level monitor category. Always web today; the concrete behavior is
described by target and change_detection.
28
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 28
required :mode, enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::Mode }
|
#monitor_id ⇒ String
33
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 33
required :monitor_id, String
|
#query ⇒ String?
118
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 118
optional :query, String
|
#removed_url_count ⇒ Integer?
123
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 123
optional :removed_url_count, Integer
|
#removed_urls ⇒ Array<String>?
At most 500 URLs are included; the corresponding count field is always exact.
129
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 129
optional :removed_urls, ContextDev::Internal::Type::ArrayOf[String]
|
#run_id ⇒ String
The run that detected this change.
39
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 39
required :run_id, String
|
#summary ⇒ String
44
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 44
required :summary, String
|
User-defined tags for grouping and filtering monitors and their changes.
135
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 135
optional :tags, ContextDev::Internal::Type::ArrayOf[String]
|
49
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 49
required :target_type, enum: -> { ContextDev::Models::MonitorRetrieveChangeResponse::TargetType }
|
#title ⇒ String
54
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 54
required :title, String
|
#url ⇒ String
59
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 59
required :url, String
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/context_dev/models/monitor_retrieve_change_response.rb', line 202
|
Instance Method Details
#to_hash ⇒ {
139
|
# File 'sig/context_dev/models/monitor_retrieve_change_response.rbs', line 139
def to_hash: -> {
|