Class: ContextDev::Models::MonitorUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/monitor_update_params.rb,
sig/context_dev/models/monitor_update_params.rbs
Overview
Defined Under Namespace
Modules: ChangeDetection, Status, Target Classes: Schedule, Webhook
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#change_detection ⇒ ContextDev::Models::MonitorUpdateParams::ChangeDetection::Exact, ...
Discriminated union describing how changes are detected.
- #monitor_id ⇒ String
- #name ⇒ String?
-
#schedule ⇒ ContextDev::Models::MonitorUpdateParams::Schedule?
Run the monitor on a fixed interval defined by a frequency and a unit, e.g.
- #status ⇒ Symbol, ...
-
#tags ⇒ Array<String>?
User-defined tags for grouping and filtering monitors and their changes.
-
#target ⇒ ContextDev::Models::MonitorUpdateParams::Target::Page, ...
Discriminated union describing what the monitor watches.
-
#webhook ⇒ ContextDev::Models::MonitorUpdateParams::Webhook?
Set to null to remove the webhook.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(ContextDev::Models::MonitorUpdateParams::Target::Page, ContextDev::Models::MonitorUpdateParams::Target::Sitemap, ContextDev::Models::MonitorUpdateParams::Target::Extract)
Instance Method Summary collapse
-
#initialize(url:, follow_subdomains: nil, instructions: nil, max_depth: nil, max_pages: nil, schema: nil, type: :extract) ⇒ Object
constructor
Some parameter documentations has been truncated, see Target::Extract for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, follow_subdomains: nil, instructions: nil, max_depth: nil, max_pages: nil, schema: nil, type: :extract) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::MonitorUpdateParams::Target::Extract for more details.
Watch a site's extracted structured data.
|
|
# File 'lib/context_dev/models/monitor_update_params.rb', line 57
|
Instance Attribute Details
#change_detection ⇒ ContextDev::Models::MonitorUpdateParams::ChangeDetection::Exact, ...
Discriminated union describing how changes are detected.
19 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 19 optional :change_detection, union: -> { ContextDev::MonitorUpdateParams::ChangeDetection } |
#monitor_id ⇒ String
13 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 13 required :monitor_id, String |
#name ⇒ String?
24 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 24 optional :name, String |
#schedule ⇒ ContextDev::Models::MonitorUpdateParams::Schedule?
Run the monitor on a fixed interval defined by a frequency and a unit, e.g. every 6 hours or every 2 days. The total interval (frequency × unit) must be between 10 minutes and 1 year.
32 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 32 optional :schedule, -> { ContextDev::MonitorUpdateParams::Schedule } |
#status ⇒ Symbol, ...
37 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 37 optional :status, enum: -> { ContextDev::MonitorUpdateParams::Status } |
#tags ⇒ Array<String>?
User-defined tags for grouping and filtering monitors and their changes.
43 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 43 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#target ⇒ ContextDev::Models::MonitorUpdateParams::Target::Page, ...
Discriminated union describing what the monitor watches.
49 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 49 optional :target, union: -> { ContextDev::MonitorUpdateParams::Target } |
#webhook ⇒ ContextDev::Models::MonitorUpdateParams::Webhook?
Set to null to remove the webhook.
55 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 55 optional :webhook, -> { ContextDev::MonitorUpdateParams::Webhook }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/monitor_update_params.rb', line 183
|
.variants ⇒ Array(ContextDev::Models::MonitorUpdateParams::Target::Page, ContextDev::Models::MonitorUpdateParams::Target::Sitemap, ContextDev::Models::MonitorUpdateParams::Target::Extract)
|
|
# File 'lib/context_dev/models/monitor_update_params.rb', line 128
|
Instance Method Details
#to_hash ⇒ {
68 |
# File 'sig/context_dev/models/monitor_update_params.rbs', line 68
def to_hash: -> {
|