Class: ContextDev::Models::MonitorUpdateParams::Target::Extract
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::MonitorUpdateParams::Target::Extract
- Defined in:
- lib/context_dev/models/monitor_update_params.rb,
sig/context_dev/models/monitor_update_params.rbs
Instance Attribute Summary collapse
- #follow_subdomains ⇒ Boolean?
-
#instructions ⇒ String
Natural-language instructions guiding which pages and facts to track and which changes to report.
-
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
-
#max_pages ⇒ Integer?
Maximum number of pages to track.
-
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the data you care about.
- #type ⇒ Symbol, :extract
-
#url ⇒ String
Root URL to extract structured data from.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
286 |
# File 'sig/context_dev/models/monitor_update_params.rbs', line 286
def initialize: (
|
Instance Attribute Details
#follow_subdomains ⇒ Boolean?
306 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 306 optional :follow_subdomains, ContextDev::Internal::Type::Boolean |
#instructions ⇒ String
Natural-language instructions guiding which pages and facts to track and which changes to report.
290 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 290 required :instructions, String |
#max_depth ⇒ Integer?
Optional maximum link depth from the starting URL (0 = only the starting page).
312 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 312 optional :max_depth, Integer |
#max_pages ⇒ Integer?
Maximum number of pages to track.
318 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 318 optional :max_pages, Integer |
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema describing the data you care about. It guides which pages are selected for tracking and gives the change judge context on what matters. If omitted, a default summary + key-points schema is used.
326 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 326 optional :schema, ContextDev::Internal::Type::HashOf[ContextDev::Internal::Type::Unknown] |
#type ⇒ Symbol, :extract
295 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 295 required :type, const: :extract |
#url ⇒ String
Root URL to extract structured data from.
301 |
# File 'lib/context_dev/models/monitor_update_params.rb', line 301 required :url, String |
Instance Method Details
#to_hash ⇒ {
296 |
# File 'sig/context_dev/models/monitor_update_params.rbs', line 296
def to_hash: -> {
|