Class: ContextDev::Models::NewsSearchParams::SearchBy::Entity::Ticker
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::NewsSearchParams::SearchBy::Entity::Ticker
- Defined in:
- lib/context_dev/models/news_search_params.rb,
sig/context_dev/models/news_search_params.rbs
Defined Under Namespace
Modules: Exchange
Instance Attribute Summary collapse
-
#exchange ⇒ Symbol, ...
Stock exchange the ticker trades on, used to disambiguate tickers listed on multiple exchanges.
-
#ticker ⇒ String
Public-company ticker.
- #type ⇒ Symbol, :ticker
Instance Method Summary collapse
-
#initialize(ticker:, exchange: nil, type: :ticker) ⇒ Object
constructor
Some parameter documentations has been truncated, see Ticker for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ticker:, exchange: nil, type: :ticker) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::NewsSearchParams::SearchBy::Entity::Ticker for more details.
Identify the company by stock ticker, optionally scoped to an exchange.
|
|
# File 'lib/context_dev/models/news_search_params.rb', line 160
|
Instance Attribute Details
#exchange ⇒ Symbol, ...
Stock exchange the ticker trades on, used to disambiguate tickers listed on multiple exchanges.
158 |
# File 'lib/context_dev/models/news_search_params.rb', line 158 optional :exchange, enum: -> { ContextDev::NewsSearchParams::SearchBy::Entity::Ticker::Exchange } |
#ticker ⇒ String
Public-company ticker.
146 |
# File 'lib/context_dev/models/news_search_params.rb', line 146 required :ticker, String |
#type ⇒ Symbol, :ticker
151 |
# File 'lib/context_dev/models/news_search_params.rb', line 151 required :type, const: :ticker |
Instance Method Details
#to_hash ⇒ {
140 |
# File 'sig/context_dev/models/news_search_params.rbs', line 140
def to_hash: -> {
|