Module: ContextDev::Models::ParseHandleParams::Ocr
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/context_dev/models/parse_handle_params.rb,
sig/context_dev/models/parse_handle_params.rbs
Overview
When true for PDF inputs, detect and OCR images embedded in the selected pages, inserting recognized text at each image's position in page reading order while preserving the PDF text layer. pdf.start/pdf.end limit the inclusive page range. When false, all OCR is disabled, including the automatic scanned-PDF fallback.
collapse
- TRUE =
:true- FALSE =
:false
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Boolean, Symbol)
258 259 260 |
# File 'lib/context_dev/models/parse_handle_params.rb', line 258 define_sorbet_constant!(:Variants) do T.type_alias { T.any(T::Boolean, ContextDev::ParseHandleParams::Ocr::TaggedSymbol) } end |
Instance Method Details
#self?.variants ⇒ ::Array[ContextDev::Models::ParseHandleParams::ocr]
287 |
# File 'sig/context_dev/models/parse_handle_params.rbs', line 287
def self?.variants: -> ::Array[ContextDev::Models::ParseHandleParams::ocr]
|