Class: ContextDev::Models::WebExtractCompetitorsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractCompetitorsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_extract_competitors_params.rb,
sig/context_dev/models/web_extract_competitors_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#domain ⇒ String
Company domain to analyze, such as
stripe.com. -
#num_competitors ⇒ Integer?
Exact number of direct competitors to return.
-
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(domain:, num_competitors: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebExtractCompetitorsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain:, num_competitors: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractCompetitorsParams for more details.
|
|
# File 'lib/context_dev/models/web_extract_competitors_params.rb', line 39
|
Instance Attribute Details
#domain ⇒ String
Company domain to analyze, such as stripe.com. Full http(s) URLs are accepted
and normalized to their domain.
15 |
# File 'lib/context_dev/models/web_extract_competitors_params.rb', line 15 required :domain, String |
#num_competitors ⇒ Integer?
Exact number of direct competitors to return. Defaults to 5.
21 |
# File 'lib/context_dev/models/web_extract_competitors_params.rb', line 21 optional :num_competitors, Integer |
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.
29 |
# File 'lib/context_dev/models/web_extract_competitors_params.rb', line 29 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
37 |
# File 'lib/context_dev/models/web_extract_competitors_params.rb', line 37 optional :timeout_ms, Integer |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/context_dev/models/web_extract_competitors_params.rbs', line 38
def to_hash: -> {
|