Class: ContextDev::Models::WebExtractCompetitorsResponse::Target

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_extract_competitors_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_name:, field:, field_description:, website_url:) ⇒ Object

Target company profile inferred from the landing page.

Parameters:

  • company_name (String)

    Company or product name inferred from the landing page.

  • field (String)

    Specific operating field, product category, or market.

  • field_description (String)

    One-sentence description of what the target company sells and who it serves.

  • website_url (String)

    Resolved URL used for the landing page analysis.



# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 144

Instance Attribute Details

#company_nameString

Company or product name inferred from the landing page.

Returns:

  • (String)


124
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 124

required :company_name, String, api_name: :companyName

#fieldString

Specific operating field, product category, or market.

Returns:

  • (String)


130
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 130

required :field, String

#field_descriptionString

One-sentence description of what the target company sells and who it serves.

Returns:

  • (String)


136
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 136

required :field_description, String, api_name: :fieldDescription

#website_urlString

Resolved URL used for the landing page analysis.

Returns:

  • (String)


142
# File 'lib/context_dev/models/web_extract_competitors_response.rb', line 142

required :website_url, String, api_name: :websiteUrl