Class: ContextDev::Models::WebExtractFontsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/web_extract_fonts_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(direct_url: nil, domain: nil, timeout_ms: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebExtractFontsParams for more details.

Parameters:

  • direct_url (String) (defaults to: nil)

    A specific URL to fetch fonts from directly, bypassing domain resolution (e.g.,

  • domain (String) (defaults to: nil)

    Domain name to extract fonts from (e.g., ‘example.com’, ‘google.com’). The domai

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 34

Instance Attribute Details

#direct_urlString?

A specific URL to fetch fonts from directly, bypassing domain resolution (e.g., ‘example.com/design-system’). When provided, fonts are extracted from this exact URL. You must provide either ‘domain’ or ‘directUrl’, but not both.

Returns:

  • (String, nil)


16
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 16

optional :direct_url, String

#domainString?

Domain name to extract fonts from (e.g., ‘example.com’, ‘google.com’). The domain will be automatically normalized and validated. You must provide either ‘domain’ or ‘directUrl’, but not both.

Returns:

  • (String, nil)


24
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 24

optional :domain, String

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Returns:

  • (Integer, nil)


32
# File 'lib/context_dev/models/web_extract_fonts_params.rb', line 32

optional :timeout_ms, Integer