Class: ContextDev::Models::WebExtractFontsResponse::Font
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractFontsResponse::Font
- Defined in:
- lib/context_dev/models/web_extract_fonts_response.rb
Instance Attribute Summary collapse
-
#fallbacks ⇒ Array<String>
Array of fallback font families.
-
#font ⇒ String
Font family name.
-
#num_elements ⇒ Float
Number of elements using this font.
-
#num_words ⇒ Float
Number of words using this font.
-
#percent_elements ⇒ Float
Percentage of elements using this font.
-
#percent_words ⇒ Float
Percentage of words using this font.
-
#uses ⇒ Array<String>
Array of CSS selectors or element types where this font is used.
Instance Method Summary collapse
-
#initialize(code:, domain:, fonts:, status:, font_links: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractFontsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, domain:, fonts:, status:, font_links: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractFontsResponse for more details.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 56 class Font < ContextDev::Internal::Type::BaseModel # @!attribute fallbacks # Array of fallback font families # # @return [Array<String>] required :fallbacks, ContextDev::Internal::Type::ArrayOf[String] # @!attribute font # Font family name # # @return [String] required :font, String # @!attribute num_elements # Number of elements using this font # # @return [Float] required :num_elements, Float # @!attribute num_words # Number of words using this font # # @return [Float] required :num_words, Float # @!attribute percent_elements # Percentage of elements using this font # # @return [Float] required :percent_elements, Float # @!attribute percent_words # Percentage of words using this font # # @return [Float] required :percent_words, Float # @!attribute uses # Array of CSS selectors or element types where this font is used # # @return [Array<String>] required :uses, ContextDev::Internal::Type::ArrayOf[String] # @!method initialize(fallbacks:, font:, num_elements:, num_words:, percent_elements:, percent_words:, uses:) # @param fallbacks [Array<String>] Array of fallback font families # # @param font [String] Font family name # # @param num_elements [Float] Number of elements using this font # # @param num_words [Float] Number of words using this font # # @param percent_elements [Float] Percentage of elements using this font # # @param percent_words [Float] Percentage of words using this font # # @param uses [Array<String>] Array of CSS selectors or element types where this font is used end |
Instance Attribute Details
#fallbacks ⇒ Array<String>
Array of fallback font families
61 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 61 required :fallbacks, ContextDev::Internal::Type::ArrayOf[String] |
#font ⇒ String
Font family name
67 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 67 required :font, String |
#num_elements ⇒ Float
Number of elements using this font
73 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 73 required :num_elements, Float |
#num_words ⇒ Float
Number of words using this font
79 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 79 required :num_words, Float |
#percent_elements ⇒ Float
Percentage of elements using this font
85 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 85 required :percent_elements, Float |
#percent_words ⇒ Float
Percentage of words using this font
91 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 91 required :percent_words, Float |
#uses ⇒ Array<String>
Array of CSS selectors or element types where this font is used
97 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 97 required :uses, ContextDev::Internal::Type::ArrayOf[String] |