Class: ContextDev::Models::WebExtractFontsResponse::Font
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractFontsResponse::Font
- Defined in:
- lib/context_dev/models/web_extract_fonts_response.rb
Instance Attribute Summary collapse
-
#fallbacks ⇒ Array<String>
Array of fallback font families.
-
#font ⇒ String
Font family name.
-
#num_elements ⇒ Float
Number of elements using this font.
-
#num_words ⇒ Float
Number of words using this font.
-
#percent_elements ⇒ Float
Percentage of elements using this font.
-
#percent_words ⇒ Float
Percentage of words using this font.
-
#uses ⇒ Array<String>
Array of CSS selectors or element types where this font is used.
Instance Method Summary collapse
- #initialize(fallbacks:, font:, num_elements:, num_words:, percent_elements:, percent_words:, uses:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(fallbacks:, font:, num_elements:, num_words:, percent_elements:, percent_words:, uses:) ⇒ Object
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 41 class Font < ContextDev::Internal::Type::BaseModel # @!attribute fallbacks # Array of fallback font families # # @return [Array<String>] required :fallbacks, ContextDev::Internal::Type::ArrayOf[String] # @!attribute font # Font family name # # @return [String] required :font, String # @!attribute num_elements # Number of elements using this font # # @return [Float] required :num_elements, Float # @!attribute num_words # Number of words using this font # # @return [Float] required :num_words, Float # @!attribute percent_elements # Percentage of elements using this font # # @return [Float] required :percent_elements, Float # @!attribute percent_words # Percentage of words using this font # # @return [Float] required :percent_words, Float # @!attribute uses # Array of CSS selectors or element types where this font is used # # @return [Array<String>] required :uses, ContextDev::Internal::Type::ArrayOf[String] # @!method initialize(fallbacks:, font:, num_elements:, num_words:, percent_elements:, percent_words:, uses:) # @param fallbacks [Array<String>] Array of fallback font families # # @param font [String] Font family name # # @param num_elements [Float] Number of elements using this font # # @param num_words [Float] Number of words using this font # # @param percent_elements [Float] Percentage of elements using this font # # @param percent_words [Float] Percentage of words using this font # # @param uses [Array<String>] Array of CSS selectors or element types where this font is used end |
Instance Attribute Details
#fallbacks ⇒ Array<String>
Array of fallback font families
46 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 46 required :fallbacks, ContextDev::Internal::Type::ArrayOf[String] |
#font ⇒ String
Font family name
52 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 52 required :font, String |
#num_elements ⇒ Float
Number of elements using this font
58 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 58 required :num_elements, Float |
#num_words ⇒ Float
Number of words using this font
64 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 64 required :num_words, Float |
#percent_elements ⇒ Float
Percentage of elements using this font
70 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 70 required :percent_elements, Float |
#percent_words ⇒ Float
Percentage of words using this font
76 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 76 required :percent_words, Float |
#uses ⇒ Array<String>
Array of CSS selectors or element types where this font is used
82 |
# File 'lib/context_dev/models/web_extract_fonts_response.rb', line 82 required :uses, ContextDev::Internal::Type::ArrayOf[String] |