Class: ContextDev::Models::WebExtractParams::Pdf
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractParams::Pdf
- Defined in:
- lib/context_dev/models/web_extract_params.rb,
sig/context_dev/models/web_extract_params.rbs
Instance Attribute Summary collapse
-
#end_ ⇒ Integer?
Last 1-based PDF page to parse.
-
#should_parse ⇒ Boolean?
When true, PDF pages are fetched and parsed.
-
#start ⇒ Integer?
First 1-based PDF page to parse.
Instance Method Summary collapse
-
#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Pdf for more details.
- #to_hash ⇒ { end_: Integer, should_parse: bool, start: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractParams::Pdf for more details.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/context_dev/models/web_extract_params.rb', line 152 class Pdf < ContextDev::Internal::Type::BaseModel # @!attribute end_ # Last 1-based PDF page to parse. Must be greater than or equal to start when both # are provided. # # @return [Integer, nil] optional :end_, Integer, api_name: :end # @!attribute should_parse # When true, PDF pages are fetched and parsed. When false, PDF pages are skipped. # # @return [Boolean, nil] optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse # @!attribute start # First 1-based PDF page to parse. # # @return [Integer, nil] optional :start, Integer # @!method initialize(end_: nil, should_parse: nil, start: nil) # Some parameter documentations has been truncated, see # {ContextDev::Models::WebExtractParams::Pdf} for more details. # # @param end_ [Integer] Last 1-based PDF page to parse. Must be greater than or equal to start when both # # @param should_parse [Boolean] When true, PDF pages are fetched and parsed. When false, PDF pages are skipped. # # @param start [Integer] First 1-based PDF page to parse. end |
Instance Attribute Details
#end_ ⇒ Integer?
Last 1-based PDF page to parse. Must be greater than or equal to start when both are provided.
158 |
# File 'lib/context_dev/models/web_extract_params.rb', line 158 optional :end_, Integer, api_name: :end |
#should_parse ⇒ Boolean?
When true, PDF pages are fetched and parsed. When false, PDF pages are skipped.
164 |
# File 'lib/context_dev/models/web_extract_params.rb', line 164 optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse |
#start ⇒ Integer?
First 1-based PDF page to parse.
170 |
# File 'lib/context_dev/models/web_extract_params.rb', line 170 optional :start, Integer |
Instance Method Details
#to_hash ⇒ { end_: Integer, should_parse: bool, start: Integer }
144 |
# File 'sig/context_dev/models/web_extract_params.rbs', line 144
def to_hash: -> { end_: Integer, should_parse: bool, start: Integer }
|