Class: ContextDev::Models::WebExtractParams::Pdf

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_extract_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebExtractParams::Pdf for more details.

Parameters:

  • end_ (Integer) (defaults to: nil)

    Last 1-based PDF page to parse. Must be greater than or equal to start when both

  • should_parse (Boolean) (defaults to: nil)

    When true, PDF pages are fetched and parsed. When false, PDF pages are skipped.

  • start (Integer) (defaults to: nil)

    First 1-based PDF page to parse.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/context_dev/models/web_extract_params.rb', line 116

class Pdf < ContextDev::Internal::Type::BaseModel
  # @!attribute end_
  #   Last 1-based PDF page to parse. Must be greater than or equal to start when both
  #   are provided.
  #
  #   @return [Integer, nil]
  optional :end_, Integer, api_name: :end

  # @!attribute should_parse
  #   When true, PDF pages are fetched and parsed. When false, PDF pages are skipped.
  #
  #   @return [Boolean, nil]
  optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse

  # @!attribute start
  #   First 1-based PDF page to parse.
  #
  #   @return [Integer, nil]
  optional :start, Integer

  # @!method initialize(end_: nil, should_parse: nil, start: nil)
  #   Some parameter documentations has been truncated, see
  #   {ContextDev::Models::WebExtractParams::Pdf} for more details.
  #
  #   @param end_ [Integer] Last 1-based PDF page to parse. Must be greater than or equal to start when both
  #
  #   @param should_parse [Boolean] When true, PDF pages are fetched and parsed. When false, PDF pages are skipped.
  #
  #   @param start [Integer] First 1-based PDF page to parse.
end

Instance Attribute Details

#end_Integer?

Last 1-based PDF page to parse. Must be greater than or equal to start when both are provided.

Returns:

  • (Integer, nil)


122
# File 'lib/context_dev/models/web_extract_params.rb', line 122

optional :end_, Integer, api_name: :end

#should_parseBoolean?

When true, PDF pages are fetched and parsed. When false, PDF pages are skipped.

Returns:

  • (Boolean, nil)


128
# File 'lib/context_dev/models/web_extract_params.rb', line 128

optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse

#startInteger?

First 1-based PDF page to parse.

Returns:

  • (Integer, nil)


134
# File 'lib/context_dev/models/web_extract_params.rb', line 134

optional :start, Integer