Class: ContextDev::Models::WebExtractStyleguideParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebExtractStyleguideParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_extract_styleguide_params.rb,
sig/context_dev/models/web_extract_styleguide_params.rbs
Overview
Defined Under Namespace
Modules: ColorScheme
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#color_scheme ⇒ Symbol, ...
Optional browser color scheme to emulate for websites that respond to prefers-color-scheme.
-
#direct_url ⇒ String?
A specific URL to fetch the styleguide from directly, bypassing domain resolution (e.g., 'https://example.com/design-system').
-
#domain ⇒ String?
Domain name to extract styleguide from (e.g., 'example.com', 'google.com').
-
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh.
-
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(color_scheme: nil, direct_url: nil, domain: nil, max_age_ms: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebExtractStyleguideParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(color_scheme: nil, direct_url: nil, domain: nil, max_age_ms: nil, tags: nil, timeout_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebExtractStyleguideParams for more details.
|
|
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 59
|
Instance Attribute Details
#color_scheme ⇒ Symbol, ...
Optional browser color scheme to emulate for websites that respond to prefers-color-scheme. This value is part of the styleguide cache key.
15 |
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 15 optional :color_scheme, enum: -> { ContextDev::WebExtractStyleguideParams::ColorScheme } |
#direct_url ⇒ String?
A specific URL to fetch the styleguide from directly, bypassing domain resolution (e.g., 'https://example.com/design-system'). When provided, the styleguide is extracted from this exact URL. You must provide either 'domain' or 'directUrl', but not both.
24 |
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 24 optional :direct_url, String |
#domain ⇒ String?
Domain name to extract styleguide from (e.g., 'example.com', 'google.com'). The domain will be automatically normalized and validated. You must provide either 'domain' or 'directUrl', but not both.
32 |
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 32 optional :domain, String |
#max_age_ms ⇒ Integer?
Maximum age in milliseconds for cached brand data before the API performs a hard refresh. Defaults to 3 months (7776000000 ms). Values below 1 day (86400000 ms) are clamped to 1 day; values above 1 year (31536000000 ms) are clamped to 1 year.
41 |
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 41 optional :max_age_ms, Integer, nil?: true |
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.
49 |
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 49 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
57 |
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 57 optional :timeout_ms, Integer |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/context_dev/models/web_extract_styleguide_params.rbs', line 52
def to_hash: -> {
|