Class: ContextDev::Models::WebExtractStyleguideParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/web_extract_styleguide_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(direct_url: nil, domain: nil, timeout_ms: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebExtractStyleguideParams for more details.

Parameters:

  • direct_url (String) (defaults to: nil)

    A specific URL to fetch the styleguide from directly, bypassing domain resolutio

  • domain (String) (defaults to: nil)

    Domain name to extract styleguide from (e.g., ‘example.com’, ‘google.com’). The

  • timeout_ms (Integer) (defaults to: nil)

    Optional timeout in milliseconds for the request. If the request takes longer th

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 35

Instance Attribute Details

#direct_urlString?

A specific URL to fetch the styleguide from directly, bypassing domain resolution (e.g., ‘example.com/design-system’). When provided, the styleguide is extracted from this exact URL. You must provide either ‘domain’ or ‘directUrl’, but not both.

Returns:

  • (String, nil)


17
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 17

optional :direct_url, String

#domainString?

Domain name to extract styleguide from (e.g., ‘example.com’, ‘google.com’). The domain will be automatically normalized and validated. You must provide either ‘domain’ or ‘directUrl’, but not both.

Returns:

  • (String, nil)


25
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 25

optional :domain, String

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Returns:

  • (Integer, nil)


33
# File 'lib/context_dev/models/web_extract_styleguide_params.rb', line 33

optional :timeout_ms, Integer