Class: ContextDev::Models::WebScreenshotParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebScreenshotParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_screenshot_params.rb
Overview
Defined Under Namespace
Modules: FullScreenshot, Page Classes: Viewport
Instance Attribute Summary collapse
-
#direct_url ⇒ String?
A specific URL to screenshot directly, bypassing domain resolution (e.g., ‘example.com/pricing’).
-
#domain ⇒ String?
Domain name to take screenshot of (e.g., ‘example.com’, ‘google.com’).
-
#full_screenshot ⇒ Symbol, ...
Optional parameter to determine screenshot type.
-
#max_age_ms ⇒ Integer?
Return a cached screenshot if a prior screenshot for the same parameters exists and is younger than this many milliseconds.
-
#page ⇒ Symbol, ...
Optional parameter to specify which page type to screenshot.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#viewport ⇒ ContextDev::Models::WebScreenshotParams::Viewport?
Optional browser viewport dimensions for the screenshot.
-
#wait_for_ms ⇒ Integer?
Optional browser wait time in milliseconds after initial page load before taking the screenshot.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(direct_url: nil, domain: nil, full_screenshot: nil, max_age_ms: nil, page: nil, timeout_ms: nil, viewport: nil, wait_for_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebScreenshotParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(direct_url: nil, domain: nil, full_screenshot: nil, max_age_ms: nil, page: nil, timeout_ms: nil, viewport: nil, wait_for_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebScreenshotParams for more details.
|
|
# File 'lib/context_dev/models/web_screenshot_params.rb', line 74
|
Instance Attribute Details
#direct_url ⇒ String?
A specific URL to screenshot directly, bypassing domain resolution (e.g., ‘example.com/pricing’). When provided, the screenshot is taken of this exact URL. You must provide either ‘domain’ or ‘directUrl’, but not both.
16 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 16 optional :direct_url, String |
#domain ⇒ String?
Domain name to take screenshot of (e.g., ‘example.com’, ‘google.com’). The domain will be automatically normalized and validated. You must provide either ‘domain’ or ‘directUrl’, but not both.
24 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 24 optional :domain, String |
#full_screenshot ⇒ Symbol, ...
Optional parameter to determine screenshot type. If ‘true’, takes a full page screenshot capturing all content. If ‘false’ or not provided, takes a viewport screenshot (standard browser view).
32 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 32 optional :full_screenshot, enum: -> { ContextDev::WebScreenshotParams::FullScreenshot } |
#max_age_ms ⇒ Integer?
Return a cached screenshot if a prior screenshot for the same parameters exists and is younger than this many milliseconds. Defaults to 1 day (86400000 ms) when omitted. Max is 30 days (2592000000 ms). Set to 0 to always capture fresh.
40 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 40 optional :max_age_ms, Integer |
#page ⇒ Symbol, ...
Optional parameter to specify which page type to screenshot. If provided, the system will scrape the domain’s links and use heuristics to find the most appropriate URL for the specified page type (30 supported languages). If not provided, screenshots the main domain landing page. Only applicable when using ‘domain’, not ‘directUrl’.
50 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 50 optional :page, enum: -> { ContextDev::WebScreenshotParams::Page } |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
58 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 58 optional :timeout_ms, Integer |
#viewport ⇒ ContextDev::Models::WebScreenshotParams::Viewport?
Optional browser viewport dimensions for the screenshot. Defaults to 1920x1080.
64 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 64 optional :viewport, -> { ContextDev::WebScreenshotParams::Viewport } |
#wait_for_ms ⇒ Integer?
Optional browser wait time in milliseconds after initial page load before taking the screenshot. Min: 0. Max: 30000 (30 seconds). Defaults to 3000 ms when omitted.
72 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 72 optional :wait_for_ms, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/web_screenshot_params.rb', line 105
|