Class: ContextDev::Models::WebScreenshotParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/web_screenshot_params.rb

Overview

Defined Under Namespace

Modules: FullScreenshot, Page, Prioritize Classes: Viewport

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(direct_url: nil, domain: nil, full_screenshot: nil, max_age_ms: nil, page: nil, prioritize: nil, viewport: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebScreenshotParams for more details.

Parameters:

  • direct_url (String) (defaults to: nil)

    A specific URL to screenshot directly, bypassing domain resolution (e.g., ‘https

  • domain (String) (defaults to: nil)

    Domain name to take screenshot of (e.g., ‘example.com’, ‘google.com’). The domai

  • full_screenshot (Symbol, ContextDev::Models::WebScreenshotParams::FullScreenshot) (defaults to: nil)

    Optional parameter to determine screenshot type. If ‘true’, takes a full page sc

  • max_age_ms (Integer) (defaults to: nil)

    Return a cached screenshot if a prior screenshot for the same parameters exists

  • page (Symbol, ContextDev::Models::WebScreenshotParams::Page) (defaults to: nil)

    Optional parameter to specify which page type to screenshot. If provided, the sy

  • prioritize (Symbol, ContextDev::Models::WebScreenshotParams::Prioritize) (defaults to: nil)

    Optional parameter to prioritize screenshot capture. If ‘speed’, optimizes for f

  • viewport (ContextDev::Models::WebScreenshotParams::Viewport) (defaults to: nil)

    Optional browser viewport dimensions for the screenshot. Defaults to 1920x1080.

  • request_options (ContextDev::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/context_dev/models/web_screenshot_params.rb', line 66

Instance Attribute Details

#direct_urlString?

A specific URL to screenshot directly, bypassing domain resolution (e.g., ‘example.com/pricing’). When provided, the screenshot is taken of this exact URL. You must provide either ‘domain’ or ‘directUrl’, but not both.

Returns:

  • (String, nil)


16
# File 'lib/context_dev/models/web_screenshot_params.rb', line 16

optional :direct_url, String

#domainString?

Domain name to take screenshot of (e.g., ‘example.com’, ‘google.com’). The domain will be automatically normalized and validated. You must provide either ‘domain’ or ‘directUrl’, but not both.

Returns:

  • (String, nil)


24
# File 'lib/context_dev/models/web_screenshot_params.rb', line 24

optional :domain, String

#full_screenshotSymbol, ...

Optional parameter to determine screenshot type. If ‘true’, takes a full page screenshot capturing all content. If ‘false’ or not provided, takes a viewport screenshot (standard browser view).



32
# File 'lib/context_dev/models/web_screenshot_params.rb', line 32

optional :full_screenshot, enum: -> { ContextDev::WebScreenshotParams::FullScreenshot }

#max_age_msInteger?

Return a cached screenshot if a prior screenshot for the same parameters exists and is younger than this many milliseconds. Defaults to 1 day (86400000 ms) when omitted. Max is 30 days (2592000000 ms). Set to 0 to always capture fresh.

Returns:

  • (Integer, nil)


40
# File 'lib/context_dev/models/web_screenshot_params.rb', line 40

optional :max_age_ms, Integer

#pageSymbol, ...

Optional parameter to specify which page type to screenshot. If provided, the system will scrape the domain’s links and use heuristics to find the most appropriate URL for the specified page type (30 supported languages). If not provided, screenshots the main domain landing page. Only applicable when using ‘domain’, not ‘directUrl’.



50
# File 'lib/context_dev/models/web_screenshot_params.rb', line 50

optional :page, enum: -> { ContextDev::WebScreenshotParams::Page }

#prioritizeSymbol, ...

Optional parameter to prioritize screenshot capture. If ‘speed’, optimizes for faster capture with basic quality. If ‘quality’, optimizes for higher quality with longer wait times. Defaults to ‘quality’ if not provided.



58
# File 'lib/context_dev/models/web_screenshot_params.rb', line 58

optional :prioritize, enum: -> { ContextDev::WebScreenshotParams::Prioritize }

#viewportContextDev::Models::WebScreenshotParams::Viewport?

Optional browser viewport dimensions for the screenshot. Defaults to 1920x1080.



64
# File 'lib/context_dev/models/web_screenshot_params.rb', line 64

optional :viewport, -> { ContextDev::WebScreenshotParams::Viewport }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/context_dev/models/web_screenshot_params.rb', line 95