Class: ContextDev::Models::WebScreenshotParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebScreenshotParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_screenshot_params.rb
Overview
Defined Under Namespace
Modules: FullScreenshot, Page, Prioritize
Instance Attribute Summary collapse
-
#direct_url ⇒ String?
A specific URL to screenshot directly, bypassing domain resolution (e.g., ‘example.com/pricing’).
-
#domain ⇒ String?
Domain name to take screenshot of (e.g., ‘example.com’, ‘google.com’).
-
#full_screenshot ⇒ Symbol, ...
Optional parameter to determine screenshot type.
-
#page ⇒ Symbol, ...
Optional parameter to specify which page type to screenshot.
-
#prioritize ⇒ Symbol, ...
Optional parameter to prioritize screenshot capture.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(direct_url: nil, domain: nil, full_screenshot: nil, page: nil, prioritize: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebScreenshotParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(direct_url: nil, domain: nil, full_screenshot: nil, page: nil, prioritize: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebScreenshotParams for more details.
|
|
# File 'lib/context_dev/models/web_screenshot_params.rb', line 52
|
Instance Attribute Details
#direct_url ⇒ String?
A specific URL to screenshot directly, bypassing domain resolution (e.g., ‘example.com/pricing’). When provided, the screenshot is taken of this exact URL. You must provide either ‘domain’ or ‘directUrl’, but not both.
16 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 16 optional :direct_url, String |
#domain ⇒ String?
Domain name to take screenshot of (e.g., ‘example.com’, ‘google.com’). The domain will be automatically normalized and validated. You must provide either ‘domain’ or ‘directUrl’, but not both.
24 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 24 optional :domain, String |
#full_screenshot ⇒ Symbol, ...
Optional parameter to determine screenshot type. If ‘true’, takes a full page screenshot capturing all content. If ‘false’ or not provided, takes a viewport screenshot (standard browser view).
32 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 32 optional :full_screenshot, enum: -> { ContextDev::WebScreenshotParams::FullScreenshot } |
#page ⇒ Symbol, ...
Optional parameter to specify which page type to screenshot. If provided, the system will scrape the domain’s links and use heuristics to find the most appropriate URL for the specified page type (30 supported languages). If not provided, screenshots the main domain landing page. Only applicable when using ‘domain’, not ‘directUrl’.
42 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 42 optional :page, enum: -> { ContextDev::WebScreenshotParams::Page } |
#prioritize ⇒ Symbol, ...
Optional parameter to prioritize screenshot capture. If ‘speed’, optimizes for faster capture with basic quality. If ‘quality’, optimizes for higher quality with longer wait times. Defaults to ‘quality’ if not provided.
50 |
# File 'lib/context_dev/models/web_screenshot_params.rb', line 50 optional :prioritize, enum: -> { ContextDev::WebScreenshotParams::Prioritize } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/context_dev/models/web_screenshot_params.rb', line 77
|