Module: ContextDev::Models::WebScreenshotParams::Page

Extended by:
Internal::Type::Enum
Defined in:
lib/context_dev/models/web_screenshot_params.rb

Overview

Optional parameter to specify which page type to screenshot. If provided, the system will scrape the domain’s links and use heuristics to find the most appropriate URL for the specified page type (30 supported languages). If not provided, screenshots the main domain landing page. Only applicable when using ‘domain’, not ‘directUrl’.

Constant Summary collapse

LOGIN =
:login
SIGNUP =
:signup
BLOG =
:blog
CAREERS =
:careers
PRICING =
:pricing
TERMS =
:terms
PRIVACY =
:privacy
CONTACT =
:contact

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info