Class: ContextDev::Models::WebScreenshotResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_screenshot_response.rb

Overview

Defined Under Namespace

Modules: ScreenshotType Classes: KeyMetadata

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credits_consumed:, credits_remaining:) ⇒ Object

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.

Parameters:

  • credits_consumed (Integer)

    The number of credits consumed by this request.

  • credits_remaining (Integer)

    The number of credits remaining for your organization after this request.



# File 'lib/context_dev/models/web_screenshot_response.rb', line 58

Instance Attribute Details

#codeInteger?

HTTP status code

Returns:

  • (Integer, nil)


11
# File 'lib/context_dev/models/web_screenshot_response.rb', line 11

optional :code, Integer

#domainString?

The normalized domain that was processed

Returns:

  • (String, nil)


17
# File 'lib/context_dev/models/web_screenshot_response.rb', line 17

optional :domain, String

#heightInteger?

Height in pixels of the returned screenshot image

Returns:

  • (Integer, nil)


23
# File 'lib/context_dev/models/web_screenshot_response.rb', line 23

optional :height, Integer

#key_metadataContextDev::Models::WebScreenshotResponse::KeyMetadata?

Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.



30
# File 'lib/context_dev/models/web_screenshot_response.rb', line 30

optional :key_metadata, -> { ContextDev::Models::WebScreenshotResponse::KeyMetadata }

#screenshotString?

Public URL of the uploaded screenshot image

Returns:

  • (String, nil)


36
# File 'lib/context_dev/models/web_screenshot_response.rb', line 36

optional :screenshot, String

#screenshot_typeSymbol, ...

Type of screenshot that was captured



42
43
44
# File 'lib/context_dev/models/web_screenshot_response.rb', line 42

optional :screenshot_type,
enum: -> { ContextDev::Models::WebScreenshotResponse::ScreenshotType },
api_name: :screenshotType

#statusString?

Status of the response, e.g., ‘ok’

Returns:

  • (String, nil)


50
# File 'lib/context_dev/models/web_screenshot_response.rb', line 50

optional :status, String

#widthInteger?

Width in pixels of the returned screenshot image

Returns:

  • (Integer, nil)


56
# File 'lib/context_dev/models/web_screenshot_response.rb', line 56

optional :width, Integer