Class: ContextDev::Models::WebScreenshotResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebScreenshotResponse
- Defined in:
- lib/context_dev/models/web_screenshot_response.rb
Overview
Defined Under Namespace
Modules: ScreenshotType Classes: KeyMetadata
Instance Attribute Summary collapse
-
#code ⇒ Integer?
HTTP status code.
-
#domain ⇒ String?
The normalized domain that was processed.
-
#height ⇒ Integer?
Height in pixels of the returned screenshot image.
-
#key_metadata ⇒ ContextDev::Models::WebScreenshotResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#screenshot ⇒ String?
Public URL of the uploaded screenshot image.
-
#screenshot_type ⇒ Symbol, ...
Type of screenshot that was captured.
-
#status ⇒ String?
Status of the response, e.g., ‘ok’.
-
#width ⇒ Integer?
Width in pixels of the returned screenshot image.
Instance Method Summary collapse
-
#initialize(credits_consumed:, credits_remaining:) ⇒ Object
constructor
Metadata about the API key used for the request.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credits_consumed:, credits_remaining:) ⇒ Object
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
|
|
# File 'lib/context_dev/models/web_screenshot_response.rb', line 58
|
Instance Attribute Details
#code ⇒ Integer?
HTTP status code
11 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 11 optional :code, Integer |
#domain ⇒ String?
The normalized domain that was processed
17 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 17 optional :domain, String |
#height ⇒ Integer?
Height in pixels of the returned screenshot image
23 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 23 optional :height, Integer |
#key_metadata ⇒ ContextDev::Models::WebScreenshotResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
30 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 30 optional :key_metadata, -> { ContextDev::Models::WebScreenshotResponse::KeyMetadata } |
#screenshot ⇒ String?
Public URL of the uploaded screenshot image
36 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 36 optional :screenshot, String |
#screenshot_type ⇒ Symbol, ...
Type of screenshot that was captured
42 43 44 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 42 optional :screenshot_type, enum: -> { ContextDev::Models::WebScreenshotResponse::ScreenshotType }, api_name: :screenshotType |
#status ⇒ String?
Status of the response, e.g., ‘ok’
50 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 50 optional :status, String |
#width ⇒ Integer?
Width in pixels of the returned screenshot image
56 |
# File 'lib/context_dev/models/web_screenshot_response.rb', line 56 optional :width, Integer |