Class: ContextDev::Models::WebWebCrawlMdParams::Pdf
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebCrawlMdParams::Pdf
- Defined in:
- lib/context_dev/models/web_web_crawl_md_params.rb,
sig/context_dev/models/web_web_crawl_md_params.rbs
Instance Attribute Summary collapse
-
#end_ ⇒ Integer?
Last 1-based PDF page to parse.
-
#ocr ⇒ Boolean?
When true, detect and OCR images embedded in the selected PDF pages, inserting recognized text at each image's position in page reading order while preserving the PDF text layer.
-
#should_parse ⇒ Boolean?
When true, PDF pages are fetched and parsed.
-
#start ⇒ Integer?
First 1-based PDF page to parse.
Instance Method Summary collapse
-
#initialize(end_: nil, ocr: nil, should_parse: nil, start: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Pdf for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, ocr: nil, should_parse: nil, start: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebCrawlMdParams::Pdf for more details.
PDF parsing controls. Use start/end to limit text extraction and embedded-image detection/OCR to an inclusive 1-based page range.
|
|
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 434
|
Instance Attribute Details
#end_ ⇒ Integer?
Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Must be greater than or equal to start when both are provided.
411 |
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 411 optional :end_, Integer, api_name: :end |
#ocr ⇒ Boolean?
When true, detect and OCR images embedded in the selected PDF pages, inserting recognized text at each image's position in page reading order while preserving the PDF text layer. This is separate from automatic scanned-PDF OCR fallback.
419 |
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 419 optional :ocr, ContextDev::Internal::Type::Boolean |
#should_parse ⇒ Boolean?
When true, PDF pages are fetched and parsed. When false, PDF pages are skipped entirely (not included in results and not counted as failures).
426 |
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 426 optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse |
#start ⇒ Integer?
First 1-based PDF page to parse. When omitted, parsing starts at the first page.
432 |
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 432 optional :start, Integer |
Instance Method Details
#to_hash ⇒ {
599 |
# File 'sig/context_dev/models/web_web_crawl_md_params.rbs', line 599
def to_hash: -> {
|