Class: ContextDev::Models::WebWebCrawlMdParams::Pdf

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_web_crawl_md_params.rb,
sig/context_dev/models/web_web_crawl_md_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebWebCrawlMdParams::Pdf for more details.

PDF parsing controls. Use start/end to limit text extraction and OCR to an inclusive 1-based page range.

Parameters:

  • end_ (Integer) (defaults to: nil)

    Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Mus

  • should_parse (Boolean) (defaults to: nil)

    When true, PDF pages are fetched and parsed. When false, PDF pages are skipped e

  • start (Integer) (defaults to: nil)

    First 1-based PDF page to parse. When omitted, parsing starts at the first page.



# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 426

Instance Attribute Details

#end_Integer?

Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Must be greater than or equal to start when both are provided.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


411
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 411

optional :end_, Integer, api_name: :end

#should_parseBoolean?

When true, PDF pages are fetched and parsed. When false, PDF pages are skipped entirely (not included in results and not counted as failures).

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


418
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 418

optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse

#startInteger?

First 1-based PDF page to parse. When omitted, parsing starts at the first page.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


424
# File 'lib/context_dev/models/web_web_crawl_md_params.rb', line 424

optional :start, Integer

Instance Method Details

#to_hash{ end_: Integer, should_parse: bool, start: Integer }

Returns:

  • ({ end_: Integer, should_parse: bool, start: Integer })


593
# File 'sig/context_dev/models/web_web_crawl_md_params.rbs', line 593

def to_hash: -> { end_: Integer, should_parse: bool, start: Integer }