Class: ContextDev::Models::WebWebCrawlMdResponse::Result::Metadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_web_crawl_md_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(crawl_depth:, status_code:, success:, title:, url:) ⇒ Object

Parameters:

  • crawl_depth (Integer)

    Depth relative to the start URL. 0 = start URL, 1 = one link away.

  • status_code (Integer)

    HTTP status code of the response

  • success (Boolean)

    true if the page was fetched and parsed successfully

  • title (String)

    The page’s <title> content (empty string if unavailable)

  • url (String)

    The URL that was fetched



# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 107

Instance Attribute Details

#crawl_depthInteger

Depth relative to the start URL. 0 = start URL, 1 = one link away.

Returns:

  • (Integer)


81
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 81

required :crawl_depth, Integer, api_name: :crawlDepth

#status_codeInteger

HTTP status code of the response

Returns:

  • (Integer)


87
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 87

required :status_code, Integer, api_name: :statusCode

#successBoolean

true if the page was fetched and parsed successfully

Returns:

  • (Boolean)


93
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 93

required :success, ContextDev::Internal::Type::Boolean

#titleString

The page’s <title> content (empty string if unavailable)

Returns:

  • (String)


99
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 99

required :title, String

#urlString

The URL that was fetched

Returns:

  • (String)


105
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 105

required :url, String