Class: ContextDev::Models::WebWebCrawlMdResponse::Result::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebCrawlMdResponse::Result::Metadata
- Defined in:
- lib/context_dev/models/web_web_crawl_md_response.rb
Overview
Instance Attribute Summary collapse
-
#crawl_depth ⇒ Integer
Depth relative to the start URL.
-
#status_code ⇒ Integer
HTTP status code of the response.
-
#success ⇒ Boolean
true if the page was fetched and parsed successfully.
-
#title ⇒ String
The page’s <title> content (empty string if unavailable).
-
#url ⇒ String
The URL that was fetched.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(crawl_depth:, status_code:, success:, title:, url:) ⇒ Object
|
|
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 107
|
Instance Attribute Details
#crawl_depth ⇒ Integer
Depth relative to the start URL. 0 = start URL, 1 = one link away.
81 |
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 81 required :crawl_depth, Integer, api_name: :crawlDepth |
#status_code ⇒ Integer
HTTP status code of the response
87 |
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 87 required :status_code, Integer, api_name: :statusCode |
#success ⇒ Boolean
true if the page was fetched and parsed successfully
93 |
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 93 required :success, ContextDev::Internal::Type::Boolean |
#title ⇒ String
The page’s <title> content (empty string if unavailable)
99 |
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 99 required :title, String |
#url ⇒ String
The URL that was fetched
105 |
# File 'lib/context_dev/models/web_web_crawl_md_response.rb', line 105 required :url, String |