Class: ContextDev::Models::WebWebScrapeHTMLParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/context_dev/models/web_web_scrape_html_params.rb

Overview

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from ContextDev::Internal::Type::BaseModel

Instance Attribute Details

#include_framesBoolean?

When true, iframes are rendered inline into the returned HTML.

Returns:

  • (Boolean, nil)


20
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 20

optional :include_frames, ContextDev::Internal::Type::Boolean

#max_age_msInteger?

Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds. Defaults to 1 day (86400000 ms) when omitted. Max is 30 days (2592000000 ms). Set to 0 to always scrape fresh.

Returns:

  • (Integer, nil)


28
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 28

optional :max_age_ms, Integer

#pdfContextDev::Models::WebWebScrapeHTMLParams::Pdf?

PDF parsing controls. Use start/end to limit text extraction and OCR to an inclusive 1-based page range.



35
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 35

optional :pdf, -> { ContextDev::WebWebScrapeHTMLParams::Pdf }

#timeout_msInteger?

Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).

Returns:

  • (Integer, nil)


43
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 43

optional :timeout_ms, Integer

#urlString

Full URL to scrape (must include http:// or https:// protocol)

Returns:

  • (String)


14
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 14

required :url, String

#wait_for_msInteger?

Optional browser wait time in milliseconds after initial page load. Min: 0. Max: 30000 (30 seconds).

Returns:

  • (Integer, nil)


50
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 50

optional :wait_for_ms, Integer