Class: ContextDev::Models::WebWebScrapeHTMLParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeHTMLParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_web_scrape_html_params.rb
Overview
Instance Attribute Summary collapse
-
#max_age_ms ⇒ Integer?
Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds.
-
#url ⇒ String
Full URL to scrape (must include http:// or https:// protocol).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(url:, max_age_ms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebWebScrapeHTMLParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, max_age_ms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeHTMLParams for more details.
|
|
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 24
|
Instance Attribute Details
#max_age_ms ⇒ Integer?
Return a cached result if a prior scrape for the same parameters exists and is younger than this many milliseconds. Defaults to 1 day (86400000 ms) when omitted. Max is 30 days (2592000000 ms). Set to 0 to always scrape fresh.
22 |
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 22 optional :max_age_ms, Integer |
#url ⇒ String
Full URL to scrape (must include http:// or https:// protocol)
14 |
# File 'lib/context_dev/models/web_web_scrape_html_params.rb', line 14 required :url, String |