Class: ContextDev::Models::WebWebScrapeImagesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeImagesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_web_scrape_images_params.rb
Overview
Defined Under Namespace
Classes: Enrichment
Instance Attribute Summary collapse
-
#enrichment ⇒ ContextDev::Models::WebWebScrapeImagesParams::Enrichment?
Optional per-image processing, sent as deep-object query params such as enrichment=true.
-
#max_age_ms ⇒ Integer?
Reuse a cached result this many milliseconds old or newer.
-
#url ⇒ String
Page URL to inspect.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ContextDev::Internal::Type::BaseModel
Instance Attribute Details
#enrichment ⇒ ContextDev::Models::WebWebScrapeImagesParams::Enrichment?
Optional per-image processing, sent as deep-object query params such as enrichment=true.
21 |
# File 'lib/context_dev/models/web_web_scrape_images_params.rb', line 21 optional :enrichment, -> { ContextDev::WebWebScrapeImagesParams::Enrichment } |
#max_age_ms ⇒ Integer?
Reuse a cached result this many milliseconds old or newer. Default: 86400000 (1 day). Set to 0 to bypass cache. Maximum: 2592000000 (30 days).
28 |
# File 'lib/context_dev/models/web_web_scrape_images_params.rb', line 28 optional :max_age_ms, Integer |
#url ⇒ String
Page URL to inspect. Must include http:// or https://.
14 |
# File 'lib/context_dev/models/web_web_scrape_images_params.rb', line 14 required :url, String |