Module: ContextDev::Models::WebWebScrapeImagesParams::Dedupe
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/context_dev/models/web_web_scrape_images_params.rb,
sig/context_dev/models/web_web_scrape_images_params.rbs
Overview
When true, visually duplicate images are removed: every image is loaded and perceptually hashed, and only the highest-resolution copy of each duplicate group is kept. Images that cannot be downloaded or hashed are kept. Default: false.
collapse
- TRUE =
:true- FALSE =
:false
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Boolean, Symbol)
175 176 177 |
# File 'lib/context_dev/models/web_web_scrape_images_params.rb', line 175 define_sorbet_constant!(:Variants) do T.type_alias { T.any(T::Boolean, ContextDev::WebWebScrapeImagesParams::Dedupe::TaggedSymbol) } end |
Instance Method Details
#self?.variants ⇒ ::Array[ContextDev::Models::WebWebScrapeImagesParams::dedupe]
114 |
# File 'sig/context_dev/models/web_web_scrape_images_params.rbs', line 114
def self?.variants: -> ::Array[ContextDev::Models::WebWebScrapeImagesParams::dedupe]
|