Class: ContextDev::Models::WebWebScrapeMdParams::Pdf
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeMdParams::Pdf
- Defined in:
- lib/context_dev/models/web_web_scrape_md_params.rb
Instance Attribute Summary collapse
-
#end_ ⇒ Integer?
Last 1-based PDF page to parse.
-
#should_parse ⇒ Boolean?
When true, PDF URLs are fetched and parsed.
-
#start ⇒ Integer?
First 1-based PDF page to parse.
Instance Method Summary collapse
-
#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Pdf for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeMdParams::Pdf for more details.
PDF parsing controls. Use start/end to limit text extraction and OCR to an inclusive 1-based page range.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 134 class Pdf < ContextDev::Internal::Type::BaseModel # @!attribute end_ # Last 1-based PDF page to parse. When omitted, parsing ends at the last page. # Must be greater than or equal to start when both are provided. # # @return [Integer, nil] optional :end_, Integer, api_name: :end # @!attribute should_parse # When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and # a 400 WEBSITE_ACCESS_ERROR is returned. # # @return [Boolean, nil] optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse # @!attribute start # First 1-based PDF page to parse. When omitted, parsing starts at the first page. # # @return [Integer, nil] optional :start, Integer # @!method initialize(end_: nil, should_parse: nil, start: nil) # Some parameter documentations has been truncated, see # {ContextDev::Models::WebWebScrapeMdParams::Pdf} for more details. # # PDF parsing controls. Use start/end to limit text extraction and OCR to an # inclusive 1-based page range. # # @param end_ [Integer] Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Mus # # @param should_parse [Boolean] When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and # # @param start [Integer] First 1-based PDF page to parse. When omitted, parsing starts at the first page. end |
Instance Attribute Details
#end_ ⇒ Integer?
Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Must be greater than or equal to start when both are provided.
140 |
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 140 optional :end_, Integer, api_name: :end |
#should_parse ⇒ Boolean?
When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and a 400 WEBSITE_ACCESS_ERROR is returned.
147 |
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 147 optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse |
#start ⇒ Integer?
First 1-based PDF page to parse. When omitted, parsing starts at the first page.
153 |
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 153 optional :start, Integer |