Class: ContextDev::Models::WebWebScrapeMdParams::Pdf

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/context_dev/models/web_web_scrape_md_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_: nil, should_parse: nil, start: nil) ⇒ Object

Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeMdParams::Pdf for more details.

PDF parsing controls. Use start/end to limit text extraction and OCR to an inclusive 1-based page range.

Parameters:

  • end_ (Integer) (defaults to: nil)

    Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Mus

  • should_parse (Boolean) (defaults to: nil)

    When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and

  • start (Integer) (defaults to: nil)

    First 1-based PDF page to parse. When omitted, parsing starts at the first page.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 104

class Pdf < ContextDev::Internal::Type::BaseModel
  # @!attribute end_
  #   Last 1-based PDF page to parse. When omitted, parsing ends at the last page.
  #   Must be greater than or equal to start when both are provided.
  #
  #   @return [Integer, nil]
  optional :end_, Integer, api_name: :end

  # @!attribute should_parse
  #   When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and
  #   a 400 WEBSITE_ACCESS_ERROR is returned.
  #
  #   @return [Boolean, nil]
  optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse

  # @!attribute start
  #   First 1-based PDF page to parse. When omitted, parsing starts at the first page.
  #
  #   @return [Integer, nil]
  optional :start, Integer

  # @!method initialize(end_: nil, should_parse: nil, start: nil)
  #   Some parameter documentations has been truncated, see
  #   {ContextDev::Models::WebWebScrapeMdParams::Pdf} for more details.
  #
  #   PDF parsing controls. Use start/end to limit text extraction and OCR to an
  #   inclusive 1-based page range.
  #
  #   @param end_ [Integer] Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Mus
  #
  #   @param should_parse [Boolean] When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and
  #
  #   @param start [Integer] First 1-based PDF page to parse. When omitted, parsing starts at the first page.
end

Instance Attribute Details

#end_Integer?

Last 1-based PDF page to parse. When omitted, parsing ends at the last page. Must be greater than or equal to start when both are provided.

Returns:

  • (Integer, nil)


110
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 110

optional :end_, Integer, api_name: :end

#should_parseBoolean?

When true, PDF URLs are fetched and parsed. When false, PDF URLs are skipped and a 400 WEBSITE_ACCESS_ERROR is returned.

Returns:

  • (Boolean, nil)


117
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 117

optional :should_parse, ContextDev::Internal::Type::Boolean, api_name: :shouldParse

#startInteger?

First 1-based PDF page to parse. When omitted, parsing starts at the first page.

Returns:

  • (Integer, nil)


123
# File 'lib/context_dev/models/web_web_scrape_md_params.rb', line 123

optional :start, Integer