Class: ContextDev::Models::WebWebScrapeMdResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeMdResponse
- Defined in:
- lib/context_dev/models/web_web_scrape_md_response.rb,
sig/context_dev/models/web_web_scrape_md_response.rbs
Overview
Defined Under Namespace
Modules: Success Classes: KeyMetadata, Metadata
Instance Attribute Summary collapse
-
#content_length ⇒ Integer
UTF-8 byte length of the returned Markdown.
-
#key_metadata ⇒ ContextDev::Models::WebWebScrapeMdResponse::KeyMetadata?
Metadata about the API key used for the request.
-
#markdown ⇒ String
Page content converted to GitHub Flavored Markdown.
-
#metadata ⇒ ContextDev::Models::WebWebScrapeMdResponse::Metadata
Metadata extracted from the scraped page HTML.
-
#success ⇒ Boolean, ContextDev::Models::WebWebScrapeMdResponse::Success
Indicates success.
-
#url ⇒ String
The URL that was scraped.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(content_length:, markdown:, metadata:, success:, url:, key_metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebWebScrapeMdResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_length:, markdown:, metadata:, success:, url:, key_metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeMdResponse for more details.
|
|
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 46
|
Instance Attribute Details
#content_length ⇒ Integer
UTF-8 byte length of the returned Markdown. Use 0 to identify an empty result and compare small values against your workload's minimum useful-content threshold.
13 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 13 required :content_length, Integer, api_name: :contentLength |
#key_metadata ⇒ ContextDev::Models::WebWebScrapeMdResponse::KeyMetadata?
Metadata about the API key used for the request. Included in every response whenever a valid API key is provided, even when the response status is not 200.
44 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 44 optional :key_metadata, -> { ContextDev::Models::WebWebScrapeMdResponse::KeyMetadata } |
#markdown ⇒ String
Page content converted to GitHub Flavored Markdown
19 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 19 required :markdown, String |
#metadata ⇒ ContextDev::Models::WebWebScrapeMdResponse::Metadata
Metadata extracted from the scraped page HTML.
25 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 25 required :metadata, -> { ContextDev::Models::WebWebScrapeMdResponse::Metadata } |
#success ⇒ Boolean, ContextDev::Models::WebWebScrapeMdResponse::Success
Indicates success
31 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 31 required :success, enum: -> { ContextDev::Models::WebWebScrapeMdResponse::Success } |
#url ⇒ String
The URL that was scraped
37 |
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 37 required :url, String |
Class Method Details
.values ⇒ Array<Boolean>
|
|
# File 'lib/context_dev/models/web_web_scrape_md_response.rb', line 317
|
Instance Method Details
#to_hash ⇒ {
39 |
# File 'sig/context_dev/models/web_web_scrape_md_response.rbs', line 39
def to_hash: -> {
|