Class: ContextDev::Models::WebWebScrapeSitemapParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeSitemapParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_web_scrape_sitemap_params.rb,
sig/context_dev/models/web_web_scrape_sitemap_params.rbs
Overview
Defined Under Namespace
Modules: Zdr
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ContextDev
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain to build a sitemap for.
-
#headers ⇒ Hash{Symbol=>String}?
Optional outbound HTTP headers forwarded only to the target URL, sent as deep-object query params such as headers=value.
-
#max_links ⇒ Integer?
Maximum number of links to return from the sitemap crawl.
-
#sitemap_url ⇒ String?
Optional explicit sitemap URL.
-
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request.
-
#url_regex ⇒ String?
Optional RE2-compatible regex pattern.
-
#zdr ⇒ Symbol, ...
Set to enabled to bypass shared caches and omit request and response content from retained usage logs.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(domain:, headers: nil, max_links: nil, sitemap_url: nil, tags: nil, timeout_ms: nil, url_regex: nil, zdr: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebWebScrapeSitemapParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain:, headers: nil, max_links: nil, sitemap_url: nil, tags: nil, timeout_ms: nil, url_regex: nil, zdr: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeSitemapParams for more details.
|
|
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 70
|
Instance Attribute Details
#domain ⇒ String
Domain to build a sitemap for
14 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 14 required :domain, String |
#headers ⇒ Hash{Symbol=>String}?
Optional outbound HTTP headers forwarded only to the target URL, sent as deep-object query params such as headers=value. When provided, caching is bypassed: the result is neither read from nor written to cache.
22 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 22 optional :headers, ContextDev::Internal::Type::HashOf[String] |
#max_links ⇒ Integer?
Maximum number of links to return from the sitemap crawl. Defaults to 10,000. Minimum is 1, maximum is 100,000.
29 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 29 optional :max_links, Integer |
#sitemap_url ⇒ String?
Optional explicit sitemap URL. When provided, exactly this sitemap is crawled instead of discovering the domain's sitemaps.
36 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 36 optional :sitemap_url, String |
#tags ⇒ Array<String>?
Optional comma-separated caller-defined tags for tracking this request. Tags are recorded on the request's usage log and can be used to filter usage on the dashboard usage page. Up to 20 tags, each 1-50 characters.
44 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 44 optional :tags, ContextDev::Internal::Type::ArrayOf[String] |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the request. If the request takes longer than this value, it will be aborted with a 408 status code. Maximum allowed value is 300000ms (5 minutes).
52 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 52 optional :timeout_ms, Integer |
#url_regex ⇒ String?
Optional RE2-compatible regex pattern. Only URLs matching this pattern are returned and counted against maxLinks.
59 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 59 optional :url_regex, String |
#zdr ⇒ Symbol, ...
Set to enabled to bypass shared caches and omit request and response content from retained usage logs. Requires zero data retention to be enabled for your organization (contact support@context.dev), otherwise the request fails with ZDR_NOT_ENABLED. Successful ZDR responses include X-Context-ZDR: true.
68 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 68 optional :zdr, enum: -> { ContextDev::WebWebScrapeSitemapParams::Zdr } |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/context_dev/models/web_web_scrape_sitemap_params.rbs', line 64
def to_hash: -> {
|