Class: ContextDev::Models::WebWebScrapeSitemapParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ContextDev::Models::WebWebScrapeSitemapParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/context_dev/models/web_web_scrape_sitemap_params.rb
Overview
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain to build a sitemap for.
-
#max_links ⇒ Integer?
Maximum number of links to return from the sitemap crawl.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(domain:, max_links: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebWebScrapeSitemapParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(domain:, max_links: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ContextDev::Models::WebWebScrapeSitemapParams for more details.
|
|
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 23
|
Instance Attribute Details
#domain ⇒ String
Domain to build a sitemap for
14 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 14 required :domain, String |
#max_links ⇒ Integer?
Maximum number of links to return from the sitemap crawl. Defaults to 10,000. Minimum is 1, maximum is 100,000.
21 |
# File 'lib/context_dev/models/web_web_scrape_sitemap_params.rb', line 21 optional :max_links, Integer |