Class: ContextDev::Resources::Brand
- Inherits:
-
Object
- Object
- ContextDev::Resources::Brand
- Defined in:
- lib/context_dev/resources/brand.rb
Instance Method Summary collapse
-
#identify_from_transaction(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandIdentifyFromTransactionResponse
Some parameter documentations has been truncated, see Models::BrandIdentifyFromTransactionParams for more details.
-
#initialize(client:) ⇒ Brand
constructor
private
A new instance of Brand.
-
#retrieve(domain:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveParams for more details.
-
#retrieve_by_email(email:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByEmailResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByEmailParams for more details.
-
#retrieve_by_isin(isin:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByIsinResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByIsinParams for more details.
-
#retrieve_by_name(name:, country_gl: nil, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByNameResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByNameParams for more details.
-
#retrieve_by_ticker(ticker:, force_language: nil, max_age_ms: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByTickerResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByTickerParams for more details.
-
#retrieve_simplified(domain:, max_age_ms: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveSimplifiedResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveSimplifiedParams for more details.
Constructor Details
#initialize(client:) ⇒ Brand
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Brand.
262 263 264 |
# File 'lib/context_dev/resources/brand.rb', line 262 def initialize(client:) @client = client end |
Instance Method Details
#identify_from_transaction(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandIdentifyFromTransactionResponse
Some parameter documentations has been truncated, see Models::BrandIdentifyFromTransactionParams for more details.
Endpoint specially designed for platforms that want to identify transaction data by the transaction title.
72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/context_dev/resources/brand.rb', line 72 def identify_from_transaction(params) parsed, = ContextDev::BrandIdentifyFromTransactionParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/transaction_identifier", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandIdentifyFromTransactionResponse, options: ) end |
#retrieve(domain:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveParams for more details.
Retrieve logos, backdrops, colors, industry, description, and more from any domain
29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/context_dev/resources/brand.rb', line 29 def retrieve(params) parsed, = ContextDev::BrandRetrieveParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve", query: query.transform_keys(max_age_ms: "maxAgeMs", max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveResponse, options: ) end |
#retrieve_by_email(email:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByEmailResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByEmailParams for more details.
Retrieve brand information using an email address while detecting disposable and free email addresses. Disposable and free email addresses (like gmail.com, yahoo.com) will throw a 422 error.
108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/context_dev/resources/brand.rb', line 108 def retrieve_by_email(params) parsed, = ContextDev::BrandRetrieveByEmailParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-email", query: query.transform_keys(max_age_ms: "maxAgeMs", max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByEmailResponse, options: ) end |
#retrieve_by_isin(isin:, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByIsinResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByIsinParams for more details.
Retrieve brand information using an ISIN (International Securities Identification Number).
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/context_dev/resources/brand.rb', line 143 def retrieve_by_isin(params) parsed, = ContextDev::BrandRetrieveByIsinParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-isin", query: query.transform_keys(max_age_ms: "maxAgeMs", max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByIsinResponse, options: ) end |
#retrieve_by_name(name:, country_gl: nil, force_language: nil, max_age_ms: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByNameResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByNameParams for more details.
Retrieve brand information using a company name.
179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/context_dev/resources/brand.rb', line 179 def retrieve_by_name(params) parsed, = ContextDev::BrandRetrieveByNameParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-name", query: query.transform_keys(max_age_ms: "maxAgeMs", max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByNameResponse, options: ) end |
#retrieve_by_ticker(ticker:, force_language: nil, max_age_ms: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByTickerResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByTickerParams for more details.
Retrieve brand information using a stock ticker symbol.
215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/context_dev/resources/brand.rb', line 215 def retrieve_by_ticker(params) parsed, = ContextDev::BrandRetrieveByTickerParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-ticker", query: query.transform_keys(max_age_ms: "maxAgeMs", max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByTickerResponse, options: ) end |
#retrieve_simplified(domain:, max_age_ms: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveSimplifiedResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveSimplifiedParams for more details.
Returns a simplified version of brand data containing only essential information: domain, title, colors, logos, and backdrops. Optimized for faster responses and reduced data transfer.
247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/context_dev/resources/brand.rb', line 247 def retrieve_simplified(params) parsed, = ContextDev::BrandRetrieveSimplifiedParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-simplified", query: query.transform_keys(max_age_ms: "maxAgeMs", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveSimplifiedResponse, options: ) end |