Class: ContextDev::Resources::Brand
- Inherits:
-
Object
- Object
- ContextDev::Resources::Brand
- Defined in:
- lib/context_dev/resources/brand.rb
Instance Method Summary collapse
-
#identify_from_transaction(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandIdentifyFromTransactionResponse
Some parameter documentations has been truncated, see Models::BrandIdentifyFromTransactionParams for more details.
-
#initialize(client:) ⇒ Brand
constructor
private
A new instance of Brand.
-
#retrieve(domain:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveParams for more details.
-
#retrieve_by_email(email:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByEmailResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByEmailParams for more details.
-
#retrieve_by_isin(isin:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByIsinResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByIsinParams for more details.
-
#retrieve_by_name(name:, country_gl: nil, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByNameResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByNameParams for more details.
-
#retrieve_by_ticker(ticker:, force_language: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByTickerResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByTickerParams for more details.
-
#retrieve_simplified(domain:, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveSimplifiedResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveSimplifiedParams for more details.
Constructor Details
#initialize(client:) ⇒ Brand
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Brand.
250 251 252 |
# File 'lib/context_dev/resources/brand.rb', line 250 def initialize(client:) @client = client end |
Instance Method Details
#identify_from_transaction(transaction_info:, city: nil, country_gl: nil, force_language: nil, high_confidence_only: nil, max_speed: nil, mcc: nil, phone: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandIdentifyFromTransactionResponse
Some parameter documentations has been truncated, see Models::BrandIdentifyFromTransactionParams for more details.
Endpoint specially designed for platforms that want to identify transaction data by the transaction title.
70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/context_dev/resources/brand.rb', line 70 def identify_from_transaction(params) parsed, = ContextDev::BrandIdentifyFromTransactionParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/transaction_identifier", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandIdentifyFromTransactionResponse, options: ) end |
#retrieve(domain:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveParams for more details.
Retrieve logos, backdrops, colors, industry, description, and more from any domain
27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/context_dev/resources/brand.rb', line 27 def retrieve(params) parsed, = ContextDev::BrandRetrieveParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveResponse, options: ) end |
#retrieve_by_email(email:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByEmailResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByEmailParams for more details.
Retrieve brand information using an email address while detecting disposable and free email addresses. Disposable and free email addresses (like gmail.com, yahoo.com) will throw a 422 error.
104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/context_dev/resources/brand.rb', line 104 def retrieve_by_email(params) parsed, = ContextDev::BrandRetrieveByEmailParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-email", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByEmailResponse, options: ) end |
#retrieve_by_isin(isin:, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByIsinResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByIsinParams for more details.
Retrieve brand information using an ISIN (International Securities Identification Number).
137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/context_dev/resources/brand.rb', line 137 def retrieve_by_isin(params) parsed, = ContextDev::BrandRetrieveByIsinParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-isin", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByIsinResponse, options: ) end |
#retrieve_by_name(name:, country_gl: nil, force_language: nil, max_speed: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByNameResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByNameParams for more details.
Retrieve brand information using a company name.
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/context_dev/resources/brand.rb', line 171 def retrieve_by_name(params) parsed, = ContextDev::BrandRetrieveByNameParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-name", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByNameResponse, options: ) end |
#retrieve_by_ticker(ticker:, force_language: nil, max_speed: nil, ticker_exchange: nil, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveByTickerResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveByTickerParams for more details.
Retrieve brand information using a stock ticker symbol.
205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/context_dev/resources/brand.rb', line 205 def retrieve_by_ticker(params) parsed, = ContextDev::BrandRetrieveByTickerParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-by-ticker", query: query.transform_keys(max_speed: "maxSpeed", timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveByTickerResponse, options: ) end |
#retrieve_simplified(domain:, timeout_ms: nil, request_options: {}) ⇒ ContextDev::Models::BrandRetrieveSimplifiedResponse
Some parameter documentations has been truncated, see Models::BrandRetrieveSimplifiedParams for more details.
Returns a simplified version of brand data containing only essential information: domain, title, colors, logos, and backdrops. Optimized for faster responses and reduced data transfer.
235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/context_dev/resources/brand.rb', line 235 def retrieve_simplified(params) parsed, = ContextDev::BrandRetrieveSimplifiedParams.dump_request(params) query = ContextDev::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "brand/retrieve-simplified", query: query.transform_keys(timeout_ms: "timeoutMS"), model: ContextDev::Models::BrandRetrieveSimplifiedResponse, options: ) end |